/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
/*
 * Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.
 */
import { Component, Event, h, Host, Listen, Prop, Method, State, Watch } from '@stencil/core';
import state, { listenToLanguageChange, setLocale } from '../../utils/locale-store';
import { translate, isHideSeconds } from '../../utils/utils';
import './datepicker/datepicker';
import './timepicker/timepicker';
import { dateServiceFactory, formattingServiceFactory } from './service';
import { OverlayHandler } from '../overlay/overlay-handler';
const EMPTYDATEPICKERINPUTOBJ = {
  dateStart: null,
  dateEnd: null,
  timeStart: null,
  timeEnd: null,
  timestampStart: null,
  timestampEnd: null,
  valid: true,
};
export class DatetimePicker {
  constructor() {
    /** Label of the datepicker input field. */
    this.label = '';
    /** Placeholder of the datepicker input field. */
    this.placeholder = '';
    /** Format of the date. */
    this.formatDate = 'dd.MM.yyyy';
    /** The max date that should be selectable. */
    this.maxDate = 20000000000000;
    /** The min date that should be selectable. */
    this.minDate = 0;
    /** please use timeFormat 'H:mm'(hours and minutes) or 'hh:mm a'(hours and minutes with AM/PM) or 'hh:mm:ss a(hours,minutes,seconds with AM/PM)',for the date range picker  */
    this.timeFormat = 'H:mm';
    this.dateTimePickerInputObj = EMPTYDATEPICKERINPUTOBJ;
    /** Reactive state for UI changes depening on overlay opening state */
    this.overlayVisible = false;
    this.overlayHandler = new OverlayHandler();
    this.formatService = formattingServiceFactory();
    this.dateService = dateServiceFactory({
      formatService: this.formatService,
    });
    this.showTemplates = false;
  }
  async componentWillLoad() {
    await setLocale();
    this.setInputPlaceholderText();
    listenToLanguageChange(() => this.setInputPlaceholderText());
    this.timePickerConfig = {
      timeFormat: this.timeFormat,
      rangeDateTime: this.rangeDateTime,
    };
    this.datePickerConfig = {
      formatDate: this.formatDate === undefined ? state.dateFormat : this.formatDate,
      maxDate: this.maxDate,
      minDate: this.minDate,
      rangeDateTime: this.rangeDateTime,
      sundayFirst: this.sundayFirst,
      timeZone: this.timeZone,
    };
    /** Remove with next Major Update */
    if (!this.hide && this.hideTime) {
      this.hide = 'time';
    }
  }
  componentDidLoad() {
    this.overlayHandler.dialog.onclick = (ev) => {
      ev.stopPropagation();
    };
    this.overlayHandler.host.onclick = (ev) => {
      ev.stopPropagation();
    };
    this.formatService.dateFormat = this.formatDate;
    this.formatService.timeFormat = this.timeFormat;
    this.formatService.timeZone = this.timeZone;
    if (isHideSeconds(this.timeFormat)) {
      this.hideSeconds = false;
      this.dateService.hideSeconds = false;
    }
    else {
      this.hideSeconds = true;
      this.dateService.hideSeconds = true;
    }
    this.dateService.rangeDateTime = this.rangeDateTime;
    this.dateService.minDate = this.minDate;
    this.dateService.maxDate = this.maxDate;
    const dateTime = this.getStartupDateTime();
    if (dateTime === undefined) {
      return;
    }
    this.dateTimePickerInputObj = Object.assign(Object.assign({}, this.dateTimePickerInputObj), dateTime);
    this.updateDatePickerInput();
  }
  onDateTimeChanged(dateTime) {
    var _a;
    this.dateTimePickerInputObj = Object.assign(Object.assign({}, this.dateTimePickerInputObj), dateTime);
    this.selectedTemplateId = null;
    (_a = this.overlayHandler.dialog) === null || _a === void 0 ? void 0 : _a.close();
    this.updateDatePickerInput();
  }
  onTimeStampChanged(timeStamp) {
    var _a;
    this.dateTimePickerInputObj = Object.assign(Object.assign({}, this.dateTimePickerInputObj), { dateStart: this.formatService.formatDate(timeStamp.timestampStart), timeStart: this.formatService.formatTime(timeStamp.timestampStart), dateEnd: this.formatService.formatDate(timeStamp.timestampEnd), timeEnd: this.formatService.formatTime(timeStamp.timestampEnd) });
    this.selectedTemplateId = null;
    (_a = this.overlayHandler.dialog) === null || _a === void 0 ? void 0 : _a.close();
    this.updateDatePickerInput();
  }
  onPlaceholderChanged() {
    this.setInputPlaceholderText();
  }
  /**
   * - listens to the 'OverlayOpenedEvent' event which is triggered when another datetimepicker on the page is opened (see overlay component)
   * - if this is the case and the overlay of this datetimepicker is open (which closes through the event) the placeholder text needs to be updated
   * - therefore the placeholder is shown again after the user opens the datetimepicker and closes it through the opening of another datetimepicker on the page
   */
  updatePlaceholderOnOverlayOpenedEvent() {
    var _a;
    this.overlayVisible = false;
    (_a = this.overlayHandler.dialog) === null || _a === void 0 ? void 0 : _a.closeYearMonthSelection();
    if (this.overlayHandler.isVisible()) {
      this.setInputPlaceholderText();
    }
  }
  handleMouseDown(event) {
    this.handleClickOutside(event);
  }
  handleTouchStart(event) {
    this.handleClickOutside(event);
  }
  handleClickOutside(event) {
    var _a, _b, _c;
    if (this.overlayHandler.isHidden()) {
      // Don't stopPropagation if dateTimePicket is closed
      return;
    }
    if (((_a = this.datepickerRef) === null || _a === void 0 ? void 0 : _a.contains(event.target)) || ((_b = this.overlayHandler.dialog) === null || _b === void 0 ? void 0 : _b.contains(event.target))) {
      return;
    }
    if (this.overlayHandler.isVisible()) {
      this.save();
      this.overlayVisible = false;
      (_c = this.overlayHandler.dialog) === null || _c === void 0 ? void 0 : _c.closeYearMonthSelection();
    }
  }
  handleEscape(ev) {
    // in case of 'Escape'
    if (ev.key !== 'Escape') {
      return;
    }
    if (this.overlayHandler.isVisible()) {
      this.save();
    }
    this.dateTimePickerInput.blur();
  }
  handleTab(ev) {
    var _a;
    if (ev.key !== 'Tab') {
      return;
    }
    const sourceTarget = ev.composedPath()[0];
    if (this.hide === 'time' ||
      (sourceTarget.dataset.seconds &&
        ((sourceTarget.parentElement && sourceTarget.parentElement.classList.contains('rangeTimePicker')) || !this.rangeDateTime) &&
        !ev.shiftKey) ||
      (this.hideSeconds && !this.rangeDateTime && sourceTarget.dataset.minutes && !ev.shiftKey) ||
      (this.hideSeconds &&
        sourceTarget.dataset.minutes &&
        sourceTarget.parentElement &&
        sourceTarget.parentElement.classList.contains('rangeTimePicker')) ||
      (sourceTarget && sourceTarget.classList.contains('input-field') && ev.shiftKey)) {
      this.save();
    }
    this.overlayHandler.hide();
    this.overlayVisible = false;
    (_a = this.overlayHandler.dialog) === null || _a === void 0 ? void 0 : _a.closeYearMonthSelection();
  }
  handleEnter(ev) {
    // in case of 'Enter'
    if (ev.key !== 'Enter') {
      return;
    }
    if (this.overlayHandler.isVisible()) {
      this.save();
    }
    this.dateTimePickerInput.blur();
  }
  async toggle() {
    if (!this.overlayHandler.isReady()) {
      return;
    }
    if (this.overlayHandler.isVisible()) {
      this.save();
    }
    else {
      this.overlayHandler.show();
      this.overlayVisible = true;
    }
    this.setInputPlaceholderText();
  }
  showPickerContainer() {
    this.inputPlaceholder = '';
    this.overlayHandler.show();
    this.overlayVisible = true;
  }
  getStartupDateTime() {
    if (this.timeStamp) {
      return {
        dateStart: this.formatService.formatDate(this.timeStamp.timestampStart),
        timeStart: this.formatService.formatTime(this.timeStamp.timestampStart),
        dateEnd: this.formatService.formatDate(this.timeStamp.timestampEnd),
        timeEnd: this.formatService.formatTime(this.timeStamp.timestampEnd),
      };
    }
    if (this.dateTime) {
      const { dateStart, dateEnd, timeStart, timeEnd } = this.dateTime;
      return {
        dateStart: dateStart !== null && dateStart !== void 0 ? dateStart : null,
        dateEnd: dateEnd !== null && dateEnd !== void 0 ? dateEnd : null,
        timeStart: timeStart !== null && timeStart !== void 0 ? timeStart : null,
        timeEnd: timeEnd !== null && timeEnd !== void 0 ? timeEnd : null,
      };
    }
  }
  updateDatePickerInput() {
    if (this.dateTimePickerInput) {
      this.dateTimePickerInput.value = this.getInputValue();
    }
  }
  /** Function to reset the datepicker's selection */
  async resetSelection() {
    var _a;
    this.dateTimePickerInputObj = EMPTYDATEPICKERINPUTOBJ;
    this.selectedTemplateId = null;
    (_a = this.overlayHandler.dialog) === null || _a === void 0 ? void 0 : _a.close();
    this.updateDatePickerInput();
    this.newDateSelected.emit(this.dateTimePickerInputObj);
  }
  getInputValue() {
    var _a;
    let returnValue = '';
    if (this.isNull()) {
      return returnValue;
    }
    if (this.showTemplates && this.selectedTemplateId) {
      /** Either a template or the template group with the selected template in it */
      const foundElement = this.templatesList.find((x) => 'templates' in x ? x.templates.find((y) => y.id === this.selectedTemplateId) : x.id === this.selectedTemplateId);
      returnValue =
        'templates' in foundElement
          ? (_a = foundElement.templates.find((template) => template.id === this.selectedTemplateId)) === null || _a === void 0 ? void 0 : _a.label
          : foundElement === null || foundElement === void 0 ? void 0 : foundElement.label;
    }
    if (returnValue === '') {
      const { dateStart, dateEnd, timeStart, timeEnd } = this.dateTimePickerInputObj;
      returnValue = this.formatService.formatRange(dateStart, dateEnd, timeStart, timeEnd);
    }
    return returnValue;
  }
  get openingIcon() {
    return this.hide === 'calendar' ? 'clock' : this.hide === 'time' ? 'calendar' : 'calendar-clock';
  }
  updateDatePickerComponent(ev) {
    const value = ev.target.value;
    const dateInput = this.dateService.getDataFromInput(value);
    const validityCheck = this.dateService.validateInput(dateInput);
    this.dateTimePickerInputObj = Object.assign(Object.assign(Object.assign({}, this.dateTimePickerInputObj), dateInput), validityCheck);
  }
  /** Corrects data based on configuration */
  correctData() {
    this.dateTimePickerInputObj = Object.assign(Object.assign({}, this.dateTimePickerInputObj), this.dateService.correctInputData(this.dateTimePickerInputObj));
    if (this.hide === 'calendar') {
      this.dateTimePickerInputObj = Object.assign(Object.assign({}, this.dateTimePickerInputObj), { dateStart: null, dateEnd: null });
    }
    else if (this.hide === 'time') {
      this.dateTimePickerInputObj = Object.assign(Object.assign({}, this.dateTimePickerInputObj), { timeStart: null, timeEnd: null });
    }
  }
  setInputPlaceholderText() {
    if (this.placeholder) {
      this.inputPlaceholder = this.placeholder;
    }
    else {
      if (this.hide === 'time') {
        this.inputPlaceholder = translate('setDate');
        if (this.rangeDateTime) {
          this.inputPlaceholder += ' ' + translate('range');
        }
      }
      else if (this.hide === 'calendar') {
        this.inputPlaceholder = translate('setTime');
        if (this.rangeDateTime) {
          this.inputPlaceholder += ' ' + translate('range');
        }
      }
      else {
        this.inputPlaceholder = translate('setDateTime');
        if (this.rangeDateTime) {
          this.inputPlaceholder = translate('setRange');
        }
      }
    }
  }
  save() {
    var _a;
    if (!this.overlayHandler.isReady()) {
      return;
    }
    this.overlayHandler.hide();
    this.overlayVisible = false;
    (_a = this.overlayHandler.dialog) === null || _a === void 0 ? void 0 : _a.closeYearMonthSelection();
    if (this.dateTimePickerInput.value.trim().length === 0) {
      this.setInputPlaceholderText();
    }
    if (this.rangeDateTime && !this.dateTimePickerInputObj.dateEnd) {
      this.dateTimePickerInputObj.dateEnd = this.dateTimePickerInputObj.dateStart;
    }
    if (this.hide === 'calendar' && !this.dateTimePickerInputObj.timeStart) {
      this.dateTimePickerInputObj.timeStart = this.dateTimePickerInputObj.timeEnd;
    }
    this.correctData();
    const timestampStart = this.dateService.toSelectionTimestamp(this.dateTimePickerInputObj.dateStart, this.dateTimePickerInputObj.timeStart);
    const timestampEnd = this.dateService.toSelectionTimestamp(this.dateTimePickerInputObj.dateEnd, this.dateTimePickerInputObj.timeEnd);
    this.dateTimePickerInputObj = Object.assign(Object.assign({}, this.dateTimePickerInputObj), { timestampStart: timestampStart !== null && timestampStart !== void 0 ? timestampStart : null, timestampEnd: timestampEnd !== null && timestampEnd !== void 0 ? timestampEnd : null });
    this.updateDatePickerInput();
    if (!this.showTemplates) {
      this.selectedTemplateId = '';
    }
    this.newDateSelected.emit(this.dateTimePickerInputObj);
  }
  isNull() {
    return (this.dateTimePickerInputObj.dateStart === null &&
      this.dateTimePickerInputObj.dateEnd === null &&
      this.dateTimePickerInputObj.timeStart === null &&
      this.dateTimePickerInputObj.timeEnd === null);
  }
  handleSelectionChanged(event) {
    event.stopPropagation();
    switch (event.detail.reason) {
      case 'date':
        this.showTemplates = false;
        this.handleDateChange(event.detail);
        break;
      case 'time':
        this.showTemplates = false;
        this.handleTimeChange(event.detail);
        break;
      case 'frame':
        this.showTemplates = true;
        this.handleRangeChange(event.detail);
        break;
    }
    this.updateDatePickerInput();
  }
  handleDateChange({ startDate: dateStart, endDate: dateEnd, rangeCompleted }) {
    this.dateTimePickerInputObj = Object.assign(Object.assign({}, this.dateTimePickerInputObj), { dateStart, dateEnd: dateEnd !== null && dateEnd !== void 0 ? dateEnd : null });
    if (this.hide === 'time') {
      if (!this.rangeDateTime || (this.rangeDateTime && rangeCompleted)) {
        this.save();
      }
    }
  }
  handleTimeChange(newTimes) {
    this.dateTimePickerInputObj = Object.assign(Object.assign({}, this.dateTimePickerInputObj), newTimes);
  }
  handleRangeChange(event) {
    var _a, _b;
    if (event.firstEmit) {
      this.selectedTemplateId = event.id;
    }
    const timestampStart = (_a = this.dateService.toSelectionTimestamp(this.formatService.formatDate(event.timestampStart), this.formatService.formatTime(event.timestampStart))) !== null && _a !== void 0 ? _a : null;
    const timestampEnd = (_b = this.dateService.toSelectionTimestamp(this.formatService.formatDate(event.timestampEnd), this.formatService.formatTime(event.timestampEnd))) !== null && _b !== void 0 ? _b : null;
    this.dateTimePickerInputObj = Object.assign(Object.assign({}, this.dateTimePickerInputObj), { dateStart: this.formatService.formatDate(event.timestampStart), dateEnd: this.formatService.formatDate(event.timestampEnd), timeStart: this.formatService.formatTime(event.timestampStart), timeEnd: this.formatService.formatTime(event.timestampEnd), timestampStart,
      timestampEnd });
    if (this.overlayHandler.isReady()) {
      this.newDateSelected.emit(this.dateTimePickerInputObj);
    }
    if (event.firstEmit) {
      this.hideOverlay();
    }
    this.updateDatePickerInput();
  }
  hideOverlay() {
    this.updateDatePickerInput();
    this.overlayHandler.hide();
    this.overlayVisible = false;
  }
  render() {
    return (h(Host, { ref: (el) => (this.datepickerRef = el) },
      h("div", { class: { 'bci-core-datetime-picker': true, 'form-group': true, 'dark-background': !!this.darkBackground }, id: this.dateTimePickerId, ref: (el) => (this.overlayHandler.host = el) },
        h("input", { "data-test": "webcore.webcomponents.datetime-picker.core-datetime-picker.input-field", id: this.dateTimePickerId + '-input', class: { 'input-field': true, invalid: !this.dateTimePickerInputObj.valid, 'has-label': !!this.label }, type: "text", ref: (el) => (this.dateTimePickerInput = el), onFocus: () => this.showPickerContainer(), onInput: (event) => this.updateDatePickerComponent(event), placeholder: this.inputPlaceholder, disabled: this.disabled, value: "" }),
        h("label", { class: "label-top" }, this.label),
        !this.overlayVisible ? (h("div", { class: "icon", "data-test": "webcore.webcomponents.datetime-picker.core-datetime-picker.toggle-picker", onClick: () => this.dateTimePickerInput.focus(), title: "Open" },
          h("span", { class: `bosch-ic bci-core-calendar-icon bosch-ic-clickable bosch-ic-${this.openingIcon} has-label` }))) : this.dateTimePickerInput.value.trim() ? (h("div", { class: "icon", "data-test": "webcore.webcomponents.datetime-picker.core-datetime-picker.reset-picker", onClick: async () => {
            await this.resetSelection();
            this.dateTimePickerInput.focus();
          }, title: "Clear" },
          h("span", { class: "bosch-ic bci-core-calendar-icon bosch-ic-clickable bosch-ic-delete has-label" }))) : (h("div", { class: "icon", "data-test": "webcore.webcomponents.datetime-picker.core-datetime-picker.toggle-picker", onClick: () => this.toggle(), title: "Close" },
          h("span", { class: "bosch-ic bci-core-calendar-icon bosch-ic-clickable bosch-ic-close-small has-label" })))),
      h("bci-overlay", { ref: (el) => (this.overlayHandler.overlay = el) },
        h("bci-datetime-dialog", { ref: (el) => (this.overlayHandler.dialog = el), dateTimePickerId: this.dateTimePickerId, onSelectionChanged: (timeStamp) => this.handleSelectionChanged(timeStamp), toggleDialogHandler: () => this.toggle(), hide: this.hide, templatesList: this.templatesList, datePickerConfig: this.datePickerConfig, timePickerConfig: this.timePickerConfig, datePickerInputObj: this.dateTimePickerInputObj, formatService: this.formatService, dateService: this.dateService, templatesDisabled: this.templatesDisabled }))));
  }
  static get is() { return "bci-datetime-picker"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["datetime-picker.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["datetime-picker.css"]
  }; }
  static get properties() { return {
    "label": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Label of the datepicker input field."
      },
      "attribute": "label",
      "reflect": false,
      "defaultValue": "''"
    },
    "placeholder": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Placeholder of the datepicker input field."
      },
      "attribute": "placeholder",
      "reflect": false,
      "defaultValue": "''"
    },
    "dateTimePickerId": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Id of the datepicker."
      },
      "attribute": "date-time-picker-id",
      "reflect": false
    },
    "formatDate": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Format of the date."
      },
      "attribute": "format-date",
      "reflect": false,
      "defaultValue": "'dd.MM.yyyy'"
    },
    "maxDate": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The max date that should be selectable."
      },
      "attribute": "max-date",
      "reflect": false,
      "defaultValue": "20000000000000"
    },
    "minDate": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The min date that should be selectable."
      },
      "attribute": "min-date",
      "reflect": false,
      "defaultValue": "0"
    },
    "hideTime": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "deprecated",
            "text": "Use hide property instead."
          }],
        "text": "Whether the timepicker should be hidden."
      },
      "attribute": "hide-time",
      "reflect": false
    },
    "hide": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'calendar' | 'time'",
        "resolved": "\"calendar\" | \"time\"",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [{
            "name": "type",
            "text": " 'calendar' | 'time'"
          }],
        "text": "Which parts of the datepicker should be hidden"
      },
      "attribute": "hide",
      "reflect": false
    },
    "templatesList": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Array<Template | TemplateGroup>",
        "resolved": "(Template | TemplateGroup)[]",
        "references": {
          "Array": {
            "location": "global"
          },
          "Template": {
            "location": "import",
            "path": "./datetime-picker.interface"
          },
          "TemplateGroup": {
            "location": "import",
            "path": "./datetime-picker.interface"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "A list of templates that are selectable. If there are no templates provided, the \"Templates\"-Button will not be shown."
      }
    },
    "templatesDisabled": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Whether the \"Templates\"-Button should be disabled."
      },
      "attribute": "templates-disabled",
      "reflect": false
    },
    "sundayFirst": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Whether should be the first day of the week in the calendar."
      },
      "attribute": "sunday-first",
      "reflect": false
    },
    "rangeDateTime": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Whether a range should be selectable."
      },
      "attribute": "range-date-time",
      "reflect": false
    },
    "disabled": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Whether the datepicker should be disabled."
      },
      "attribute": "disabled",
      "reflect": false
    },
    "darkBackground": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "dark-background",
      "reflect": false
    },
    "timeFormat": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "TimePickerTimeFormat",
        "resolved": "\"H:mm\" | \"HH:mm:ss\" | \"hh:mm a\" | \"hh:mm:ss a\"",
        "references": {
          "TimePickerTimeFormat": {
            "location": "import",
            "path": "./model"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "please use timeFormat 'H:mm'(hours and minutes) or 'hh:mm a'(hours and minutes with AM/PM) or 'hh:mm:ss a(hours,minutes,seconds with AM/PM)',for the date range picker"
      },
      "attribute": "time-format",
      "reflect": false,
      "defaultValue": "'H:mm'"
    },
    "timeZone": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "time-zone",
      "reflect": false
    },
    "dateTime": {
      "type": "unknown",
      "mutable": true,
      "complexType": {
        "original": "DateTime",
        "resolved": "DateTime",
        "references": {
          "DateTime": {
            "location": "import",
            "path": "./datetime-picker.interface"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      }
    },
    "timeStamp": {
      "type": "unknown",
      "mutable": true,
      "complexType": {
        "original": "TimeStamp",
        "resolved": "TimeStamp",
        "references": {
          "TimeStamp": {
            "location": "import",
            "path": "./datetime-picker.interface"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      }
    }
  }; }
  static get states() { return {
    "dateTimePickerInputObj": {},
    "formatTime": {},
    "inputPlaceholder": {},
    "datePickerConfig": {},
    "timePickerConfig": {},
    "hideSeconds": {},
    "overlayVisible": {}
  }; }
  static get events() { return [{
      "method": "newDateSelected",
      "name": "newDateSelected",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Event emitted when the datetime picker dropdown is closed via the enter key,\ntab key on last input field.\nValue emitted is the string from the main input field"
      },
      "complexType": {
        "original": "DateTime",
        "resolved": "DateTime",
        "references": {
          "DateTime": {
            "location": "import",
            "path": "./datetime-picker.interface"
          }
        }
      }
    }]; }
  static get methods() { return {
    "toggle": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "",
        "tags": []
      }
    },
    "resetSelection": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "Function to reset the datepicker's selection",
        "tags": []
      }
    }
  }; }
  static get watchers() { return [{
      "propName": "dateTime",
      "methodName": "onDateTimeChanged"
    }, {
      "propName": "timeStamp",
      "methodName": "onTimeStampChanged"
    }, {
      "propName": "placeholder",
      "methodName": "onPlaceholderChanged"
    }]; }
  static get listeners() { return [{
      "name": "OverlayOpenedEvent",
      "method": "updatePlaceholderOnOverlayOpenedEvent",
      "target": "document",
      "capture": false,
      "passive": false
    }, {
      "name": "mousedown",
      "method": "handleMouseDown",
      "target": "document",
      "capture": false,
      "passive": true
    }, {
      "name": "touchstart",
      "method": "handleTouchStart",
      "target": "document",
      "capture": false,
      "passive": true
    }, {
      "name": "keydown",
      "method": "handleEscape",
      "target": "document",
      "capture": false,
      "passive": false
    }, {
      "name": "keydown",
      "method": "handleTab",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "keydown",
      "method": "handleEnter",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "show",
      "method": "showPickerContainer",
      "target": undefined,
      "capture": false,
      "passive": false
    }]; }
}

