/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
import { clamp, endOfDay, getUnixTime, isAfter, isBefore, parse, startOfDay } from 'date-fns';
import { zonedTimeToUtc } from 'date-fns-tz';
import { formattingServiceFactory } from './formatting-service';
/**
 * This config is used when no config was provided to the dateServiceFactory function
 */
export const defaultDateConfig = {
  formatService: formattingServiceFactory(),
  rangeDateTime: false,
  hideSeconds: false,
  minDate: 0,
  maxDate: 0,
};
const FORMAT_BLOCKS = {
  dd: /(0[1-9]|[12][0-9]|3[01])/,
  MM: /(0[1-9]|1[0-2])/,
  yy: /([0-9]{2})/,
  d: /([1-9]|[12][0-9]|3[01])/,
  M: /([1-9]|1[0-2])/,
  y: /([12][0-9]{3})/,
  h: /(0?[0-9]|1[0-2])/,
  H: /(0?[0-9]|[1][0-9]|2[0-3])/,
  mm: /([0-5][0-9])/,
  ss: /([0-5][0-9])/,
  ' a': /( [AaPp][Mm])/,
};
/** All the date formats that can be parsed from a string */
const SUPPORTED_DATE_FORMATS_DEFAULT = [
  'dd.MM.y',
  'MM/dd/y',
  'dd/MM/y',
  'y-MM-dd',
  'd.M.y',
  'M/d/y',
  'd/M/y',
  'y-M-d',
  'dd.MM.yy',
  'MM/dd/yy',
  'dd/MM/yy',
  'yy-MM-dd',
  'd.M.yy',
  'M/d/yy',
  'd/M/yy',
  'yy-M-d',
];
/** All the date formats that can be parsed from a string. Prioritising "/"-Formats, where Days are before Months */
const SUPPORTED_DATE_FORMATS_START_WITH_DAY = [
  'dd.MM.y',
  'dd/MM/y',
  'dd.MM.yy',
  'dd/MM/yy',
  'MM/dd/y',
  'MM/dd/yy',
  'y-MM-dd',
  'd.M.y',
  'd/M/y',
  'M/d/y',
  'y-M-d',
  'yy-MM-dd',
  'd.M.yy',
  'd/M/yy',
  'M/d/yy',
  'yy-M-d',
];
/** All the time formats that can be parsed from a string */
const SUPPORTED_TIME_FORMATS = ['h:mm:ss a', 'H:mm:ss', 'h:mm a', 'H:mm', 'h a'];
/**
 * Uses the defaultDateConfig if no value is provided
 * @param config
 * @returns
 */
export function dateServiceFactory(config = {}) {
  const { hideSeconds, rangeDateTime, minDate, maxDate, formatService } = Object.assign(Object.assign({}, defaultDateConfig), config);
  return new DateService(hideSeconds, rangeDateTime, minDate, maxDate, formatService);
}
/**
 * Used to manipulate date values
 */
export class DateService {
  constructor(hideSeconds, rangeDateTime, minDate, maxDate, formatService) {
    this.hideSeconds = hideSeconds;
    this.rangeDateTime = rangeDateTime;
    this.minDate = minDate;
    this.maxDate = maxDate;
    this.formatService = formatService;
  }
  getTodayValue(timeZone = undefined) {
    return timeZone === undefined ? new Date() : new Date(new Date().toLocaleString('en-US', { timeZone: timeZone }));
  }
  getDataFromInput(input) {
    const dates = this.getDateFromDateInput(input);
    const times = this.getTimeFromDateInput(input);
    const correctedData = this.correctInputData(Object.assign(Object.assign({}, dates), times));
    return Object.assign(Object.assign({}, correctedData), { valid: true });
  }
  /**
   * check whether the input contains valid date and time values and that they are also in the correct time order.
   * @param input
   * @returns
   */
  validateInput(input) {
    const dateStart = startOfDay(this.formatService.formatDateToDate(input.dateStart || ''));
    const dateEnd = startOfDay(this.formatService.formatDateToDate(input.dateEnd || ''));
    if (isAfter(dateStart, endOfDay(this.maxDate)) ||
      isBefore(dateStart, startOfDay(this.minDate)) ||
      isAfter(dateEnd, endOfDay(this.maxDate)) ||
      isBefore(dateEnd, startOfDay(this.minDate)) ||
      isAfter(dateStart, dateEnd)) {
      return { valid: false, timeEnd: null, dateEnd: null };
    }
    else {
      return { valid: true };
    }
  }
  /**
   * Corrects date values, puts them within allowed ranges and swaps values if necessary.
   * @param dateObj dateStart, dateEnd, timeStart, timeEnd
   * @returns corrected dateStart, dateEnd, timeStart, timeEnd
   */
  correctInputData(dateObj) {
    const { dateStart, dateEnd, timeStart, timeEnd } = dateObj;
    let parsedDateStart, parsedDateEnd;
    // Case with only one date and two times
    if (!!dateStart && !!timeStart && !!timeEnd && !dateEnd) {
      parsedDateStart = this.dateWithinAllowedRange(this.formatService.formatDateWithOptionalTime(dateStart, timeStart));
      parsedDateEnd = this.dateWithinAllowedRange(this.formatService.formatDateWithOptionalTime(dateStart, timeEnd));
      if (isBefore(parsedDateEnd, parsedDateStart)) {
        return Object.assign({}, this.createInputData(parsedDateEnd, parsedDateStart));
      }
    }
    // Case when nothing valid was entered into the input
    else if (!dateStart || !dateEnd) {
      return dateObj;
    }
    // Base case
    else {
      parsedDateStart = this.dateWithinAllowedRange(this.formatService.formatDateWithOptionalTime(dateStart, timeStart));
      parsedDateEnd = this.dateWithinAllowedRange(this.formatService.formatDateWithOptionalTime(dateEnd, timeEnd));
      if (isBefore(parsedDateEnd, parsedDateStart)) {
        return Object.assign({}, this.createInputData(parsedDateEnd, parsedDateStart));
      }
    }
    return Object.assign({}, this.createInputData(parsedDateStart, parsedDateEnd));
  }
  dateWithinAllowedRange(date) {
    return clamp(date, {
      start: this.formatService.timestampToZonedTime(this.minDate / 1000),
      end: this.maxDate === 0 ? Infinity : this.formatService.timestampToZonedTime(this.maxDate / 1000),
    });
  }
  /**
   * Creates valid InputData object from two dates.
   * @param dateStart Date to infer dateStart and timeStart from
   * @param dateEnd Date to infer dateEnd and timeEnd from
   */
  createInputData(dateStart, dateEnd) {
    return {
      dateStart: this.formatService.formatDate(dateStart),
      dateEnd: this.formatService.formatDate(dateEnd) || null,
      timeStart: this.formatService.formatTime(dateStart),
      timeEnd: this.formatService.formatTime(dateEnd) || null,
    };
  }
  /**
   * Returns utc timestamp created by timezone from property time-zone or with local browser timezone
   * @param date string parsed with formatDate
   * @param time string in format 00:00
   */
  toSelectionTimestamp(date, time) {
    if (!date || !this.formatService.timeZone) {
      return undefined;
    }
    const dateTime = this.formatService.formatDateWithOptionalTime(date, time);
    return getUnixTime(zonedTimeToUtc(dateTime, this.formatService.timeZone)) * 1000;
  }
  getDateFromDateInput(input) {
    const matches = this.getPartFromDateInput(input, 'dateStart', 'dateEnd', this.DATE_FORMATS);
    const result = { dateStart: null, dateEnd: null };
    result.dateStart = matches.dateStart ? this.formatService.formatDate(matches.dateStart) : null;
    result.dateEnd = matches.dateEnd ? this.formatService.formatDate(matches.dateEnd) : null;
    return result;
  }
  getTimeFromDateInput(input) {
    const matches = this.getPartFromDateInput(input, 'timeStart', 'timeEnd', this.TIME_FORMATS);
    const result = { timeStart: null, timeEnd: null };
    result.timeStart = matches.timeStart ? this.formatService.formatTime(matches.timeStart) : null;
    result.timeEnd = matches.timeEnd ? this.formatService.formatTime(matches.timeEnd) : null;
    return result;
  }
  getPartFromDateInput(input, startKey, endKey, tests) {
    var _a, _b;
    let match;
    let countMatches = 0;
    const dateObj = {
      [startKey]: null,
      [endKey]: null,
    };
    const result = {
      [startKey]: null,
      [endKey]: null,
    };
    Object.keys(tests).forEach((key) => {
      var _a;
      const pattern = tests[key];
      // Match time input
      while ((match = pattern.exec(input)) !== null) {
        // This is necessary to avoid infinite loops with zero-width matches
        if (match.index === pattern.lastIndex) {
          pattern.lastIndex++;
        }
        if (match[0] !== null && match.index !== ((_a = dateObj[startKey]) === null || _a === void 0 ? void 0 : _a.atIndex)) {
          countMatches++;
          if (countMatches >= 3)
            break;
          if (this.rangeDateTime && countMatches === 2) {
            dateObj[endKey] = { match: match[0], fromFormat: key, atIndex: match.index };
          }
          else {
            // only match first date
            if (countMatches >= 2)
              break;
            dateObj[startKey] = { match: match[0], fromFormat: key, atIndex: match.index };
          }
        }
      }
    });
    // parse to a normal date as the matches can be from different formats
    if (!!dateObj[endKey]) {
      const { match, fromFormat } = dateObj[endKey];
      const normalizedDate = parse(match, fromFormat, new Date());
      result[endKey] = normalizedDate;
    }
    if (!!dateObj[startKey]) {
      const { match, fromFormat } = dateObj[startKey];
      const normalizedDate = parse(match, fromFormat, new Date());
      result[startKey] = normalizedDate;
    }
    // Swap dates if match found later is before other match in the input string.
    // This happens if match before is from a format that gets searched later.
    if (((_a = dateObj[startKey]) === null || _a === void 0 ? void 0 : _a.atIndex) > ((_b = dateObj[endKey]) === null || _b === void 0 ? void 0 : _b.atIndex)) {
      const temp = result[startKey];
      result[startKey] = result[endKey];
      result[endKey] = temp;
    }
    return result;
  }
  get DATE_FORMATS() {
    var _a, _b;
    const formats = {};
    const DATE_FORMATS = ((_a = this.formatService.dateFormat) === null || _a === void 0 ? void 0 : _a.toLowerCase().startsWith('dd/')) || ((_b = this.formatService.dateFormat) === null || _b === void 0 ? void 0 : _b.toLowerCase().startsWith('d/'))
      ? SUPPORTED_DATE_FORMATS_START_WITH_DAY
      : SUPPORTED_DATE_FORMATS_DEFAULT;
    DATE_FORMATS.forEach((format) => {
      let regex = format;
      ['.', '/', '-'].forEach((symbol) => {
        regex = regex.replace(new RegExp(`[${symbol}]`, 'g'), `[${symbol}]`);
      });
      Object.keys(FORMAT_BLOCKS).forEach((block) => {
        regex = regex.replace(new RegExp(block, 'g'), FORMAT_BLOCKS[block].source);
      });
      formats[format] = new RegExp(regex, 'g');
    });
    return formats;
  }
  get TIME_FORMATS() {
    const formats = {};
    SUPPORTED_TIME_FORMATS.map((format) => {
      let regex = format;
      [':'].forEach((symbol) => {
        regex = regex.replace(new RegExp(`[${symbol}]`, 'g'), `[${symbol}]`);
      });
      Object.keys(FORMAT_BLOCKS).forEach((block) => {
        regex = regex.replace(new RegExp(block, 'g'), FORMAT_BLOCKS[block].source);
      });
      formats[format] = new RegExp(regex, 'g');
    });
    return formats;
  }
}

