/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
import { format, fromUnixTime, parse } from 'date-fns';
import { utcToZonedTime } from 'date-fns-tz';
import { DEFAULT_LOCALE } from '../../../utils/localization';
/**
 * is used in the formattingServiceFactory if no valid is provided
 */
export const defaultFactoryConfig = {
  dateFormat: DEFAULT_LOCALE.dateFormat,
  timeFormat: DEFAULT_LOCALE.timeFormat,
};
/**
 * Uses the defaultFactoryConfig if nothing was provided
 * @param config
 * @returns
 */
export function formattingServiceFactory(config = {}) {
  const { dateFormat, timeFormat, timeZone } = Object.assign(Object.assign({}, defaultFactoryConfig), config);
  return new FormattingService(dateFormat, timeFormat, timeZone);
}
/**
 * Used to format date values
 */
export class FormattingService {
  constructor(dateFormat, timeFormat, timeZone) {
    this.dateFormat = dateFormat;
    this.timeFormat = timeFormat;
    this.timeZone = timeZone;
  }
  /**
   * Returns date in any format with utc timezone set by property time-zone or with local browser timezone
   * @param date
   * @returns
   */
  formatDate(date) {
    if (!date) {
      return '';
    }
    if (typeof date === 'number') {
      return this.formatNumber(date, this.dateFormat);
    }
    if (typeof date === 'string') {
      return format(this.formatDateToDate(date), this.dateFormat);
    }
    return format(date, this.dateFormat);
  }
  formatDateToDate(date) {
    return parse(date, this.dateFormat, new Date());
  }
  /**
   * Returns time in any format with utc timezone set by property time-zone or with local browser timezone
   * @param time
   * @returns
   */
  formatTime(time) {
    if (!time) {
      return '';
    }
    if (typeof time === 'number') {
      return this.formatNumber(time, this.timeFormat);
    }
    return format(time, this.timeFormat);
  }
  /**
   * Formats a date/time range for display
   * @param {string} [dateStart] - The start date
   * @param {string} [dateEnd] - The end date
   * @param {string} [timeStart] - The start time
   * @param {string} [timeEnd] - The end time
   * @returns {string} The formatted date/time range string
   */
  formatRange(dateStart, dateEnd, timeStart, timeEnd) {
    let value = '';
    if (dateStart) {
      value += dateStart;
    }
    if (dateStart && timeStart) {
      value += ' ';
    }
    if (timeStart) {
      value += timeStart;
    }
    if ((dateStart && dateEnd && dateEnd !== dateStart) || (timeStart && timeEnd && timeEnd !== timeStart)) {
      value += ' – ';
    }
    if (dateEnd && dateEnd !== dateStart) {
      value += dateEnd;
    }
    if (dateEnd && timeEnd && dateEnd !== dateStart) {
      value += ' ';
    }
    if (timeEnd && (timeStart !== timeEnd || dateStart !== dateEnd)) {
      value += timeEnd;
    }
    return value;
  }
  formatDateWithOptionalTime(date, time) {
    const dateString = time ? date + ' ' + time : date;
    const format = time ? this.dateFormat + ' ' + this.timeFormat : this.dateFormat;
    return parse(dateString, format, new Date());
  }
  timestampToZonedTime(timestamp) {
    if (this.timeZone) {
      return utcToZonedTime(fromUnixTime(timestamp), this.timeZone);
    }
    return fromUnixTime(timestamp);
  }
  formatNumber(timestamp, formatting) {
    return format(this.timestampToZonedTime(timestamp / 1000), formatting);
  }
}

