/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
/*
 * Copyright (C) 2020 Robert Bosch GmbH Copyright (C) 2020 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.
 */
import { Component, Host, h, Prop, State, Event, Element, Watch, forceUpdate } from '@stencil/core';
import { isResponsiveMode, translate } from '../../utils/utils';
import { setLocale } from '../../utils/locale-store';
export class FacilitySelector {
  constructor() {
    this.darkBackground = false;
    this.enableMultiSelection = false;
    this.displayRecentSearches = false;
    this.activeLevel = 0;
    this.columns = [];
    this.columnsExpanded = false;
    this.recentSearchesExpanded = false;
    this.searchString = '';
    this.ColumnSearchInputElement = () => (h("bci-facility-search-input", { searchString: this.searchString, darkBackground: this.darkBackground, isColumnExpanded: this.columnsExpanded, facilitySelectorController: this.facilitySelectorController, onSearch: (event) => this.handleSearch(event), onColumnInputExpanded: (event) => this.toggleColumnDisplay(event.detail), onBreadcrumbItemClicked: (event) => this.goToLevel(event.detail) }));
    this.ColumnListElement = ({ list, index }) => (h("bci-column-list", { list: list, selectedId: this.getSelectedItemAtLevel(index) ? this.getSelectedItemAtLevel(index).id : null, facilitySelectorController: this.facilitySelectorController, onColumnItemSelected: (event) => this.handleItemSelected(event, index), onColumnItemChecked: (event) => this.handleItemChecked(event, index) }));
    this.ColumnSearchResultElement = () => (h("bci-facility-search-result", { searchString: this.searchString, searchResults: this.searchResults, facilitySelectorController: this.facilitySelectorController, onSearchResultSelected: (event) => this.handleSearchResultSelected(event), onSearchResultChecked: (event) => this.handleSearchResultChecked(event) }));
    this.RecentSearchesElement = () => this.displayRecentSearches && (h("bci-facility-recent-search", { expanded: this.recentSearchesExpanded, recentSearchController: this.recentSearchController, onRecentSearchSelected: (event) => this.handleRecentSearchSelected(event) }));
  }
  onCheckedItemsSet() {
    if (!this.facilitySelectorController.isStateSet) {
      this.facilitySelectorController.setDefaultState(this.checkedItems);
    }
    else {
      this.facilitySelectorController.checkAll(this.checkedItems);
    }
  }
  async componentWillLoad() {
    await setLocale();
    this.initializeSelector();
  }
  componentDidRender() {
    const columnListElements = this.getColumnListElements();
    this.scrollIntoViewElement(columnListElements[columnListElements.length - 1]);
  }
  initializeSelector() {
    if (this.facilitySelectorController) {
      this.facilitySelectorController.initialize(this.checkedItems);
      this.facilitySelectorController.enableMultiSelection(this.enableMultiSelection);
      this.facilitySelectorController.onChange(() => {
        this.updateActiveLevel();
        this.updateColumns();
        this.updateChildElements();
      });
    }
  }
  getColumnListElements() {
    return this.el.shadowRoot.querySelectorAll('bci-column-list') || [];
  }
  getSearchInputElement() {
    return this.el.shadowRoot.querySelector('bci-facility-search-input');
  }
  getSearchResultsElement() {
    return this.el.shadowRoot.querySelector('bci-facility-search-result');
  }
  getColumnItemsAtLevel(level) {
    return this.facilitySelectorController.getColumnAtLevel(level) || [];
  }
  getSelectedItemAtLevel(level) {
    return this.facilitySelectorController.selectionState.getSelectedItemAtLevel(level);
  }
  updateActiveLevel() {
    this.activeLevel = (this.facilitySelectorController.getColumns() || []).length - 1;
  }
  updateColumns() {
    this.columns = [...(this.facilitySelectorController.getColumns() || [])] || [];
  }
  updateChildElements() {
    const columnListElement = this.getColumnListElements();
    const searchElement = this.getSearchInputElement();
    const searchResultsElement = this.getSearchResultsElement();
    if (columnListElement) {
      columnListElement.forEach((element) => element.markCheckedItems());
    }
    if (searchElement) {
      forceUpdate(searchElement);
    }
    if (searchResultsElement) {
      searchResultsElement.markCheckedItems();
    }
  }
  handleItemSelected({ detail }, levelIndex) {
    if (!detail || !detail.item) {
      return;
    }
    this.clearSearch();
    const { item, isSelectedOrChecked } = detail;
    if (isSelectedOrChecked) {
      this.facilitySelectorController.selectNode(item, levelIndex);
    }
    else {
      this.facilitySelectorController.deSelectNode(item, levelIndex);
    }
  }
  handleItemChecked({ detail }, levelIndex) {
    if (!detail || !detail.item) {
      return;
    }
    const { item, isSelectedOrChecked } = detail;
    if (isSelectedOrChecked) {
      this.facilitySelectorController.checkNode(item, levelIndex);
    }
    else {
      this.facilitySelectorController.uncheckNode(item, levelIndex);
    }
  }
  handleSearch({ detail: searchString }) {
    if (!searchString || !searchString.trim()) {
      this.clearSearch();
      return;
    }
    this.columnsExpanded = true;
    this.searchString = searchString.trim();
    this.facilitySelectorController
      .search({
      searchRoot: this.getSelectedItemAtLevel(this.activeLevel - 1),
      searchString: this.searchString,
    })
      .then((result) => {
      this.searchResults = result;
    });
  }
  handleSearchResultSelected({ detail }) {
    const selectedSearchResult = detail.item;
    const searchRoot = this.getSelectedItemAtLevel(this.activeLevel - 1);
    this.facilitySelectorController.selectSearchResult(selectedSearchResult, searchRoot).then(() => {
      this.clearSearch();
      this.updateColumns();
      this.updateChildElements();
      this.updateActiveLevel();
    });
  }
  handleSearchResultChecked({ detail }) {
    this.facilitySelectorController.checkSearchResult(detail.isSelectedOrChecked, detail.item);
  }
  handleRecentSearchSelected({ detail: recentSearchItem }) {
    this.reset();
    this.facilitySelectorController.selectRecentSeachItem(recentSearchItem);
  }
  handleSave() {
    if (this.displayRecentSearches && this.recentSearchController) {
      const checkedItemsByLevel = [];
      for (let i = 0; i < this.facilitySelectorController.selectionState.checkedItemPerLevel.length; i++) {
        checkedItemsByLevel.push(this.facilitySelectorController.selectionState.checkedItemPerLevel[i] || []);
      }
      this.recentSearchController.addRecentSearch({
        checkedItemsByLevel,
      });
    }
    this.clearSearch();
    this.toggleColumnDisplay(false, false);
    this.facilitySelectorController.updateDefaultState();
    this.save.emit(this.facilitySelectorController.selectionState.checkedItemList);
  }
  toggleColumnDisplay(expand, resetState = true) {
    this.columnsExpanded = expand;
    if (!expand && resetState) {
      this.facilitySelectorController.resetToDefaultState();
      this.clearSearch();
    }
  }
  goToLevel(level) {
    if (isResponsiveMode() && level >= 0 && this.facilitySelectorController.getColumns) {
      this.activeLevel = level;
    }
  }
  scrollIntoViewElement(element) {
    if (!element || !element.scrollIntoView) {
      return;
    }
    element.scrollIntoView({ behavior: 'smooth', block: 'nearest', inline: 'center' });
  }
  reset() {
    this.facilitySelectorController.reset();
    this.clearSearch();
  }
  clearSearch() {
    this.searchString = '';
    this.searchResults = null;
  }
  render() {
    return (h(Host, { class: this.darkBackground ? 'dark-background' : '' },
      h(this.ColumnSearchInputElement, null),
      this.columnsExpanded && (h("div", { class: `bci-portal-facility-collapsible ${this.columnsExpanded ? '' : 'collapsed'}` },
        h("div", { class: "bci-portal-column-container" }, isResponsiveMode() ? (h("div", { class: "responsive-container" },
          h("div", { class: "responsive-list" },
            !this.searchResults && this.activeLevel !== 0 && (h("div", { "data-test": "webcore.webcomponents.facility-selector.bci-portal-facility-back-button", class: "back-button", onClick: () => this.goToLevel(this.activeLevel - 1) },
              h("span", { class: "bosch-ic bosch-ic-small bosch-ic-back-left bosch-ic-clickable" }),
              translate('back'))),
            h(this.ColumnListElement, { list: this.getColumnItemsAtLevel(this.activeLevel), index: this.activeLevel })),
          this.searchResults && h(this.ColumnSearchResultElement, null))) : (this.facilitySelectorController.hasColumns() && (h("div", { class: "list-container" },
          this.columns.map((list, index) => this.searchResults && index === this.columns.length - 1 ? ('') : (h(this.ColumnListElement, { list: list, index: index }))),
          this.searchResults && h(this.ColumnSearchResultElement, null))))),
        h(this.RecentSearchesElement, null),
        h("div", { class: "bci-portal-save-button-container" },
          h("button", { "data-test": "webcore.webcomponents.facility-selector.bci-portal-reset-button", class: "button-link no-arrow reset", onClick: () => this.reset() }, translate('reset')),
          h("button", { "data-test": "webcore.webcomponents.facility-selector.bci-portal-save-button", class: "button-link no-arrow save", onClick: () => this.handleSave() }, translate('save')))))));
  }
  static get is() { return "bci-facility-selector"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["facility-selector.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["facility-selector.css"]
  }; }
  static get properties() { return {
    "checkedItems": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Facility[]",
        "resolved": "Facility[]",
        "references": {
          "Facility": {
            "location": "import",
            "path": "./facility.interface"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      }
    },
    "darkBackground": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "dark-background",
      "reflect": false,
      "defaultValue": "false"
    },
    "enableMultiSelection": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "enable-multi-selection",
      "reflect": false,
      "defaultValue": "false"
    },
    "displayRecentSearches": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "display-recent-searches",
      "reflect": false,
      "defaultValue": "false"
    },
    "facilitySelectorController": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "FacilitySelectorController",
        "resolved": "FacilitySelectorController",
        "references": {
          "FacilitySelectorController": {
            "location": "import",
            "path": "../.."
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      }
    },
    "recentSearchController": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "RecentSearchController",
        "resolved": "RecentSearchController",
        "references": {
          "RecentSearchController": {
            "location": "import",
            "path": "../.."
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      }
    }
  }; }
  static get states() { return {
    "activeLevel": {},
    "columns": {},
    "columnsExpanded": {},
    "recentSearchesExpanded": {},
    "searchString": {},
    "searchResults": {}
  }; }
  static get events() { return [{
      "method": "save",
      "name": "save",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "string[]",
        "resolved": "string[]",
        "references": {}
      }
    }]; }
  static get elementRef() { return "el"; }
  static get watchers() { return [{
      "propName": "checkedItems",
      "methodName": "onCheckedItemsSet"
    }]; }
}

