/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
/*
 * Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.
 */
import { Component, h, Listen, Prop, State, Event } from '@stencil/core';
import { translate } from '../../utils/utils';
import Fuzzysort from 'fuzzysort';
import { setLocale } from '../../utils/locale-store';
export class HeaderIconSearch {
  constructor() {
    this.searchList = [];
    this.searchOptions = {
      key: 'searchItem',
      allowTypo: true,
      limit: 5,
    };
    this.thresholdScoreLimit = -2000; // A score of 0 indicates a perfect match. Lesser the score worse the match.
    this.hasTypo = false;
    this.navigationItems = [];
    this.showSearchInput = false;
    this.searchResults = [];
  }
  async componentWillLoad() {
    await setLocale();
    this.searchList = this.getSearchList(this.navigationItems);
  }
  handleKeyDown(ev) {
    if (ev.key === 'Escape') {
      this.showSearchInput = false;
    }
  }
  /**
   * Searches through the search list to find a match
   * @param searchStr
   */
  search(searchStr) {
    this.searchString = searchStr.trim();
    if (!this.searchString) {
      this.searchResults = [];
      return;
    }
    const fuzzyResults = Fuzzysort.go(this.searchString, this.searchList, this.searchOptions);
    this.searchResults = fuzzyResults.map((item) => item.obj);
    this.hasTypo = fuzzyResults.every((item) => item.score < this.thresholdScoreLimit);
  }
  /**
   * Gets an array of searchable titles and tags based on the views array
   * @param navigationItems
   */
  getSearchList(navigationItems, parentItem) {
    const headerSearchList = [];
    navigationItems.forEach((navItem) => {
      if (!navItem.children) {
        headerSearchList.push(...this.getSearchListItems(navItem, parentItem));
      }
      else {
        headerSearchList.push(...this.getSearchList(navItem.children, navItem));
      }
    });
    return headerSearchList;
  }
  /**
   * Returns individual list item for title and tags.
   * @param navigationItem
   */
  getSearchListItems(navigationItem, parentItem) {
    const searchItems = [];
    searchItems.push(navigationItem.title);
    if (Array.isArray(navigationItem.tags) && navigationItem.tags.length > 0) {
      searchItems.push(...navigationItem.tags);
    }
    return searchItems.map((item) => {
      return {
        title: parentItem ? navigationItem.title + ' - ' + parentItem.title : navigationItem.title,
        searchItem: item,
        url: navigationItem.path,
      };
    });
  }
  /**
   * Method to highlight search text in result
   * @param text
   * @param searchString
   */
  getSearchResultText(searchItem, searchString) {
    return Fuzzysort.highlight(Fuzzysort.single(searchString, searchItem.title), '<b>', '</b>') || searchItem.title;
  }
  /**
   * Called on click of a search result
   * Navigates to desired view
   * @param path
   */
  navigateToItem(detail) {
    this.closeSearch();
    this.searchResultItemClicked.emit(detail.url);
  }
  /**
   * Called when user clicks on the search icon in the header
   */
  showSearch() {
    this.showSearchInput = true;
    this.searchInput.focus();
  }
  /**
   * Called when the user closes the search input
   */
  closeSearch() {
    this.showSearchInput = false;
  }
  /**
   * Called when the user clears the search input
   */
  clearSearch() {
    this.searchInput.value = '';
    this.searchString = '';
    this.searchResults = [];
    this.searchInput.focus();
  }
  render() {
    return (h("div", { class: "bci-portal-search-icon" },
      h("span", { class: "bosch-ic bosch-ic-medium bosch-ic-clickable bosch-ic-search", "data-test": "webcore.webcomponents.header-search-icon.search.span", onClick: () => this.showSearch() }),
      h("div", { class: 'bci-portal-search-input-container ' + (this.showSearchInput ? 'draw-out' : 'draw-in') },
        h("div", { class: "bci-portal-header-search-input" },
          h("input", { "data-test": "webcore.webcomponents.header-search-icon.search.input", placeholder: translate('search'), ref: (el) => (this.searchInput = el), onInput: () => this.search(this.searchInput.value) }),
          !!this.searchString ? (h("span", { "data-test": "webcore.webcomponents.header-search-icon.close.span", class: "bci-portal-input-icon close bosch-ic bosch-ic-close-small bosch-ic-clickable", onClick: () => this.clearSearch() })) : (''),
          h("span", { class: "bci-portal-input-icon search bosch-ic bosch-ic-search bosch-ic-clickable", onClick: () => this.closeSearch() })),
        h("div", { class: 'bci-portal-search-results-container ' + (this.searchResults.length === 0 ? 'hide' : 'show') },
          h("div", { class: "bci-portal-search-result-group" }, this.hasTypo ? translate('didYouMean') : translate('mostRelevant')),
          h("ul", { class: "bci-portal-search-result-list" }, this.searchResults
            .filter((result, index, arr) => {
            // Removing duplicate titles
            return arr.findIndex((i) => i.title === result.title) === index;
          })
            .map((result) => {
            return (h("li", { "data-test": "webcore.webcomponents.header-search-icon.bci-portal-search-result-click-navigate-item", class: "bci-portal-search-result bosch-ic-clickable", onClick: () => this.navigateToItem(result) },
              h("span", { innerHTML: this.getSearchResultText(result, this.searchString) })));
          }))))));
  }
  static get is() { return "bci-portal-header-search-icon"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["header-search-icon.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["header-search-icon.css"]
  }; }
  static get properties() { return {
    "navigationItems": {
      "type": "unknown",
      "mutable": true,
      "complexType": {
        "original": "SidebarNavItem[]",
        "resolved": "SidebarNavItem[]",
        "references": {
          "SidebarNavItem": {
            "location": "import",
            "path": "../../interfaces/navigation.interface"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "defaultValue": "[]"
    }
  }; }
  static get states() { return {
    "showSearchInput": {},
    "searchString": {},
    "searchResults": {}
  }; }
  static get events() { return [{
      "method": "searchResultItemClicked",
      "name": "bci.portal.header.navItemClicked",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      }
    }]; }
  static get listeners() { return [{
      "name": "bci.portal.viewsLoaded",
      "method": "componentWillLoad",
      "target": "window",
      "capture": false,
      "passive": false
    }, {
      "name": "keydown",
      "method": "handleKeyDown",
      "target": undefined,
      "capture": false,
      "passive": false
    }]; }
}

