/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
import { getLogger } from '../../../../../../utils/utils';
import { TreeManagerUtils } from '../tree-manager';
export class TreeSelectionService {
  constructor(onInvalidSelection, selectionMode = 'multi', initialSelection = []) {
    this.onInvalidSelection = onInvalidSelection;
    this._selections = [];
    this._logger = getLogger();
    this._selectionMode = selectionMode;
    this.setInitialSelections(initialSelection);
  }
  setInitialSelections(initialSelection) {
    this._selections = initialSelection;
  }
  resetSelection(tree) {
    this.resetSelectionByTree(tree);
    this._selections = [];
  }
  /**
   * updates selections states of giving tree according to current selection
   * In Mismatching case of Invalid set selection and existing tree nodes function triggers OnInvalidSelection
   * @param tree
   */
  updateTreeWithCurrentSelection(tree) {
    this.setSelectionsAndUpdateInTree(tree, this.selections);
  }
  /**
   * sets the selection and updates the given tree with such
   * @param tree
   * @param selections
   */
  setSelectionsAndUpdateInTree(tree = [], selections) {
    const validSelections = this.validateSelectionByLevel(tree, selections);
    this._selections = validSelections;
    if (tree.length > 0) {
      this.setSelectionsInLevelDeep(tree);
    }
  }
  get selections() {
    return this._selections;
  }
  get selectionMode() {
    return this._selectionMode;
  }
  set selectionMode(selectionMode) {
    this._selectionMode = selectionMode;
  }
  /**
   * searches and updates within the given tree a specific node and sets the given new state within
   * @param tree
   * @param changedNode
   * @param newState
   * @returns
   */
  updateNodeStateInTree(tree, changedNode, newState) {
    var _a;
    if (!tree) {
      return;
    }
    const effectedNode = TreeManagerUtils.getNodeFromTreeByNodePath(tree, changedNode);
    if (!effectedNode || effectedNode.selectionState === newState) {
      /** no change */
      return;
    }
    if (this.selectionMode === 'single') {
      this.resetSelection(tree);
    }
    // we only need to deselect children if children are selected, therefore the === 'indeterminate' check
    const isParentBeingChecked = effectedNode.selectionState === 'indeterminate' && newState === 'checked';
    const isBeingChecked = newState === 'checked';
    effectedNode.selectionState = newState;
    if (isBeingChecked) {
      const parentNodePaths = this.setIndeterminateOnParentsByNodePath(tree, (_a = effectedNode.parent) === null || _a === void 0 ? void 0 : _a.path);
      /** remove parents from this.selections, cause the children is selected therefore no parent can be selected (only indeterminate) */
      this.setSelectionsAndUpdateInTree(tree, this.removeNodesFromSelection(parentNodePaths));
    }
    if (isParentBeingChecked) {
      this.setUncheckedOnChildren(effectedNode.children);
      this.setSelectionsAndUpdateInTree(tree, this.removeChildrenFromSelection(changedNode));
    }
    this.setSelectionsAndUpdateInTree(tree, newState === 'checked' ? [...this._selections, changedNode] : this.removeNodeFromSelections(this._selections, changedNode));
    if (!isBeingChecked) {
      this.updateIndeterminateStateOfParents(tree, this._selections, effectedNode);
    }
  }
  setSelectionsInLevel(level, selections) {
    level.forEach((node) => {
      const selectionsContainingNode = selections.filter((selection) => selection.length > node.level && selection[node.level].id === node.id);
      if (selectionsContainingNode.length === 0) {
        if (node.selectionState === 'checked') {
          node.selectionState = 'unchecked';
        }
        return;
      }
      const nodeIsIndeterminate = selectionsContainingNode.some((selection) => selection.length > node.level + 1);
      node.selectionState = nodeIsIndeterminate ? 'indeterminate' : 'checked';
    });
    return level;
  }
  isSelectionsValidBySelectionMode(selections) {
    return !(selections.length > 1 && this.selectionMode === 'single');
  }
  /**
   * returns valid selections - validated by the selectionMode Rule
   * @param selections
   * @returns
   */
  validateSelectionsBySelectionModeRule(selections) {
    const isSelectionsValid = this.isSelectionsValidBySelectionMode(selections);
    if (!isSelectionsValid) {
      this._logger.error("The bci-multi-selector is in 'single' selection mode, but the initial selection you provided contains more that one selection. Therefore the initial selection will be empty");
    }
    return isSelectionsValid ? selections : [];
  }
  validateSelectionByLevel(checkedLevel, selections) {
    let validatedSelections = this.validateSelectionsBySelectionModeRule(selections);
    if (validatedSelections.length === 0 || checkedLevel === undefined) {
      return validatedSelections;
    }
    const { valid, invalid } = this.validateSelectionIsMappingLevelRule(validatedSelections, checkedLevel);
    validatedSelections = valid;
    if (invalid.length !== 0) {
      invalid.forEach((invalidSelection) => (this._selections = this.removeNodeFromSelections(this._selections, invalidSelection)));
      this.onInvalidSelection(invalid);
    }
    return valid;
  }
  /**
   * validates if the level related selections map to the actual level
   * Tries to find mismatches between set Selection and actual level (mismatches are invalid nodes)
   * Search is only within the given level
   * @param selections
   * @param checkedLevel
   * @returns
   */
  validateSelectionIsMappingLevelRule(selections, checkedLevel) {
    var _a, _b;
    const startSplitSelection = { valid: [], invalid: [] };
    const [ignoredNodePaths, groupedNodePaths] = this.groupByNodePathId(selections, (_b = (_a = checkedLevel[0]) === null || _a === void 0 ? void 0 : _a.parent) === null || _b === void 0 ? void 0 : _b.path);
    const searchSpaceKeySet = new Set(checkedLevel.map(({ id }) => id));
    const toSplitSelection = ({ invalid, valid }, [key, value]) => {
      if (searchSpaceKeySet.has(key)) {
        return { valid: valid.concat(value), invalid };
      }
      return { valid, invalid: invalid.concat(value) };
    };
    const validatedSelectionSplit = [...groupedNodePaths.entries()].reduce(toSplitSelection, startSplitSelection);
    validatedSelectionSplit.valid = validatedSelectionSplit.valid.concat(ignoredNodePaths);
    return validatedSelectionSplit;
  }
  /**
   * All children of the parent node will have the same 'node.id' at the parent node level (same index),
   * because the NodeLink contains the entire path to them.
   * So, filtering them is as simple as comparing at the same NodeLink level for the parent id
   * @param selection
   * @param parent
   * @returns
   */
  splitSelectionByNodePath(selection, parent) {
    const parentNode = parent[parent.length - 1];
    const parentDepthIndex = parent.length - 1;
    return selection.reduce(([match, miss], nodeLink) => {
      var _a;
      if (((_a = nodeLink[parentDepthIndex]) === null || _a === void 0 ? void 0 : _a.id) === parentNode.id) {
        match.push(nodeLink);
      }
      else {
        miss.push(nodeLink);
      }
      return [match, miss];
    }, [[], []]);
  }
  /**
   * example:
   *  input:
   *    selections: [ [ {id, label}, {id, label}, ...], [ {id, label}, {id, label}, ...] ...]
   *    nodePathOfNodeToRemove: [ {id, label}, {id, label} ...]
   *
   * @param selections
   * @param nodePathOfNodeToRemove
   * @returns
   */
  removeNodeFromSelections(selections, nodePathOfNodeToRemove) {
    const nodeToRemove = nodePathOfNodeToRemove[nodePathOfNodeToRemove.length - 1];
    return selections.filter((path) => path[path.length - 1].id !== nodeToRemove.id);
  }
  resetSelectionByTree(level) {
    level.forEach((node) => {
      node.selectionState = 'unchecked';
      this.resetSelectionByTree(node.children);
    });
  }
  setSelectionsInLevelDeep(level) {
    const validSelection = this.validateSelectionByLevel(level, this._selections);
    this.setSelectionsInLevel(level, validSelection);
    level.forEach((node) => {
      if (node.children && node.children.length > 0) {
        this.setSelectionsInLevelDeep(node.children);
      }
    });
  }
  setIndeterminateOnParentsByNodePath(tree, nodePath) {
    var _a;
    const node = TreeManagerUtils.getNodeFromTreeByNodePath(tree, nodePath);
    if (!node) {
      return [];
    }
    node.selectionState = 'indeterminate';
    return [node.path].concat(this.setIndeterminateOnParentsByNodePath(tree, (_a = node.parent) === null || _a === void 0 ? void 0 : _a.path));
  }
  /**
   * The result contains all NodePaths which were part of the selections parameter, but split into ignoredNodePaths and groupedNodePaths
   * @param selections
   * @param parentNodePath is used to filter the selections before grouping. Only nodes that are its children will be part of the groupedNodePaths Map
   * @returns
   */
  groupByNodePathId(selections, parentNodePath) {
    var _a;
    const [filteredSelections, ignoredNodePaths] = parentNodePath
      ? this.splitSelectionByNodePath(selections, parentNodePath)
      : [selections, []];
    const depthIndex = (_a = parentNodePath === null || parentNodePath === void 0 ? void 0 : parentNodePath.length) !== null && _a !== void 0 ? _a : 0;
    const groupedNodePaths = filteredSelections.reduce((map, nodePath) => {
      const nodeLink = nodePath[depthIndex];
      if (!nodeLink) {
        // Is only undefined when its the parentNodePath itself.
        // As this node obviously exists, it can be ignored for further validation.
        ignoredNodePaths.push(nodePath);
        return map;
      }
      const key = nodeLink.id;
      const group = map.get(key) || [];
      group.push(nodePath);
      return map.set(key, group);
    }, new Map());
    return [ignoredNodePaths, groupedNodePaths];
  }
  removeNodesFromSelection(nodePathsToRemove) {
    return nodePathsToRemove.reduce((selections, nodePath) => this.removeNodeFromSelections(selections, nodePath), this._selections);
  }
  removeChildrenFromSelection(changedNode) {
    const clickedNodePlusChildren = this.filterSelectionByNodePath(this._selections, changedNode);
    const childrenOfClickedNode = clickedNodePlusChildren.filter((nodeLink) => nodeLink.length !== changedNode.length);
    return this._selections.filter((nodeLink) => !childrenOfClickedNode.includes(nodeLink));
  }
  updateIndeterminateStateOfParents(tree, selection, effectedNode) {
    var _a;
    if (!effectedNode.parent) {
      return;
    }
    const parentNode = TreeManagerUtils.getNodeFromTreeByNodePath(tree, (_a = effectedNode.parent) === null || _a === void 0 ? void 0 : _a.path);
    if (selection.some((selectedPath) => selectedPath.some((node) => node.id === parentNode.id))) {
      // if this node stays indeterminate due to another selection, all of its parent will as well
      return;
    }
    parentNode.selectionState = 'unchecked';
    this.updateIndeterminateStateOfParents(tree, selection, parentNode);
  }
  filterSelectionByNodePath(selection, parent) {
    const [match] = this.splitSelectionByNodePath(selection, parent);
    return match;
  }
  setUncheckedOnChildren(nodes) {
    if (nodes.length === 0) {
      return;
    }
    nodes.forEach((node) => {
      node.selectionState = 'unchecked';
      this.setUncheckedOnChildren(node.children);
    });
  }
}

