/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
/*
 * Copyright (C) 2021 Robert Bosch GmbH Copyright (C) 2021 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.
 */
import { Component, Event, h, Host, Listen, Prop, State, Watch } from '@stencil/core';
import { setLocale } from '../../utils/locale-store';
import { OverlayHandler } from '../overlay/overlay-handler';
import { translate } from '../../utils/utils';
import { WidthObserver } from './service/width-observer-service';
import { KeyEventListener } from './service/key-event-listener-service';
import { MultiSelectorManager } from './service/multi-selector-manager/multi-selector-manager.service';
export class MultiSelector {
  constructor() {
    /**
     * Mark this element to be shown on dark background (it will adapt styling). Default: false.
     */
    this.darkBackground = false;
    /** defines the mode of selection - if single, then is only 1 selection at a time possible (default multi) */
    this.selectionMode = 'multi';
    /** pre selection */
    this.initialSelection = [];
    /** Enforce single column mode, normally only used for smaller screens / selectors. */
    this.singleColumnMode = false;
    /** Prevents going into fullscreen / responsive mode on low resolutions. */
    this.preventFullscreen = false;
    /** state that keeps the focus as long as the user interacts with any component part of this multi selector (including overlay) */
    this.focused = false;
    this.searchValue = '';
    this.activeLevels = [];
    this.isLoading = false;
    this.enforceOverlayViewport = 'vp1';
    this.inputComponents = [];
    // to be turned into property in the future when implementing and offering that feature
    this.showSave = false;
    this.overlayVP1Config = {
      placement: 'none',
    };
    this.overlayVP2And3Config = {
      placement: 'bottom-start',
    };
    this.currentOverlayConfig = this.overlayVP1Config;
    this.overlayHandler = new OverlayHandler(true);
  }
  hideDialog() {
    if (this.focused) {
      this.handleOnFinish();
    }
  }
  onDataSourceUpdate() {
    this._dataSources = Array.isArray(this.dataSource) ? this.dataSource : [{ id: '', label: '', dataSource: this.dataSource }];
    this.selectedDataSource = this._dataSources[0];
    this.activeLevels = [];
    this.initiateTreeManager(this.selectedDataSource.dataSource);
  }
  onSelectionModeChange() {
    var _a, _b;
    (_a = this === null || this === void 0 ? void 0 : this.multiSelectorManager) === null || _a === void 0 ? void 0 : _a.resetSelection();
    (_b = this === null || this === void 0 ? void 0 : this.multiSelectorManager) === null || _b === void 0 ? void 0 : _b.updateSelectionMode(this.selectionMode);
  }
  onSearchChange(newSearch) {
    if (!!this.multiSelectorManager) {
      this.multiSelectorManager.resetFocus();
      this.multiSelectorManager.updateFilter(newSearch);
    }
  }
  onInitialSelectionChange(newInitialSelection) {
    this.multiSelectorManager.initiateSelections(newInitialSelection);
  }
  componentDidLoad() {
    this.setupHideOverlayListeners();
    this.setupWidthObserver();
    this.setupKeyListeners();
  }
  async componentWillLoad() {
    await setLocale();
    this.onDataSourceUpdate();
    this.multiSelectorManager.updateFilter(this.searchValue);
  }
  render() {
    // Order of input and other elements is important for proper background color when focused!
    return (h(Host, null,
      this.renderStandardInput(),
      h("bci-overlay", { ref: (el) => (this.overlayHandler.overlay = el), config: this.currentOverlayConfig },
        h("bci-multi-selector-overlay", { tabindex: "0", ref: (el) => (this.overlayHandler.dialog = el), headerLabel: this.selectedDataSource.label, filterText: this.multiSelectorManager.getFilter(), showSave: this.showSave, enforceViewport: this.enforceOverlayViewport, activeLevels: this.activeLevels, resetSelectionButtonEnabled: this.multiSelectorManager.selections.length !== 0, onNavigateBack: () => this.handleNavigateBack(), onSelectionReset: () => this.handleResetSelection(), onSelectionFinished: () => this.handleOnFinish(), onNodeSelectionChange: (event) => this.handleNodeSelectionChange(event.detail), onNodeActiveChange: (event) => this.handleNodeActiveChange(event.detail), onClearSearch: () => this.handleClearSearch(), isLoading: this.isLoading },
          h("div", { slot: "input-and-label" }, this.renderOverlayInput())))));
  }
  /**
   * @returns the standard Input component
   */
  renderStandardInput() {
    const isMultiSelectorHost = true;
    return this.renderInput(isMultiSelectorHost);
  }
  /**
   * @returns a rendered Input dedicated for the overlay component
   */
  renderOverlayInput() {
    const isMultiSelectorHost = false;
    return this.renderInput(isMultiSelectorHost);
  }
  renderInput(isMultiSelectorHost) {
    return (h("bci-multi-selector-input", { ref: (el) => (isMultiSelectorHost ? this.inputComponents.push((this.overlayHandler.host = el)) : this.inputComponents.push(el)), searchValue: this.searchValue, searchPlaceholder: translate('search'), selections: this.multiSelectorManager.selections, dataSources: this._dataSources, selectedDataSource: this.selectedDataSource, onSelectSearchType: (event) => this.handleOnSelectSearchType(event.detail), onFocusInput: () => isMultiSelectorHost && this.handleOnMultiSelectorInputFocus(), onSearchChange: (value) => (this.searchValue = value.detail), onClearSearch: () => this.handleClearSearch(), class: isMultiSelectorHost ? (this.focused ? ' focused' : '') + (this.darkBackground ? ' dark-background' : '') : '' }));
  }
  initiateTreeManager(dataSource) {
    this.multiSelectorManager = new MultiSelectorManager(dataSource, (activeLevels) => this.onActiveChangeObserverFunction(activeLevels), (selection) => this.selectionUpdateObserverFunction(Object.assign(Object.assign({}, selection), { rootId: this.selectedDataSource.id })), () => this.handleClearSearch(), (invalidNodes) => this.invalidSelection.emit({ invalidNodes }), (isLoading) => (this.isLoading = isLoading), this.initialSelection, this.selectionMode);
  }
  setupHideOverlayListeners() {
    this.overlayHandler.dialog.onclick = (ev) => {
      ev.stopPropagation();
    };
    this.overlayHandler.host.onclick = (ev) => {
      ev.stopPropagation();
    };
  }
  setupWidthObserver() {
    const setVp1 = () => {
      this.currentOverlayConfig = this.overlayVP1Config;
      this.enforceOverlayViewport = this.preventFullscreen ? 'vp2' : 'vp1';
    };
    const setVp2_3 = () => {
      this.currentOverlayConfig = this.overlayVP2And3Config;
      this.enforceOverlayViewport = this.singleColumnMode ? 'vp2' : undefined;
    };
    this.widthObserver = new WidthObserver(document.documentElement, {
      onVp1: this.preventFullscreen ? setVp2_3 : setVp1,
      onVp2: setVp2_3,
      onVp3: setVp2_3,
    }, false);
    this.widthObserver.connect();
  }
  setupKeyListeners() {
    this.setupOverlayKeyListener();
    this.setupSearchInputKeyListener();
  }
  setupSearchInputKeyListener() {
    this.inputKeyObserver = new KeyEventListener(null);
    this.inputKeyObserver.addListener('keyup', this.onMultiSelectorInputArrowDown.bind(this), 'ArrowDown');
  }
  onMultiSelectorInputArrowDown() {
    this.overlayKeyEventListener.active = true;
    this.inputKeyObserver.active = false;
    if (document.activeElement instanceof HTMLElement) {
      document.activeElement.blur();
      this.overlayHandler.dialog.focus();
    }
    this.multiSelectorManager.arrowDownPressed();
  }
  onArrowUp() {
    var _a, _b;
    if (this.multiSelectorManager.isFirstElementFocussed()) {
      this.multiSelectorManager.resetFocus();
      if (this.enforceOverlayViewport === 'vp1') {
        (_a = this.inputComponents[1]) === null || _a === void 0 ? void 0 : _a.setFocusOnInputField();
      }
      else {
        (_b = this.inputComponents[0]) === null || _b === void 0 ? void 0 : _b.setFocusOnInputField();
      }
    }
    else {
      this.multiSelectorManager.arrowUpPressed();
    }
  }
  setupOverlayKeyListener() {
    this.overlayHandler.focusChangeObserver = (isFocussed) => {
      this.overlayKeyEventListener.active = isFocussed;
      this.inputKeyObserver.active = !isFocussed;
    };
    this.overlayKeyEventListener = new KeyEventListener(null);
    this.overlayKeyEventListener
      .addListener('keyup', this.onArrowUp.bind(this), 'ArrowUp')
      .addListener('keyup', this.multiSelectorManager.arrowRightPressed.bind(this.multiSelectorManager), 'ArrowRight')
      .addListener('keyup', this.multiSelectorManager.arrowDownPressed.bind(this.multiSelectorManager), 'ArrowDown')
      .addListener('keyup', this.multiSelectorManager.arrowLeftPressed.bind(this.multiSelectorManager), 'ArrowLeft')
      .addListener('keyup', this.multiSelectorManager.spacePressed.bind(this.multiSelectorManager), 'Space');
  }
  handleResetSelection() {
    var _a;
    (_a = this.multiSelectorManager) === null || _a === void 0 ? void 0 : _a.resetSelection();
  }
  handleNodeActiveChange(activeChangedEvent) {
    this.multiSelectorManager.setActiveStateOfNodeByPath(activeChangedEvent.path, activeChangedEvent.active);
  }
  handleNodeSelectionChange(selectionChangeEvent) {
    this.multiSelectorManager.setSelectionStateOfNodeByPath(selectionChangeEvent.path, selectionChangeEvent.newState);
  }
  handleNavigateBack() {
    const currentLevel = this.activeLevels[this.activeLevels.length - 1];
    this.multiSelectorManager.deactivateLevel(currentLevel);
  }
  handleOnSelectSearchType(rootNode) {
    this.selectedDataSource = rootNode;
    this.searchValue = '';
  }
  handleClearSearch() {
    this.searchValue = '';
  }
  handleOnFinish() {
    this.selectionFinished.emit({ selections: this.multiSelectorManager.selections, rootId: this.selectedDataSource.id });
    this.focused = false;
    this.overlayHandler.hide();
  }
  handleOnMultiSelectorInputFocus() {
    this.overlayHandler.show();
    this.focused = true;
    this.overlayKeyEventListener.active = false;
    this.inputKeyObserver.active = true;
  }
  selectionUpdateObserverFunction(event) {
    this.searchValue = '';
    this.selectionChanged.emit(event);
  }
  onActiveChangeObserverFunction(activeLevels) {
    this.activeLevels = activeLevels;
  }
  static get is() { return "bci-multi-selector"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["multi-selector.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["multi-selector.css"]
  }; }
  static get properties() { return {
    "darkBackground": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Mark this element to be shown on dark background (it will adapt styling). Default: false."
      },
      "attribute": "dark-background",
      "reflect": false,
      "defaultValue": "false"
    },
    "dataSource": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "MultiSelectorDataSource",
        "resolved": "RootDataSource | RootNode[]",
        "references": {
          "MultiSelectorDataSource": {
            "location": "import",
            "path": "./model"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "DataSource that provides function implementations to receive/call data content"
      }
    },
    "selectionMode": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "SelectionMode",
        "resolved": "\"multi\" | \"single\"",
        "references": {
          "SelectionMode": {
            "location": "import",
            "path": "./model"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "defines the mode of selection - if single, then is only 1 selection at a time possible (default multi)"
      },
      "attribute": "selection-mode",
      "reflect": false,
      "defaultValue": "'multi'"
    },
    "initialSelection": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "NodePath[]",
        "resolved": "NodePath[]",
        "references": {
          "NodePath": {
            "location": "import",
            "path": "./model"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "pre selection"
      },
      "defaultValue": "[]"
    },
    "singleColumnMode": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Enforce single column mode, normally only used for smaller screens / selectors."
      },
      "attribute": "single-column-mode",
      "reflect": false,
      "defaultValue": "false"
    },
    "preventFullscreen": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Prevents going into fullscreen / responsive mode on low resolutions."
      },
      "attribute": "prevent-fullscreen",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
  static get states() { return {
    "focused": {},
    "selectedDataSource": {},
    "searchValue": {},
    "activeLevels": {},
    "isLoading": {},
    "enforceOverlayViewport": {},
    "currentOverlayConfig": {}
  }; }
  static get events() { return [{
      "method": "selectionFinished",
      "name": "selectionFinished",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emits the final selection. It is triggered whenever user closes selector."
      },
      "complexType": {
        "original": "SelectionFinishedEvent",
        "resolved": "SelectionFinishedEvent",
        "references": {
          "SelectionFinishedEvent": {
            "location": "import",
            "path": "./model"
          }
        }
      }
    }, {
      "method": "selectionChanged",
      "name": "selectionChanged",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emits all selected elements and emits when any element selection was added/removed/changed"
      },
      "complexType": {
        "original": "SelectionChangedEvent",
        "resolved": "SelectionChangedEvent",
        "references": {
          "SelectionChangedEvent": {
            "location": "import",
            "path": "./model"
          }
        }
      }
    }, {
      "method": "invalidSelection",
      "name": "invalidSelection",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emits all invalid elements when they are detected"
      },
      "complexType": {
        "original": "InvalidPreselectionErrorEvent",
        "resolved": "InvalidPreselectionErrorEvent",
        "references": {
          "InvalidPreselectionErrorEvent": {
            "location": "import",
            "path": "./model"
          }
        }
      }
    }]; }
  static get watchers() { return [{
      "propName": "dataSource",
      "methodName": "onDataSourceUpdate"
    }, {
      "propName": "selectionMode",
      "methodName": "onSelectionModeChange"
    }, {
      "propName": "searchValue",
      "methodName": "onSearchChange"
    }, {
      "propName": "initialSelection",
      "methodName": "onInitialSelectionChange"
    }]; }
  static get listeners() { return [{
      "name": "click",
      "method": "hideDialog",
      "target": "body",
      "capture": false,
      "passive": false
    }]; }
}

