/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
import { LoadingHandlerService } from '../../multi-selector-overlay/multi-selector-tree/service/loading-handler/loading-handler.service';
import { TreeFilterService } from '../../multi-selector-overlay/multi-selector-tree/service/tree-filter/tree-filter.service';
import { TreeManagerUtils } from '../../multi-selector-overlay/multi-selector-tree/service/tree-manager';
import { TreeSelectionService } from '../../multi-selector-overlay/multi-selector-tree/service/tree-selection/tree-selection.service';
export class MultiSelectorManager {
  /**
   * initiate class and load the initial root level of the tree
   * @param dataSource
   * @param singleSelectMode
   * @param onActiveChange Provide a function that is called whenever the active levels change
   */
  constructor(dataSource, onActiveChange, onSelectionChange, onClearSearch, onInvalidSelection, onLoadingChange, initialSelection = [], selectionMode = 'multi') {
    this.onActiveChange = onActiveChange;
    this.onSelectionChange = onSelectionChange;
    this.onClearSearch = onClearSearch;
    this.onInvalidSelection = onInvalidSelection;
    this.onLoadingChange = onLoadingChange;
    this._activeLevels = [];
    this._filterService = new TreeFilterService();
    this._focussedNode = null;
    this.dataSource = this.loadingHandler = new LoadingHandlerService(dataSource, (value) => this.invokeAsync(() => this.onLoadingChange(value)));
    this._selectionService = new TreeSelectionService(this.onInvalidSelection, selectionMode, initialSelection);
    this._selectionService.setInitialSelections(initialSelection);
    this.handleLoadedNodes(this.dataSource.getRoots()).then(() => {
      this.updateActiveLevels();
    });
  }
  getFilter() {
    return this._filterService.filter;
  }
  updateFilter(filter) {
    if (filter === this._filterService.filter) {
      return;
    }
    this._filterService.filter = filter;
    this.updateActiveLevels();
  }
  resetSelection(notify = true) {
    if (!this._tree) {
      return;
    }
    this._selectionService.resetSelection(this._tree);
    if (notify) {
      this.updateSelection([], 'reset');
    }
    // the tree needs to be redrawn when changing the selection, even if no OnSelectionChange event is triggered
    this.updateActiveLevels();
  }
  updateSelection(path, selectionState) {
    Promise.resolve().then(() => this.onSelectionChange({
      changedNode: path,
      reason: selectionState,
      selections: this._selectionService.selections,
    }));
  }
  updateSelectionMode(selectionMode) {
    if (this._selectionService.selectionMode === selectionMode) {
      return;
    }
    this.resetSelection(false);
    this._selectionService.selectionMode = selectionMode;
  }
  setSelectionStateOfNodeByPath(changedNode, newState) {
    if (!this._tree) {
      return;
    }
    this._selectionService.updateNodeStateInTree(this._tree, changedNode, newState);
    this.updateSelection(changedNode, newState);
    this.updateActiveLevels();
  }
  initiateSelections(selections) {
    this._selectionService.setSelectionsAndUpdateInTree(this._tree, selections);
    this.updateActiveLevels();
  }
  get isLoading() {
    return this.loadingHandler.isLoading;
  }
  getActiveLevels() {
    const filteredActiveLevels = this._filterService.applyFilter(this._activeLevels);
    return [...filteredActiveLevels];
  }
  async arrowLeftPressed() {
    if (!this._focussedNode) {
      this.initiateFocussedNode();
      this.updateActiveLevels();
      return;
    }
    else if (!this._focussedNode.parent) {
      /** no changed */
      return;
    }
    const parentNode = this._focussedNode.parent;
    if (parentNode) {
      this.setFocusedNodeByPath(parentNode.path);
      await this.setActiveStateOfNodeByPath(parentNode.path, false);
    }
    else {
      this.updateActiveLevels();
    }
  }
  async arrowRightPressed() {
    var _a;
    if (!this._focussedNode) {
      this.initiateFocussedNode();
      this.updateActiveLevels();
      return;
    }
    else if (!this._focussedNode.hasChildren) {
      /** no changed */
      return;
    }
    if (this._focussedNode.hasChildren) {
      await this.setActiveStateOfNodeByPath(this._focussedNode.path, true);
      this.setFocusedNodeByPath((_a = this._focussedNode.children[0]) === null || _a === void 0 ? void 0 : _a.path);
    }
    else {
      this.updateActiveLevels();
    }
  }
  arrowUpPressed() {
    if (!this._focussedNode) {
      this.initiateFocussedNode();
      this.updateActiveLevels();
      return;
    }
    let levelOfFocussedNode = this.getLevelOfFocussedNode();
    let index = levelOfFocussedNode.findIndex((node) => node.id === this._focussedNode.id);
    if (index === -1) {
      console.error('NODE NOT FOUND IN LEVEL', levelOfFocussedNode);
      return;
    }
    else if (index === 0) {
      index = levelOfFocussedNode.length - 1;
    }
    else {
      index = index - 1;
    }
    this.setFocusedNodeByPath(levelOfFocussedNode[index].path);
    return this.updateActiveLevels();
  }
  arrowDownPressed() {
    if (!this._focussedNode) {
      this.initiateFocussedNode();
      this.updateActiveLevels();
      return;
    }
    let levelOfFocussedNode = this.getLevelOfFocussedNode();
    let index = levelOfFocussedNode.findIndex((node) => node.id === this._focussedNode.id);
    if (index === -1) {
      console.error('NODE NOT FOUND IN LEVEL', levelOfFocussedNode);
      return;
    }
    else if (index === levelOfFocussedNode.length - 1) {
      /** index is set on last node of the level (therefore starts on first again) */
      index = 0;
    }
    else {
      index = Number(index) + 1;
    }
    this.setFocusedNodeByPath(levelOfFocussedNode[index].path);
    return this.updateActiveLevels();
  }
  mouseDown() {
    this.removeFocusOfNode();
    this.updateActiveLevels();
  }
  spacePressed() {
    if (!this._focussedNode) {
      this.initiateFocussedNode();
    }
    const newSelectionState = this._focussedNode.selectionState === 'checked' ? 'unchecked' : 'checked';
    this._selectionService.updateNodeStateInTree(this._tree, this._focussedNode.path, newSelectionState);
    this.updateSelection(this._focussedNode.path, newSelectionState);
    this.updateActiveLevels();
  }
  initiateFocussedNode() {
    const [firstNodeOfLastLevel] = TreeManagerUtils.getNodesByLevel(this.getLastActiveLevel());
    this.setFocusedNodeByPath(firstNodeOfLastLevel === null || firstNodeOfLastLevel === void 0 ? void 0 : firstNodeOfLastLevel.path);
  }
  /**
   * takes care of updating the references of class variables if a refresh/clone of the tree happened
   */
  refreshFocussedNodeReference() {
    if (this._focussedNode) {
      this._focussedNode = TreeManagerUtils.getNodeFromTreeByNodePath(this._tree, this._focussedNode.path);
    }
  }
  isFirstElementFocussed() {
    const currentActiveLevel = TreeManagerUtils.getNodesByLevel(this._activeLevels[this._activeLevels.length - 1]);
    return currentActiveLevel.indexOf(this._focussedNode) === 0 || !this._focussedNode;
  }
  resetFocus() {
    if (!this._focussedNode) {
      return;
    }
    this._focussedNode.focused = false;
    this._focussedNode = null;
    this.updateActiveLevels();
  }
  getLevelOfFocussedNode() {
    /** if no parent exists return current level
     * Returns the nodes of the treeLevel since the sorting is important here
     */
    const filteredActiveLevels = this.getActiveLevels();
    return TreeManagerUtils.getNodesByLevel(filteredActiveLevels[this._focussedNode.level]);
  }
  removeFocusOfNode() {
    if (this._focussedNode) {
      this._focussedNode.focused = false;
      this._focussedNode = null;
    }
  }
  setFocusedNodeByPath(nodePath) {
    if (this._focussedNode) {
      this._focussedNode.focused = false;
    }
    this._focussedNode = TreeManagerUtils.getNodeFromTreeByNodePath(this._tree, nodePath);
    this._focussedNode.focused = true;
  }
  /**
   * sets the active State of a Node by its NodePath (last element of NodePath is the effected Node)
   * @param path
   * @param active
   * @returns
   */
  async setActiveStateOfNodeByPath(path, active) {
    if (!this._tree) {
      return;
    }
    const effectedNode = TreeManagerUtils.getNodeFromTreeByNodePath(this._tree, path);
    if (!effectedNode || !effectedNode.hasChildren) {
      return;
    }
    const node = this.updateActiveStateOfNode(effectedNode, active);
    if (!node) {
      return;
    }
    if (this._filterService.filter) {
      // whenever children are loaded the search should be cleared
      this.onClearSearch();
    }
    if (active) {
      return this.loadChildrenOfNode(node).then(() => this.updateActiveLevels());
    }
    else {
      this.updateActiveLevels();
    }
  }
  /**
   * sets a level to inactive by setting its parent and all children to inactive
   * @param level
   */
  deactivateLevel(level) {
    if (!level.parentNode || !this._tree) {
      /** "level" is the only level left - cant be closed */
      return;
    }
    this.onClearSearch();
    const effectedNode = TreeManagerUtils.getNodeFromTreeByNodePath(this._tree, level.parentNode.path);
    if (!effectedNode) {
      return;
    }
    this.updateActiveStateOfNode(effectedNode, false);
    this.updateActiveLevels();
  }
  getLastActiveLevel() {
    return this._activeLevels[this._activeLevels.length - 1];
  }
  /**
   * updates the active Levels and notifies about a refresh of the activeLevels
   */
  updateActiveLevels() {
    if (!this._tree) {
      return;
    }
    this._activeLevels = TreeManagerUtils.getActiveLevels(this._tree);
    this._activeLevels = this._filterService.applyFilter(this._activeLevels);
    this.notifyCallback();
  }
  notifyCallback() {
    const filteredActiveLevels = this.getActiveLevels();
    Promise.resolve().then(() => this.onActiveChange(filteredActiveLevels));
  }
  mapNodesToMultiSelectorTreeNodes(nodes, parent) {
    const treeNodes = nodes.map((item) => {
      var _a;
      const itemLink = { id: item.id, label: item.label };
      return Object.assign(Object.assign({}, item), { path: parent ? [...parent.path, itemLink] : [itemLink], focused: false, active: false, hasChildren: (_a = item.hasChildren) !== null && _a !== void 0 ? _a : true, children: [], parent, level: parent ? parent.level + 1 : 0, selectionState: 'unchecked' });
    });
    if (parent) {
      parent.children = treeNodes;
      if (treeNodes.length === 0) {
        parent.hasChildren = false;
      }
    }
    return treeNodes;
  }
  /**
   * updates the active levels according to the given Path of the changed node
   * @param effectedNode represents the the node that is gonna change the node state
   * @param active the new state of the node (true=selected=open, false=unselected=close)
   * @returns reference to the selected node
   */
  updateActiveStateOfNode(effectedNode, active) {
    if (!this._tree) {
      return;
    }
    if (!effectedNode || effectedNode.active === active) {
      /** no change */
      return;
    }
    const clone = TreeManagerUtils.cloneNode(effectedNode);
    // node changes state from not selected(inactive) TO selected(active)
    if (clone.parent) {
      clone.parent.children = TreeManagerUtils.setAllNodesInTreeToInactive(clone.parent.children);
    }
    else {
      const isRootNode = this._tree.some((node) => node.id === clone.id);
      if (isRootNode) {
        this._tree = this._tree.map((child) => (child.id === clone.id ? clone : child));
        this._tree = TreeManagerUtils.setAllNodesInTreeToInactive(this._tree);
      }
    }
    clone.active = active && clone.hasChildren;
    this.refreshFocussedNodeReference();
    return clone;
  }
  /**
   * loads the children of a node if already loaded returns the loaded children
   * @param node
   * @returns
   */
  async loadChildrenOfNode(node) {
    if (!node) {
      return;
    }
    if (!node.hasChildren || node.children.length > 0) {
      /** Node has no Children OR the children where already loaded before */
      return node.children;
    }
    // hides the nodes that should no longer be visible while loading the next children
    this.updateActiveLevels();
    // the children are not yet loaded
    return this.handleLoadedNodes(this.dataSource.getChildren(node.id), node);
  }
  async handleLoadedNodes(nodes, parent) {
    return nodes
      .then((nodes) => this.mapNodesToMultiSelectorTreeNodes(nodes, parent))
      .then((children) => {
      //children = this._selectionService.setSelectionsInLevel(children);
      // if there is no parent, then the root nodes were loaded
      if (!parent) {
        this._tree = children;
      }
      else if (children.length > 0) {
        parent.children = children;
      }
      else {
        parent.hasChildren = false;
      }
      this._selectionService.updateTreeWithCurrentSelection(this._tree);
      return children;
    })
      .then((children) => {
      this.refreshFocussedNodeReference();
      return children;
    });
  }
  invokeAsync(func) {
    Promise.resolve().then(() => func());
  }
  get selections() {
    return this._selectionService.selections;
  }
}

