/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
import { WidthObserver } from '../multi-selector/service/width-observer-service';
export class OverlayHandler {
  constructor(_fullwidth = false, overlay = undefined, host = undefined, dialog = undefined) {
    this._fullwidth = _fullwidth;
    this.visible = false;
    this.isFocussed = false;
    // event to trigger when an overlay is opened
    this.overlayOpenedEvent = new CustomEvent('OverlayOpenedEvent');
    this.overlay = overlay;
    this.host = host;
    this.dialog = dialog;
  }
  get overlay() {
    return this._overlay;
  }
  set overlay(overlay) {
    this._overlay = overlay;
    if (this._overlay) {
      this._overlay.host = this.host;
      this._overlay.dialog = this.dialog;
    }
  }
  get host() {
    return this._host;
  }
  set host(host) {
    var _a, _b;
    if (this._host === host) {
      return;
    }
    this._host = host;
    const isConnected = (_b = (_a = this.widthObserver) === null || _a === void 0 ? void 0 : _a.isConnected()) !== null && _b !== void 0 ? _b : false;
    if (this.widthObserver) {
      this.widthObserver.disconnect();
    }
    if (this._fullwidth && host !== undefined) {
      this.widthObserver = new WidthObserver(host, {
        onChange: (width) => this.updateOverlayWidth(width),
      });
      if (isConnected) {
        this.widthObserver.connect();
      }
    }
    if (this.overlay) {
      this.overlay.host = host;
    }
  }
  get dialog() {
    return this._dialog;
  }
  set dialog(dialog) {
    this._dialog = dialog;
    if (this.overlay) {
      this.overlay.dialog = dialog;
    }
  }
  isReady() {
    return this.host !== undefined && this.overlay !== undefined && this.dialog !== undefined;
  }
  isHidden() {
    return this.isReady() && !this.visible;
  }
  isVisible() {
    return this.isReady() && this.visible;
  }
  async show() {
    var _a;
    if (this.isHidden()) {
      // if another overlay is open, this event triggers it to close itself
      document.dispatchEvent(this.overlayOpenedEvent);
      (_a = this.widthObserver) === null || _a === void 0 ? void 0 : _a.connect();
      await this.handleVisibilityChanged(() => this.overlay.show());
      this.setupFocusObserver();
      this.setupScrollObserver();
      this.setupMutationObserver();
      document.addEventListener('OverlayOpenedEvent', () => {
        this.hide();
      });
    }
  }
  async hide() {
    var _a;
    (_a = this.widthObserver) === null || _a === void 0 ? void 0 : _a.disconnect();
    if (this.isVisible()) {
      this.removeFocusObserver();
      this.removeScrollObserver();
      this.removeMutationObserver();
      document.removeEventListener('OverlayOpenedEvent', () => { });
      return this.handleVisibilityChanged(() => this.overlay.hide());
    }
  }
  updateOverlayWidth(width) {
    this.dialog.style.width = `${width}px`;
    this.updateOverlay();
  }
  async handleVisibilityChanged(action) {
    var _a;
    const oldVisibility = this.visible;
    this.visible = await action();
    if (oldVisibility !== this.visible) {
      (_a = this.visibilityChangeObserver) === null || _a === void 0 ? void 0 : _a.call(this, this.visible);
    }
  }
  setupFocusObserver() {
    document.addEventListener('focusin', (event) => this.handleFocus(event));
  }
  removeFocusObserver() {
    document.removeEventListener('focusin', (event) => this.handleFocus(event));
  }
  handleFocus(event) {
    var _a;
    const oldFocusState = this.isFocussed;
    this.isFocussed = event.relatedTarget === this.dialog.parentNode || event.target === this.dialog.parentNode;
    if (oldFocusState != this.isFocussed) {
      (_a = this.focusChangeObserver) === null || _a === void 0 ? void 0 : _a.call(this, this.isFocussed);
    }
  }
  setupScrollObserver() {
    window.addEventListener('scroll', () => this.updateOverlay());
    window.addEventListener('wheel', () => this.updateOverlay());
  }
  removeScrollObserver() {
    window.removeEventListener('scroll', () => this.updateOverlay());
    window.removeEventListener('wheel', () => this.updateOverlay());
  }
  setupMutationObserver() {
    this.resizeObserver = new ResizeObserver((entries) => {
      entries.forEach((_) => {
        this.updateOverlay();
      });
    });
    this.resizeObserver.observe(this.dialog);
  }
  removeMutationObserver() {
    var _a;
    (_a = this.resizeObserver) === null || _a === void 0 ? void 0 : _a.disconnect();
  }
  updateOverlay() {
    window.requestAnimationFrame(() => this.overlay.update());
  }
}

