/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
import { p as proxyCustomElement, H, c as createEvent, h, b as Host } from './p-6fc5b736.js';
import { c as createDate } from './p-9dead869.js';
import { r as requiredArgs, t as toDate, L as LOCALE_MAP, s as state, D as DEFAULT_LOCALE } from './p-d4c86b19.js';
import { f as format } from './p-98fe95a7.js';
import { s as setMonth, g as getDaysInMonth } from './p-ec555305.js';
import { a as isBefore, i as isAfter } from './p-15f94564.js';

/**
 * @name isSameMonth
 * @category Month Helpers
 * @summary Are the given dates in the same month (and year)?
 *
 * @description
 * Are the given dates in the same month (and year)?
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * @param {Date|Number} dateLeft - the first date to check
 * @param {Date|Number} dateRight - the second date to check
 * @returns {Boolean} the dates are in the same month (and year)
 * @throws {TypeError} 2 arguments required
 *
 * @example
 * // Are 2 September 2014 and 25 September 2014 in the same month?
 * var result = isSameMonth(new Date(2014, 8, 2), new Date(2014, 8, 25))
 * //=> true
 *
 * @example
 * // Are 2 September 2014 and 25 September 2015 in the same month?
 * var result = isSameMonth(new Date(2014, 8, 2), new Date(2015, 8, 25))
 * //=> false
 */

function isSameMonth(dirtyDateLeft, dirtyDateRight) {
  requiredArgs(2, arguments);
  var dateLeft = toDate(dirtyDateLeft);
  var dateRight = toDate(dirtyDateRight);
  return dateLeft.getFullYear() === dateRight.getFullYear() && dateLeft.getMonth() === dateRight.getMonth();
}

/**
 * @name isSameYear
 * @category Year Helpers
 * @summary Are the given dates in the same year?
 *
 * @description
 * Are the given dates in the same year?
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * @param {Date|Number} dateLeft - the first date to check
 * @param {Date|Number} dateRight - the second date to check
 * @returns {Boolean} the dates are in the same year
 * @throws {TypeError} 2 arguments required
 *
 * @example
 * // Are 2 September 2014 and 25 September 2014 in the same year?
 * var result = isSameYear(new Date(2014, 8, 2), new Date(2014, 8, 25))
 * //=> true
 */

function isSameYear(dirtyDateLeft, dirtyDateRight) {
  requiredArgs(2, arguments);
  var dateLeft = toDate(dirtyDateLeft);
  var dateRight = toDate(dirtyDateRight);
  return dateLeft.getFullYear() === dateRight.getFullYear();
}

const yearMonthCss = "/*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2022 Robert Bosch GmbH Copyright (C) 2022 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n */@font-face{font-family:\"Bosch-Sans\";font-weight:400;src:url(\"..//fonts/BoschSans-Regular.eot\");src:url(\"..//fonts/BoschSans-Regular.eot?#iefix\") format(\"embedded-opentype\"), url(\"..//fonts/BoschSans-Regular.woff2\") format(\"woff2\"), url(\"..//fonts/BoschSans-Regular.woff\") format(\"woff\"), url(\"..//fonts/BoschSans-Regular.ttf\") format(\"truetype\"), url(\"..//fonts/BoschSans-RegularItalic.woff2\") format(\"woff2\"), url(\"..//fonts/BoschSans-RegularItalic.woff\") format(\"woff\"), url(\"..//fonts/BoschSans-RegularItalic.ttf\") format(\"truetype\"), url(\"..//fonts/BoschSans-Regular.svg#svgFontName\") format(\"svg\");}@font-face{font-family:\"Bosch-Sans\";font-weight:300;src:url(\"..//fonts/BoschSans-Light.eot\");src:url(\"..//fonts/BoschSans-Light.eot?#iefix\") format(\"embedded-opentype\"), url(\"..//fonts/BoschSans-Light.woff2\") format(\"woff2\"), url(\"..//fonts/BoschSans-Light.woff\") format(\"woff\"), url(\"..//fonts/BoschSans-Light.ttf\") format(\"truetype\"), url(\"..//fonts/BoschSans-LightItalic.woff2\") format(\"woff2\"), url(\"..//fonts/BoschSans-LightItalic.woff\") format(\"woff\"), url(\"..//fonts/BoschSans-LightItalic.ttf\") format(\"truetype\"), url(\"..//fonts/BoschSans-Light.svg#svgFontName\") format(\"svg\");}@font-face{font-family:\"Bosch-Sans\";font-weight:500;src:url(\"..//fonts/BoschSans-Medium.eot\");src:url(\"..//fonts/BoschSans-Medium.eot?#iefix\") format(\"embedded-opentype\"), url(\"..//fonts/BoschSans-Medium.woff2\") format(\"woff2\"), url(\"..//fonts/BoschSans-Medium.woff\") format(\"woff\"), url(\"..//fonts/BoschSans-Medium.ttf\") format(\"truetype\"), url(\"..//fonts/BoschSans-MediumItalic.woff2\") format(\"woff2\"), url(\"..//fonts/BoschSans-MediumItalic.woff\") format(\"woff\"), url(\"..//fonts/BoschSans-MediumItalic.ttf\") format(\"truetype\"), url(\"..//fonts/BoschSans-Medium.svg#svgFontName\") format(\"svg\");}@font-face{font-family:\"Bosch-Sans\";font-weight:700;src:url(\"..//fonts/BoschSans-Bold.eot\");src:url(\"..//fonts/BoschSans-Bold.eot?#iefix\") format(\"embedded-opentype\"), url(\"..//fonts/BoschSans-Bold.woff2\") format(\"woff2\"), url(\"..//fonts/BoschSans-Bold.woff\") format(\"woff\"), url(\"..//fonts/BoschSans-Bold.ttf\") format(\"truetype\"), url(\"..//fonts/BoschSans-BoldItalic.woff2\") format(\"woff2\"), url(\"..//fonts/BoschSans-BoldItalic.woff\") format(\"woff\"), url(\"..//fonts/BoschSans-BoldItalic.ttf\") format(\"truetype\"), url(\"..//fonts/BoschSans-Bold.svg#svgFontName\") format(\"svg\");}@font-face{font-family:\"Bosch-Sans\";font-weight:900;src:url(\"..//fonts/BoschSans-Black.eot\");src:url(\"..//fonts/BoschSans-Black.eot?#iefix\") format(\"embedded-opentype\"), url(\"..//fonts/BoschSans-Black.woff2\") format(\"woff2\"), url(\"..//fonts/BoschSans-Black.woff\") format(\"woff\"), url(\"..//fonts/BoschSans-Black.ttf\") format(\"truetype\"), url(\"..//fonts/BoschSans-BlackItalic.woff2\") format(\"woff2\"), url(\"..//fonts/BoschSans-BlackItalic.woff\") format(\"woff\"), url(\"..//fonts/BoschSans-BlackItalic.ttf\") format(\"truetype\"), url(\"..//fonts/BoschSans-Black.svg#svgFontName\") format(\"svg\");}@font-face{font-family:\"Bosch-Ic\";font-style:normal;font-stretch:normal;font-weight:normal;src:url(\"..//fonts/Bosch-Icon.eot?mh5qa9\");src:url(\"..//fonts/Bosch-Icon.eot?mh5qa9#iefix\") format(\"embedded-opentype\"), url(\"..//fonts/Bosch-Icon.ttf?mh5qa9\") format(\"truetype\"), url(\"..//fonts/Bosch-Icon.woff?mh5qa9\") format(\"woff\"), url(\"..//fonts/Bosch-Icon.svg?mh5qa9#Bosch-Icon\") format(\"svg\")}@font-face{font-family:\"Bosch-Sans-Condensed\";font-weight:300;src:url(\"..//fonts/BoschSansCond-Regular.otf\"), url(\"..//fonts/BoschSansCondensed-Regular.ttf\") format(\"truetype\"), url(\"..//fonts/BoschSansCondensed-RegularItalic.ttf\") format(\"truetype\")}@font-face{font-family:\"Bosch-Sans-Condensed\";font-weight:700;src:url(\"..//fonts/BoschSansCond-Bold.otf\"), url(\"..//fonts/BoschSansCondensed-Bold.ttf\") format(\"truetype\"), url(\"..//fonts/BoschSansCondensed-BoldItalic.ttf\") format(\"truetype\")}/*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2018 Robert Bosch GmbH Copyright (C) 2018 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2018 Robert Bosch GmbH Copyright (C) 2018 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2022 Robert Bosch GmbH Copyright (C) 2022 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2018 Robert Bosch GmbH Copyright (C) 2018 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2018 Robert Bosch GmbH Copyright (C) 2018 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2022 Robert Bosch GmbH Copyright (C) 2022 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2022 Robert Bosch GmbH Copyright (C) 2022 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2018 Robert Bosch GmbH Copyright (C) 2018 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2020 Robert Bosch GmbH Copyright (C) 2020 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2022 Robert Bosch GmbH Copyright (C) 2022 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2022 Robert Bosch GmbH Copyright (C) 2022 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2023 Robert Bosch GmbH Copyright (C) 2023 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n */.flex-column{display:flex;flex-direction:column;box-sizing:border-box}.flex-row{display:flex;flex-direction:row;box-sizing:border-box}.flex-none{flex:0 0 auto}.flex-grow{flex:1 1 100%;height:100%}.flex-layout-start-strech{place-content:stretch flex-start;align-items:stretch}.flex-layout-center-center{place-content:center;align-items:center}.flex-fill{width:100%;box-sizing:border-box;max-width:100%}.flex-row-wrap{flex-flow:row wrap;box-sizing:border-box;display:flex}.flex-row-wrap.grow{flex:1 1 100%;max-width:100%}.flex-center{display:flex;justify-content:center;align-items:center}.flex-space-between{display:flex;justify-content:space-between;align-items:center}/*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n */.clickable-element{transition:0.4s;cursor:pointer}.clickable-element:active,.clickable-element.active{color:#007bc0}.clickable-element:active:hover,.clickable-element:hover .clickable-element:focus{color:#9dc9ff}.clickable-element:disabled,.clickable-element.disabled{color:#a4abb3}.clickable-element:disabled:active,.clickable-element:disabled.active,.clickable-element:disabled:active:hover,.clickable-element:disabled:hover,.clickable-element.disabled:active,.clickable-element.disabled.active,.clickable-element.disabled:active:hover,.clickable-element.disabled:hover{color:#a4abb3}button.button-primary,button.button-default,input.button-primary,input.button-default{color:#ffffff;font-family:\"Bosch-Sans\";font-weight:400;font-size:16px;height:48px;padding:0px 16px;display:inline-flex;justify-content:center;align-items:center;gap:8px;cursor:pointer;width:auto;background-color:#007bc0;background-size:100% 200%;border-width:0;border-color:transparent;border-style:solid;-webkit-border-radius:0;-moz-border-radius:0;-ms-border-radius:0;border-radius:0}button.button-primary:hover,button.button-primary:focus-visible,button.button-default:hover,button.button-default:focus-visible,input.button-primary:hover,input.button-primary:focus-visible,input.button-default:hover,input.button-default:focus-visible{background-color:#00629a;color:#ffffff;outline:0}button.button-primary:active,button.button-default:active,input.button-primary:active,input.button-default:active{background-color:#004975;color:#ffffff;outline:0}button.button-primary:disabled,button.button-primary.disabled,button.button-default:disabled,button.button-default.disabled,input.button-primary:disabled,input.button-primary.disabled,input.button-default:disabled,input.button-default.disabled{background-color:#c1c7cc;color:#656a6f;background-image:none;cursor:default}button.button-primary.button-lg,button.button-default.button-lg,input.button-primary.button-lg,input.button-default.button-lg{font-family:\"Bosch-Sans\";font-weight:400;font-size:20px;height:48px;padding:0 24px 0 24px;display:inline-flex;justify-content:center;align-items:center;gap:8px;cursor:pointer;width:auto}button.button-primary.button-sm,button.button-default.button-sm,input.button-primary.button-sm,input.button-default.button-sm{font-family:\"Bosch-Sans\";font-weight:400;font-size:12px;height:48px;padding:0 12px 0 12px;display:inline-flex;justify-content:center;align-items:center;gap:8px;cursor:pointer;width:auto}button.button-primary.button-xs,button.button-default.button-xs,input.button-primary.button-xs,input.button-default.button-xs{font-family:\"Bosch-Sans\";font-weight:400;font-size:10px;height:48px;padding:0 12px 0 12px;display:inline-flex;justify-content:center;align-items:center;gap:8px;cursor:pointer;width:auto}button.button-primary:not(.mat-icon-button):has(mat-icon),button.button-default:not(.mat-icon-button):has(mat-icon),input.button-primary:not(.mat-icon-button):has(mat-icon),input.button-default:not(.mat-icon-button):has(mat-icon){padding:0px 16px 0px 14px}button.button-primary.mat-icon-button,button.button-default.mat-icon-button,input.button-primary.mat-icon-button,input.button-default.mat-icon-button{padding:12px}button.button-secondary,input.button-secondary{color:#007bc0;background-color:transparent;font-family:\"Bosch-Sans\";font-weight:400;font-size:16px;height:48px;padding:0px 15px;display:inline-flex;justify-content:center;align-items:center;gap:8px;cursor:pointer;width:auto;border-width:1px;border-color:#007bc0;border-style:solid;-webkit-border-radius:0;-moz-border-radius:0;-ms-border-radius:0;border-radius:0}button.button-secondary:hover,button.button-secondary:focus-visible,input.button-secondary:hover,input.button-secondary:focus-visible{border-color:#004975;outline:0;color:#004975;background-color:#d1e4ff;border-width:1px;border-color:#004975;border-style:solid;-webkit-border-radius:0;-moz-border-radius:0;-ms-border-radius:0;border-radius:0}button.button-secondary:active,input.button-secondary:active{border-color:#004975;color:#004975;outline:0;background-color:#9dc9ff;border-width:1px;border-color:#004975;border-style:solid;-webkit-border-radius:0;-moz-border-radius:0;-ms-border-radius:0;border-radius:0}button.button-secondary:disabled,button.button-secondary.disabled,input.button-secondary:disabled,input.button-secondary.disabled{color:#979ea4;border-color:#979ea4;background-color:transparent;cursor:default}button.button-secondary.button-lg,input.button-secondary.button-lg{font-family:\"Bosch-Sans\";font-weight:400;font-size:20px;height:48px;padding:0 24px 0 24px;display:inline-flex;justify-content:center;align-items:center;gap:8px;cursor:pointer;width:auto}button.button-secondary.button-sm,input.button-secondary.button-sm{font-family:\"Bosch-Sans\";font-weight:400;font-size:12px;height:48px;padding:0 12px 0 12px;display:inline-flex;justify-content:center;align-items:center;gap:8px;cursor:pointer;width:auto}button.button-secondary.button-xs,input.button-secondary.button-xs{font-family:\"Bosch-Sans\";font-weight:400;font-size:10px;height:48px;padding:0 12px 0 12px;display:inline-flex;justify-content:center;align-items:center;gap:8px;cursor:pointer;width:auto}button.button-secondary:not(.mat-icon-button):has(mat-icon),input.button-secondary:not(.mat-icon-button):has(mat-icon){padding:0 15px 0 13px}button.button-secondary.mat-icon-button,input.button-secondary.mat-icon-button{padding:11px}button.button-tertiary,input.button-tertiary{color:#007bc0;background-color:transparent;font-family:\"Bosch-Sans\";font-weight:400;font-size:16px;height:48px;padding:0px 16px;display:inline-flex;justify-content:center;align-items:center;gap:8px;cursor:pointer;width:auto;border-style:none}button.button-tertiary:hover,button.button-tertiary:focus-visible,input.button-tertiary:hover,input.button-tertiary:focus-visible{outline:0;color:#00629a;background-color:#d1e4ff}button.button-tertiary:active,input.button-tertiary:active{color:#004975;background-color:#9dc9ff;outline:0}button.button-tertiary:disabled,button.button-tertiary.disabled,input.button-tertiary:disabled,input.button-tertiary.disabled{color:#979ea4;background-color:transparent;cursor:default}button.button-tertiary.button-lg,input.button-tertiary.button-lg{font-family:\"Bosch-Sans\";font-weight:400;font-size:20px;height:48px;padding:0 24px 0 24px;display:inline-flex;justify-content:center;align-items:center;gap:8px;cursor:pointer;width:auto}button.button-tertiary.button-sm,input.button-tertiary.button-sm{font-family:\"Bosch-Sans\";font-weight:400;font-size:12px;height:48px;padding:0 12px 0 12px;display:inline-flex;justify-content:center;align-items:center;gap:8px;cursor:pointer;width:auto}button.button-tertiary.button-xs,input.button-tertiary.button-xs{font-family:\"Bosch-Sans\";font-weight:400;font-size:10px;height:48px;padding:0 12px 0 12px;display:inline-flex;justify-content:center;align-items:center;gap:8px;cursor:pointer;width:auto}button.button-tertiary:not(.mat-icon-button):has(mat-icon),input.button-tertiary:not(.mat-icon-button):has(mat-icon){padding:0px 16px 0px 14px}button.button-tertiary.mat-icon-button,input.button-tertiary.mat-icon-button{padding:12px}button.button-integrated,input.button-integrated{color:#000000;background-color:transparent;font-family:\"Bosch-Sans\";font-weight:400;font-size:16px;height:48px;padding:0px 16px;display:inline-flex;justify-content:center;align-items:center;gap:8px;cursor:pointer;width:auto;border-style:none}button.button-integrated:hover,button.button-integrated:focus-visible,input.button-integrated:hover,input.button-integrated:focus-visible{color:#007bc0;outline:0}button.button-integrated:active,input.button-integrated:active{color:#00629a;outline:0}button.button-integrated:disabled,button.button-integrated.disabled,input.button-integrated:disabled,input.button-integrated.disabled{color:#979ea4 !important;background-color:transparent;cursor:default}button.button-integrated:not(.mat-icon-button):has(mat-icon),input.button-integrated:not(.mat-icon-button):has(mat-icon){padding:0px 16px 0px 14px}button.button-integrated.mat-icon-button,input.button-integrated.mat-icon-button{padding:12px}button.button-link,input.button-link{color:#007bc0;background-color:transparent;border:none;-webkit-box-shadow:none;box-shadow:none;font-family:\"Bosch-Sans\";font-weight:400;font-size:16px;height:48px;padding:0 16px 0 16px;display:inline-flex;justify-content:center;align-items:center;gap:8px;cursor:pointer;width:auto}button.button-link::after,input.button-link::after{position:absolute;font-family:\"Bosch-Ic\";font-style:normal;font-weight:normal;font-size:18px;content:\"\\e181\";-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}button.button-link:hover,button.button-link:focus-visible,input.button-link:hover,input.button-link:focus-visible{color:#00629a;text-decoration:underline;outline:0}button.button-link:active,input.button-link:active{color:#004975;text-decoration:underline}button.button-link.disabled,button.button-link[disabled],button.button-link fieldset[disabled],input.button-link.disabled,input.button-link[disabled],input.button-link fieldset[disabled]{color:#c1c7cc;text-decoration:none;-webkit-transition:none;-o-transition:none;transition:none}button.button-link.disabled::after,button.button-link[disabled]::after,button.button-link fieldset[disabled]::after,input.button-link.disabled::after,input.button-link[disabled]::after,input.button-link fieldset[disabled]::after{-webkit-transform:translate(0, 0);-ms-transform:translate(0, 0);-o-transform:translate(0, 0);transform:translate(0, 0)}button.button-link.button-lg,input.button-link.button-lg{font-family:\"Bosch-Sans\";font-weight:400;font-size:20px;height:48px;padding:0 24px 0 24px;display:inline-flex;justify-content:center;align-items:center;gap:8px;cursor:pointer;width:auto}button.button-link.button-lg::after,input.button-link.button-lg::after{font-size:22px}button.button-link.button-sm,input.button-link.button-sm{font-family:\"Bosch-Sans\";font-weight:400;font-size:14px;height:48px;padding:0 12px 0 12px;display:inline-flex;justify-content:center;align-items:center;gap:8px;cursor:pointer;width:auto}button.button-link.button-sm::after,input.button-link.button-sm::after{font-size:14px}button.button-link.no-arrow::after,input.button-link.no-arrow::after{content:\"\"}button.button-link:not(.mat-icon-button):has(mat-icon),input.button-link:not(.mat-icon-button):has(mat-icon){padding:0px 16px 0px 14px}button.button-link.mat-icon-button,input.button-link.mat-icon-button{padding:12px}button.button-block,input[type=submit].button-block,input[type=reset].button-block,input[type=button].button-block{display:block;width:100%}/*!\n *  Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2018 Robert Bosch GmbH Copyright (C) 2018 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2018 Robert Bosch GmbH Copyright (C) 2018 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2022 Robert Bosch GmbH Copyright (C) 2022 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2018 Robert Bosch GmbH Copyright (C) 2018 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2018 Robert Bosch GmbH Copyright (C) 2018 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2022 Robert Bosch GmbH Copyright (C) 2022 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2022 Robert Bosch GmbH Copyright (C) 2022 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2018 Robert Bosch GmbH Copyright (C) 2018 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2020 Robert Bosch GmbH Copyright (C) 2020 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2022 Robert Bosch GmbH Copyright (C) 2022 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2022 Robert Bosch GmbH Copyright (C) 2022 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2023 Robert Bosch GmbH Copyright (C) 2023 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n */bci-year-month{width:100%;height:100%}.year-month-grid{width:100%;height:100%;padding:16px;display:flex;box-sizing:border-box;flex-direction:column;justify-content:space-between}.year-month-grid .row{width:100%;display:flex;align-items:center;justify-content:space-between}.year-month-grid .row .selection-chip{width:60px;height:30px;font-size:16px;background:transparent;display:grid;place-items:center;line-height:1.5;border:none;border-radius:15px;cursor:pointer;outline:none;user-select:none}.year-month-grid .row .selection-chip:hover,.year-month-grid .row .selection-chip:focus{background:#e0e2e5}.year-month-grid .row .selection-chip:active{background:#c1c7cc}.year-month-grid .row .selection-chip.today{border:1px solid #000000}.year-month-grid .row .selection-chip.selected{background:#007bc0;color:white;border:none}.year-month-grid .row .selection-chip.selected:hover,.year-month-grid .row .selection-chip.selected:focus{background:#00629a}.year-month-grid .row .selection-chip.selected:active{background:#004975}.year-month-grid .row .selection-chip:disabled{pointer-events:none;color:#c1c7cc}.year-month-grid .row .selection-chip:disabled.today{border-color:#c1c7cc}.year-month-grid .row .selection-chip:disabled.selected{background:#c1c7cc;color:#8a9097}";

/** number of years displayed per page */
const YEAR_PAGE_SIZE = 20;
/** Where the currently selected year is displayed on the yearSelection Page. 0-based. */
const SELECTED_YEAR_SPOT = 9;
const YearMonthSelection = /*@__PURE__*/ proxyCustomElement(class extends H {
  constructor() {
    super();
    this.__registerHost();
    this.yearMonthSelected = createEvent(this, "yearMonthSelected", 7);
  }
  handleSelectionStepChange(newValue, oldValue) {
    // Reopen of YearMonthSelection
    if (!oldValue && !!newValue) {
      this.displayedYears = this.getDisplayedYearsFromYear(this.dateObj.calendarDateYear);
    }
  }
  handleSelectionPageChange(newValue) {
    this.displayedYears = this.getDisplayedYearsFromYear(this.dateObj.calendarDateYear + newValue * YEAR_PAGE_SIZE);
  }
  getDisplayedYearsFromYear(year) {
    const yearsBefore = [];
    for (let i = year - SELECTED_YEAR_SPOT; i < year; i++) {
      yearsBefore.push(i);
    }
    const yearsAfter = [];
    for (let i = year + 1; i < year + (YEAR_PAGE_SIZE - SELECTED_YEAR_SPOT); i++) {
      yearsAfter.push(i);
    }
    const years = [...yearsBefore, year, ...yearsAfter];
    return this.createGrid(years, YEAR_PAGE_SIZE, 4);
  }
  get months() {
    const locale = { locale: LOCALE_MAP[state.language || DEFAULT_LOCALE.language] };
    const months = [];
    for (let i = 0; i < 12; i++) {
      months.push(format(setMonth(new Date(), i), 'LLL', locale));
    }
    return this.createGrid(months, 12, 3);
  }
  // use generics here because years are numbers and months are strings
  createGrid(array, gridItems, rowSize) {
    const grid = [];
    for (let i = 0; i < gridItems; i += rowSize) {
      const row = array.slice(i, i + rowSize);
      grid.push(row);
    }
    return grid;
  }
  handleMonthClick(monthIndex) {
    this.yearMonthSelected.emit({ selectedYearMonth: monthIndex });
  }
  handleYearClick(year) {
    this.yearMonthSelected.emit({ selectedYearMonth: year });
  }
  render() {
    const selectedYear = this.dateObj.calendarDateYear;
    const selectedMonth = this.dateObj.calendarDateMonth;
    const selectionAsDate = createDate(new Date(), selectedYear, selectedMonth);
    return (h(Host, null, this.selectionStep === 'year' ? (h("div", { class: "year-month-grid" }, this.displayedYears.map((yearRow) => (h("div", { class: "row" }, yearRow.map((year) => {
      const selected = isSameYear(createDate(new Date(), year, 0), selectionAsDate);
      const isTodaysDate = isSameYear(createDate(new Date(), year, 0), new Date());
      const notInRange = isBefore(createDate(new Date(), year, 0, 1), this.minDate) ||
        isAfter(createDate(new Date(), year, 11, getDaysInMonth(new Date(year, 11))), this.maxDate);
      const buttonClasses = {
        'selection-chip': true,
        selected,
        today: isTodaysDate,
      };
      return (h("button", { class: buttonClasses, "aria-label": `Select Year ${year}`, key: year, disabled: notInRange, onClick: () => this.handleYearClick(year) }, year));
    })))))) : this.selectionStep === 'month' ? (h("div", { class: "year-month-grid" }, this.months.map((monthRow, rowI) => (h("div", { class: "row" }, monthRow.map((month, monthI) => {
      const monthIndex = rowI * (this.months.length - 1) + monthI;
      const selected = isSameMonth(createDate(new Date(), selectedYear, monthIndex), selectionAsDate);
      const isTodaysDate = isSameMonth(createDate(new Date(), selectedYear, monthIndex), new Date());
      const notInRange = isBefore(createDate(new Date(), selectedYear, monthIndex, 1), this.minDate) ||
        isAfter(createDate(new Date(), selectedYear, monthIndex, getDaysInMonth(new Date(selectedYear, monthIndex))), this.maxDate);
      const buttonClasses = {
        'selection-chip': true,
        selected,
        today: isTodaysDate,
      };
      return (h("button", { class: buttonClasses, "aria-label": `Select Month ${month}`, disabled: notInRange, onClick: () => this.handleMonthClick(monthIndex), key: month }, month));
    })))))) : undefined));
  }
  static get watchers() { return {
    "selectionStep": ["handleSelectionStepChange"],
    "yearSelectionPageOffset": ["handleSelectionPageChange"]
  }; }
  static get style() { return yearMonthCss; }
}, [0, "bci-year-month", {
    "selectionStep": [1, "selection-step"],
    "yearSelectionPageOffset": [2, "year-selection-page-offset"],
    "dateObj": [8, "date-obj"],
    "minDate": [2, "min-date"],
    "maxDate": [2, "max-date"],
    "displayedYears": [32]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["bci-year-month"];
  components.forEach(tagName => { switch (tagName) {
    case "bci-year-month":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, YearMonthSelection);
      }
      break;
  } });
}

export { YearMonthSelection as Y, defineCustomElement as d };

