/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
import { g as e, f as t } from "./p-b4277e0d.js";

function toInteger(e) {
  if (null === e || !0 === e || !1 === e) return NaN;
  var t = Number(e);
  return isNaN(t) ? t : t < 0 ? Math.ceil(t) : Math.floor(t);
}

function requiredArgs(e, t) {
  if (t.length < e) throw new TypeError(e + " argument" + (e > 1 ? "s" : "") + " required, but only " + t.length + " present");
}

/**
 * @name toDate
 * @category Common Helpers
 * @summary Convert the given argument to an instance of Date.
 *
 * @description
 * Convert the given argument to an instance of Date.
 *
 * If the argument is an instance of Date, the function returns its clone.
 *
 * If the argument is a number, it is treated as a timestamp.
 *
 * If the argument is none of the above, the function returns Invalid Date.
 *
 * **Note**: *all* Date arguments passed to any *date-fns* function is processed by `toDate`.
 *
 * @param {Date|Number} argument - the value to convert
 * @returns {Date} the parsed date in the local time zone
 * @throws {TypeError} 1 argument required
 *
 * @example
 * // Clone the date:
 * const result = toDate(new Date(2014, 1, 11, 11, 30, 30))
 * //=> Tue Feb 11 2014 11:30:30
 *
 * @example
 * // Convert the timestamp to date:
 * const result = toDate(1392098430000)
 * //=> Tue Feb 11 2014 11:30:30
 */ function toDate(e) {
  requiredArgs(1, arguments);
  var t = Object.prototype.toString.call(e);
 // Clone the date
    return e instanceof Date || "object" == typeof e && "[object Date]" === t ? new Date(e.getTime()) : "number" == typeof e || "[object Number]" === t ? new Date(e) : ("string" != typeof e && "[object String]" !== t || "undefined" == typeof console || (
  // eslint-disable-next-line no-console
  console.warn("Starting with v2.0.0-beta.1 date-fns doesn't accept strings as date arguments. Please use `parseISO` to parse strings. See: https://git.io/fjule"), 
  // eslint-disable-next-line no-console
  console.warn((new Error).stack)), new Date(NaN));
}

/**
 * @name addDays
 * @category Day Helpers
 * @summary Add the specified number of days to the given date.
 *
 * @description
 * Add the specified number of days to the given date.
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * @param {Date|Number} date - the date to be changed
 * @param {Number} amount - the amount of days to be added. Positive decimals will be rounded using `Math.floor`, decimals less than zero will be rounded using `Math.ceil`.
 * @returns {Date} - the new date with the days added
 * @throws {TypeError} - 2 arguments required
 *
 * @example
 * // Add 10 days to 1 September 2014:
 * const result = addDays(new Date(2014, 8, 1), 10)
 * //=> Thu Sep 11 2014 00:00:00
 */ function addDays(e, t) {
  requiredArgs(2, arguments);
  var a = toDate(e), n = toInteger(t);
  return isNaN(n) ? new Date(NaN) : n ? (a.setDate(a.getDate() + n), a) : a;
}

/**
 * @name addMilliseconds
 * @category Millisecond Helpers
 * @summary Add the specified number of milliseconds to the given date.
 *
 * @description
 * Add the specified number of milliseconds to the given date.
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * @param {Date|Number} date - the date to be changed
 * @param {Number} amount - the amount of milliseconds to be added. Positive decimals will be rounded using `Math.floor`, decimals less than zero will be rounded using `Math.ceil`.
 * @returns {Date} the new date with the milliseconds added
 * @throws {TypeError} 2 arguments required
 *
 * @example
 * // Add 750 milliseconds to 10 July 2014 12:45:30.000:
 * const result = addMilliseconds(new Date(2014, 6, 10, 12, 45, 30, 0), 750)
 * //=> Thu Jul 10 2014 12:45:30.750
 */ function addMilliseconds(e, t) {
  requiredArgs(2, arguments);
  var a = toDate(e).getTime(), n = toInteger(t);
  return new Date(a + n);
}

/**
 * Google Chrome as of 67.0.3396.87 introduced timezones with offset that includes seconds.
 * They usually appear for dates that denote time before the timezones were introduced
 * (e.g. for 'Europe/Prague' timezone the offset is GMT+00:57:44 before 1 October 1891
 * and GMT+01:00:00 after that date)
 *
 * Date#getTimezoneOffset returns the offset in minutes and would return 57 for the example above,
 * which would lead to incorrect calculations.
 *
 * This function returns the timezone offset in milliseconds that takes seconds in account.
 */ function getTimezoneOffsetInMilliseconds(e) {
  var t = new Date(Date.UTC(e.getFullYear(), e.getMonth(), e.getDate(), e.getHours(), e.getMinutes(), e.getSeconds(), e.getMilliseconds()));
  return t.setUTCFullYear(e.getFullYear()), e.getTime() - t.getTime();
}

/**
 * @name startOfDay
 * @category Day Helpers
 * @summary Return the start of a day for the given date.
 *
 * @description
 * Return the start of a day for the given date.
 * The result will be in the local timezone.
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * @param {Date|Number} date - the original date
 * @returns {Date} the start of a day
 * @throws {TypeError} 1 argument required
 *
 * @example
 * // The start of a day for 2 September 2014 11:55:00:
 * const result = startOfDay(new Date(2014, 8, 2, 11, 55, 0))
 * //=> Tue Sep 02 2014 00:00:00
 */ function startOfDay(e) {
  requiredArgs(1, arguments);
  var t = toDate(e);
  return t.setHours(0, 0, 0, 0), t;
}

/**
 * @name differenceInCalendarDays
 * @category Day Helpers
 * @summary Get the number of calendar days between the given dates.
 *
 * @description
 * Get the number of calendar days between the given dates. This means that the times are removed
 * from the dates and then the difference in days is calculated.
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * @param {Date|Number} dateLeft - the later date
 * @param {Date|Number} dateRight - the earlier date
 * @returns {Number} the number of calendar days
 * @throws {TypeError} 2 arguments required
 *
 * @example
 * // How many calendar days are between
 * // 2 July 2011 23:00:00 and 2 July 2012 00:00:00?
 * const result = differenceInCalendarDays(
 *   new Date(2012, 6, 2, 0, 0),
 *   new Date(2011, 6, 2, 23, 0)
 * )
 * //=> 366
 * // How many calendar days are between
 * // 2 July 2011 23:59:00 and 3 July 2011 00:01:00?
 * const result = differenceInCalendarDays(
 *   new Date(2011, 6, 3, 0, 1),
 *   new Date(2011, 6, 2, 23, 59)
 * )
 * //=> 1
 */
function differenceInCalendarDays(e, t) {
  requiredArgs(2, arguments);
  var a = startOfDay(e), n = startOfDay(t), i = a.getTime() - getTimezoneOffsetInMilliseconds(a), r = n.getTime() - getTimezoneOffsetInMilliseconds(n);
  // Round the number of days to the nearest integer
  // because the number of milliseconds in a day is not constant
  // (e.g. it's different in the day of the daylight saving time clock shift)
  return Math.round((i - r) / 864e5);
}

/**
 * @name isSameDay
 * @category Day Helpers
 * @summary Are the given dates in the same day (and year and month)?
 *
 * @description
 * Are the given dates in the same day (and year and month)?
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * @param {Date|Number} dateLeft - the first date to check
 * @param {Date|Number} dateRight - the second date to check
 * @returns {Boolean} the dates are in the same day (and year and month)
 * @throws {TypeError} 2 arguments required
 *
 * @example
 * // Are 4 September 06:00:00 and 4 September 18:00:00 in the same day?
 * var result = isSameDay(new Date(2014, 8, 4, 6, 0), new Date(2014, 8, 4, 18, 0))
 * //=> true
 * 
 * @example
 * // Are 4 September and 4 October in the same day?
 * var result = isSameDay(new Date(2014, 8, 4), new Date(2014, 9, 4))
 * //=> false
 * 
 * @example
 * // Are 4 September, 2014 and 4 September, 2015 in the same day?
 * var result = isSameDay(new Date(2014, 8, 4), new Date(2015, 8, 4))
 * //=> false
 */ function isSameDay(e, t) {
  requiredArgs(2, arguments);
  var a = startOfDay(e), n = startOfDay(t);
  return a.getTime() === n.getTime();
}

/**
 * @name isDate
 * @category Common Helpers
 * @summary Is the given value a date?
 *
 * @description
 * Returns true if the given value is an instance of Date. The function works for dates transferred across iframes.
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * @param {*} value - the value to check
 * @returns {boolean} true if the given value is a date
 * @throws {TypeError} 1 arguments required
 *
 * @example
 * // For a valid date:
 * const result = isDate(new Date())
 * //=> true
 *
 * @example
 * // For an invalid date:
 * const result = isDate(new Date(NaN))
 * //=> true
 *
 * @example
 * // For some value:
 * const result = isDate('2014-02-31')
 * //=> false
 *
 * @example
 * // For an object:
 * const result = isDate({})
 * //=> false
 */ function isDate(e) {
  return requiredArgs(1, arguments), e instanceof Date || "object" == typeof e && "[object Date]" === Object.prototype.toString.call(e);
}

/**
 * @name isValid
 * @category Common Helpers
 * @summary Is the given date valid?
 *
 * @description
 * Returns false if argument is Invalid Date and true otherwise.
 * Argument is converted to Date using `toDate`. See [toDate]{@link https://date-fns.org/docs/toDate}
 * Invalid Date is a Date, whose time value is NaN.
 *
 * Time value of Date: http://es5.github.io/#x15.9.1.1
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * - Now `isValid` doesn't throw an exception
 *   if the first argument is not an instance of Date.
 *   Instead, argument is converted beforehand using `toDate`.
 *
 *   Examples:
 *
 *   | `isValid` argument        | Before v2.0.0 | v2.0.0 onward |
 *   |---------------------------|---------------|---------------|
 *   | `new Date()`              | `true`        | `true`        |
 *   | `new Date('2016-01-01')`  | `true`        | `true`        |
 *   | `new Date('')`            | `false`       | `false`       |
 *   | `new Date(1488370835081)` | `true`        | `true`        |
 *   | `new Date(NaN)`           | `false`       | `false`       |
 *   | `'2016-01-01'`            | `TypeError`   | `false`       |
 *   | `''`                      | `TypeError`   | `false`       |
 *   | `1488370835081`           | `TypeError`   | `true`        |
 *   | `NaN`                     | `TypeError`   | `false`       |
 *
 *   We introduce this change to make *date-fns* consistent with ECMAScript behavior
 *   that try to coerce arguments to the expected type
 *   (which is also the case with other *date-fns* functions).
 *
 * @param {*} date - the date to check
 * @returns {Boolean} the date is valid
 * @throws {TypeError} 1 argument required
 *
 * @example
 * // For the valid date:
 * const result = isValid(new Date(2014, 1, 31))
 * //=> true
 *
 * @example
 * // For the value, convertable into a date:
 * const result = isValid(1393804800000)
 * //=> true
 *
 * @example
 * // For the invalid date:
 * const result = isValid(new Date(''))
 * //=> false
 */ function isValid(e) {
  if (requiredArgs(1, arguments), !isDate(e) && "number" != typeof e) return !1;
  var t = toDate(e);
  return !isNaN(Number(t));
}

// for accurate equality comparisons of UTC timestamps that end up
// having the same representation in local time, e.g. one hour before
// DST ends vs. the instant that DST ends.
function compareLocalAsc(e, t) {
  var a = e.getFullYear() - t.getFullYear() || e.getMonth() - t.getMonth() || e.getDate() - t.getDate() || e.getHours() - t.getHours() || e.getMinutes() - t.getMinutes() || e.getSeconds() - t.getSeconds() || e.getMilliseconds() - t.getMilliseconds();
  return a < 0 ? -1 : a > 0 ? 1 : a;
}

/**
 * @name differenceInDays
 * @category Day Helpers
 * @summary Get the number of full days between the given dates.
 *
 * @description
 * Get the number of full day periods between two dates. Fractional days are
 * truncated towards zero.
 *
 * One "full day" is the distance between a local time in one day to the same
 * local time on the next or previous day. A full day can sometimes be less than
 * or more than 24 hours if a daylight savings change happens between two dates.
 *
 * To ignore DST and only measure exact 24-hour periods, use this instead:
 * `Math.floor(differenceInHours(dateLeft, dateRight)/24)|0`.
 *
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * @param {Date|Number} dateLeft - the later date
 * @param {Date|Number} dateRight - the earlier date
 * @returns {Number} the number of full days according to the local timezone
 * @throws {TypeError} 2 arguments required
 *
 * @example
 * // How many full days are between
 * // 2 July 2011 23:00:00 and 2 July 2012 00:00:00?
 * const result = differenceInDays(
 *   new Date(2012, 6, 2, 0, 0),
 *   new Date(2011, 6, 2, 23, 0)
 * )
 * //=> 365
 * // How many full days are between
 * // 2 July 2011 23:59:00 and 3 July 2011 00:01:00?
 * const result = differenceInDays(
 *   new Date(2011, 6, 3, 0, 1),
 *   new Date(2011, 6, 2, 23, 59)
 * )
 * //=> 0
 * // How many full days are between
 * // 1 March 2020 0:00 and 1 June 2020 0:00 ?
 * // Note: because local time is used, the
 * // result will always be 92 days, even in
 * // time zones where DST starts and the
 * // period has only 92*24-1 hours.
 * const result = differenceInDays(
 *   new Date(2020, 5, 1),
 *   new Date(2020, 2, 1)
 * )
//=> 92
 */ var a = {
  lessThanXSeconds: {
    one: "less than a second",
    other: "less than {{count}} seconds"
  },
  xSeconds: {
    one: "1 second",
    other: "{{count}} seconds"
  },
  halfAMinute: "half a minute",
  lessThanXMinutes: {
    one: "less than a minute",
    other: "less than {{count}} minutes"
  },
  xMinutes: {
    one: "1 minute",
    other: "{{count}} minutes"
  },
  aboutXHours: {
    one: "about 1 hour",
    other: "about {{count}} hours"
  },
  xHours: {
    one: "1 hour",
    other: "{{count}} hours"
  },
  xDays: {
    one: "1 day",
    other: "{{count}} days"
  },
  aboutXWeeks: {
    one: "about 1 week",
    other: "about {{count}} weeks"
  },
  xWeeks: {
    one: "1 week",
    other: "{{count}} weeks"
  },
  aboutXMonths: {
    one: "about 1 month",
    other: "about {{count}} months"
  },
  xMonths: {
    one: "1 month",
    other: "{{count}} months"
  },
  aboutXYears: {
    one: "about 1 year",
    other: "about {{count}} years"
  },
  xYears: {
    one: "1 year",
    other: "{{count}} years"
  },
  overXYears: {
    one: "over 1 year",
    other: "over {{count}} years"
  },
  almostXYears: {
    one: "almost 1 year",
    other: "almost {{count}} years"
  }
};

function buildFormatLongFn(e) {
  return function() {
    var t = arguments.length > 0 && void 0 !== arguments[0] ? arguments[0] : {}, a = t.width ? String(t.width) : e.defaultWidth, n = e.formats[a] || e.formats[e.defaultWidth];
    // TODO: Remove String()
        return n;
  };
}

var n = {
  date: buildFormatLongFn({
    formats: {
      full: "EEEE, MMMM do, y",
      long: "MMMM do, y",
      medium: "MMM d, y",
      short: "MM/dd/yyyy"
    },
    defaultWidth: "full"
  }),
  time: buildFormatLongFn({
    formats: {
      full: "h:mm:ss a zzzz",
      long: "h:mm:ss a z",
      medium: "h:mm:ss a",
      short: "h:mm a"
    },
    defaultWidth: "full"
  }),
  dateTime: buildFormatLongFn({
    formats: {
      full: "{{date}} 'at' {{time}}",
      long: "{{date}} 'at' {{time}}",
      medium: "{{date}}, {{time}}",
      short: "{{date}}, {{time}}"
    },
    defaultWidth: "full"
  })
}, i = {
  lastWeek: "'last' eeee 'at' p",
  yesterday: "'yesterday at' p",
  today: "'today at' p",
  tomorrow: "'tomorrow at' p",
  nextWeek: "eeee 'at' p",
  other: "P"
};

function buildLocalizeFn(e) {
  return function(t, a) {
    var n, i = a || {};
    if ("formatting" === (i.context ? String(i.context) : "standalone") && e.formattingValues) {
      var r = e.defaultFormattingWidth || e.defaultWidth, o = i.width ? String(i.width) : r;
      n = e.formattingValues[o] || e.formattingValues[r];
    } else {
      var s = e.defaultWidth, d = i.width ? String(i.width) : e.defaultWidth;
      n = e.values[d] || e.values[s];
    }
    // @ts-ignore: For some reason TypeScript just don't want to match it, no matter how hard we try. I challenge you to try to remove it!
    return n[e.argumentCallback ? e.argumentCallback(t) : t];
  };
}

function buildMatchFn(e) {
  return function(t) {
    var a = arguments.length > 1 && void 0 !== arguments[1] ? arguments[1] : {}, n = a.width, i = n && e.matchPatterns[n] || e.matchPatterns[e.defaultMatchWidth], r = t.match(i);
    if (!r) return null;
    var o, s = r[0], d = n && e.parsePatterns[n] || e.parsePatterns[e.defaultParseWidth], u = Array.isArray(d) ? findIndex(d, (function(e) {
      return e.test(s);
    })) : findKey(d, (function(e) {
      return e.test(s);
    }));
    o = e.valueCallback ? e.valueCallback(u) : u, o = a.valueCallback ? a.valueCallback(o) : o;
    var m = t.slice(s.length);
    return {
      value: o,
      rest: m
    };
  };
}

function findKey(e, t) {
  for (var a in e) if (e.hasOwnProperty(a) && t(e[a])) return a;
}

function findIndex(e, t) {
  for (var a = 0; a < e.length; a++) if (t(e[a])) return a;
}

function buildMatchPatternFn(e) {
  return function(t) {
    var a = arguments.length > 1 && void 0 !== arguments[1] ? arguments[1] : {}, n = t.match(e.matchPattern);
    if (!n) return null;
    var i = n[0], r = t.match(e.parsePattern);
    if (!r) return null;
    var o = e.valueCallback ? e.valueCallback(r[0]) : r[0];
    o = a.valueCallback ? a.valueCallback(o) : o;
    var s = t.slice(i.length);
    return {
      value: o,
      rest: s
    };
  };
}

var r = {
  code: "en-US",
  formatDistance: function(e, t, n) {
    var i, r = a[e];
    return i = "string" == typeof r ? r : 1 === t ? r.one : r.other.replace("{{count}}", t.toString()), 
    null != n && n.addSuffix ? n.comparison && n.comparison > 0 ? "in " + i : i + " ago" : i;
  },
  formatLong: n,
  formatRelative: function(e, t, a, n) {
    return i[e];
  },
  localize: {
    ordinalNumber: function(e, t) {
      var a = Number(e), n = a % 100;
 // If ordinal numbers depend on context, for example,
      // if they are different for different grammatical genders,
      // use `options.unit`.
      
      // `unit` can be 'year', 'quarter', 'month', 'week', 'date', 'dayOfYear',
      // 'day', 'hour', 'minute', 'second'.
            if (n > 20 || n < 10) switch (n % 10) {
       case 1:
        return a + "st";

       case 2:
        return a + "nd";

       case 3:
        return a + "rd";
      }
      return a + "th";
    },
    era: buildLocalizeFn({
      values: {
        narrow: [ "B", "A" ],
        abbreviated: [ "BC", "AD" ],
        wide: [ "Before Christ", "Anno Domini" ]
      },
      defaultWidth: "wide"
    }),
    quarter: buildLocalizeFn({
      values: {
        narrow: [ "1", "2", "3", "4" ],
        abbreviated: [ "Q1", "Q2", "Q3", "Q4" ],
        wide: [ "1st quarter", "2nd quarter", "3rd quarter", "4th quarter" ]
      },
      defaultWidth: "wide",
      argumentCallback: function(e) {
        return e - 1;
      }
    }),
    month: buildLocalizeFn({
      values: {
        narrow: [ "J", "F", "M", "A", "M", "J", "J", "A", "S", "O", "N", "D" ],
        abbreviated: [ "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" ],
        wide: [ "January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December" ]
      },
      defaultWidth: "wide"
    }),
    day: buildLocalizeFn({
      values: {
        narrow: [ "S", "M", "T", "W", "T", "F", "S" ],
        short: [ "Su", "Mo", "Tu", "We", "Th", "Fr", "Sa" ],
        abbreviated: [ "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat" ],
        wide: [ "Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday" ]
      },
      defaultWidth: "wide"
    }),
    dayPeriod: buildLocalizeFn({
      values: {
        narrow: {
          am: "a",
          pm: "p",
          midnight: "mi",
          noon: "n",
          morning: "morning",
          afternoon: "afternoon",
          evening: "evening",
          night: "night"
        },
        abbreviated: {
          am: "AM",
          pm: "PM",
          midnight: "midnight",
          noon: "noon",
          morning: "morning",
          afternoon: "afternoon",
          evening: "evening",
          night: "night"
        },
        wide: {
          am: "a.m.",
          pm: "p.m.",
          midnight: "midnight",
          noon: "noon",
          morning: "morning",
          afternoon: "afternoon",
          evening: "evening",
          night: "night"
        }
      },
      defaultWidth: "wide",
      formattingValues: {
        narrow: {
          am: "a",
          pm: "p",
          midnight: "mi",
          noon: "n",
          morning: "in the morning",
          afternoon: "in the afternoon",
          evening: "in the evening",
          night: "at night"
        },
        abbreviated: {
          am: "AM",
          pm: "PM",
          midnight: "midnight",
          noon: "noon",
          morning: "in the morning",
          afternoon: "in the afternoon",
          evening: "in the evening",
          night: "at night"
        },
        wide: {
          am: "a.m.",
          pm: "p.m.",
          midnight: "midnight",
          noon: "noon",
          morning: "in the morning",
          afternoon: "in the afternoon",
          evening: "in the evening",
          night: "at night"
        }
      },
      defaultFormattingWidth: "wide"
    })
  },
  match: {
    ordinalNumber: buildMatchPatternFn({
      matchPattern: /^(\d+)(th|st|nd|rd)?/i,
      parsePattern: /\d+/i,
      valueCallback: function(e) {
        return parseInt(e, 10);
      }
    }),
    era: buildMatchFn({
      matchPatterns: {
        narrow: /^(b|a)/i,
        abbreviated: /^(b\.?\s?c\.?|b\.?\s?c\.?\s?e\.?|a\.?\s?d\.?|c\.?\s?e\.?)/i,
        wide: /^(before christ|before common era|anno domini|common era)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        any: [ /^b/i, /^(a|c)/i ]
      },
      defaultParseWidth: "any"
    }),
    quarter: buildMatchFn({
      matchPatterns: {
        narrow: /^[1234]/i,
        abbreviated: /^q[1234]/i,
        wide: /^[1234](th|st|nd|rd)? quarter/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        any: [ /1/i, /2/i, /3/i, /4/i ]
      },
      defaultParseWidth: "any",
      valueCallback: function(e) {
        return e + 1;
      }
    }),
    month: buildMatchFn({
      matchPatterns: {
        narrow: /^[jfmasond]/i,
        abbreviated: /^(jan|feb|mar|apr|may|jun|jul|aug|sep|oct|nov|dec)/i,
        wide: /^(january|february|march|april|may|june|july|august|september|october|november|december)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        narrow: [ /^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i ],
        any: [ /^ja/i, /^f/i, /^mar/i, /^ap/i, /^may/i, /^jun/i, /^jul/i, /^au/i, /^s/i, /^o/i, /^n/i, /^d/i ]
      },
      defaultParseWidth: "any"
    }),
    day: buildMatchFn({
      matchPatterns: {
        narrow: /^[smtwf]/i,
        short: /^(su|mo|tu|we|th|fr|sa)/i,
        abbreviated: /^(sun|mon|tue|wed|thu|fri|sat)/i,
        wide: /^(sunday|monday|tuesday|wednesday|thursday|friday|saturday)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        narrow: [ /^s/i, /^m/i, /^t/i, /^w/i, /^t/i, /^f/i, /^s/i ],
        any: [ /^su/i, /^m/i, /^tu/i, /^w/i, /^th/i, /^f/i, /^sa/i ]
      },
      defaultParseWidth: "any"
    }),
    dayPeriod: buildMatchFn({
      matchPatterns: {
        narrow: /^(a|p|mi|n|(in the|at) (morning|afternoon|evening|night))/i,
        any: /^([ap]\.?\s?m\.?|midnight|noon|(in the|at) (morning|afternoon|evening|night))/i
      },
      defaultMatchWidth: "any",
      parsePatterns: {
        any: {
          am: /^a/i,
          pm: /^p/i,
          midnight: /^mi/i,
          noon: /^no/i,
          morning: /morning/i,
          afternoon: /afternoon/i,
          evening: /evening/i,
          night: /night/i
        }
      },
      defaultParseWidth: "any"
    })
  },
  options: {
    weekStartsOn: 0
    /* Sunday */ ,
    firstWeekContainsDate: 1
  }
};

/**
 * @name subMilliseconds
 * @category Millisecond Helpers
 * @summary Subtract the specified number of milliseconds from the given date.
 *
 * @description
 * Subtract the specified number of milliseconds from the given date.
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * @param {Date|Number} date - the date to be changed
 * @param {Number} amount - the amount of milliseconds to be subtracted. Positive decimals will be rounded using `Math.floor`, decimals less than zero will be rounded using `Math.ceil`.
 * @returns {Date} the new date with the milliseconds subtracted
 * @throws {TypeError} 2 arguments required
 *
 * @example
 * // Subtract 750 milliseconds from 10 July 2014 12:45:30.000:
 * const result = subMilliseconds(new Date(2014, 6, 10, 12, 45, 30, 0), 750)
 * //=> Thu Jul 10 2014 12:45:29.250
 */
function subMilliseconds(e, t) {
  requiredArgs(2, arguments);
  var a = toInteger(t);
  return addMilliseconds(e, -a);
}

// See issue: https://github.com/date-fns/date-fns/issues/376
function startOfUTCISOWeek(e) {
  requiredArgs(1, arguments);
  var t = 1, a = toDate(e), n = a.getUTCDay(), i = (n < t ? 7 : 0) + n - t;
  return a.setUTCDate(a.getUTCDate() - i), a.setUTCHours(0, 0, 0, 0), a;
}

// See issue: https://github.com/date-fns/date-fns/issues/376
function getUTCISOWeekYear(e) {
  requiredArgs(1, arguments);
  var t = toDate(e), a = t.getUTCFullYear(), n = new Date(0);
  n.setUTCFullYear(a + 1, 0, 4), n.setUTCHours(0, 0, 0, 0);
  var i = startOfUTCISOWeek(n), r = new Date(0);
  r.setUTCFullYear(a, 0, 4), r.setUTCHours(0, 0, 0, 0);
  var o = startOfUTCISOWeek(r);
  return t.getTime() >= i.getTime() ? a + 1 : t.getTime() >= o.getTime() ? a : a - 1;
}

// See issue: https://github.com/date-fns/date-fns/issues/376
function startOfUTCISOWeekYear(e) {
  requiredArgs(1, arguments);
  var t = getUTCISOWeekYear(e), a = new Date(0);
  a.setUTCFullYear(t, 0, 4), a.setUTCHours(0, 0, 0, 0);
  var n = startOfUTCISOWeek(a);
  return n;
}

// This function will be a part of public API when UTC function will be implemented.
// See issue: https://github.com/date-fns/date-fns/issues/376
function getUTCISOWeek(e) {
  requiredArgs(1, arguments);
  var t = toDate(e), a = startOfUTCISOWeek(t).getTime() - startOfUTCISOWeekYear(t).getTime();
  // Round the number of days to the nearest integer
  // because the number of milliseconds in a week is not constant
  // (e.g. it's different in the week of the daylight saving time clock shift)
  return Math.round(a / 6048e5) + 1;
}

// See issue: https://github.com/date-fns/date-fns/issues/376
function startOfUTCWeek(e, t) {
  requiredArgs(1, arguments);
  var a = t || {}, n = a.locale, i = n && n.options && n.options.weekStartsOn, r = null == i ? 0 : toInteger(i), o = null == a.weekStartsOn ? r : toInteger(a.weekStartsOn);
  // Test if weekStartsOn is between 0 and 6 _and_ is not NaN
  if (!(o >= 0 && o <= 6)) throw new RangeError("weekStartsOn must be between 0 and 6 inclusively");
  var s = toDate(e), d = s.getUTCDay(), u = (d < o ? 7 : 0) + d - o;
  return s.setUTCDate(s.getUTCDate() - u), s.setUTCHours(0, 0, 0, 0), s;
}

// See issue: https://github.com/date-fns/date-fns/issues/376
function getUTCWeekYear(e, t) {
  requiredArgs(1, arguments);
  var a = toDate(e), n = a.getUTCFullYear(), i = t || {}, r = i.locale, o = r && r.options && r.options.firstWeekContainsDate, s = null == o ? 1 : toInteger(o), d = null == i.firstWeekContainsDate ? s : toInteger(i.firstWeekContainsDate);
  // Test if weekStartsOn is between 1 and 7 _and_ is not NaN
  if (!(d >= 1 && d <= 7)) throw new RangeError("firstWeekContainsDate must be between 1 and 7 inclusively");
  var u = new Date(0);
  u.setUTCFullYear(n + 1, 0, d), u.setUTCHours(0, 0, 0, 0);
  var m = startOfUTCWeek(u, t), l = new Date(0);
  l.setUTCFullYear(n, 0, d), l.setUTCHours(0, 0, 0, 0);
  var c = startOfUTCWeek(l, t);
  return a.getTime() >= m.getTime() ? n + 1 : a.getTime() >= c.getTime() ? n : n - 1;
}

// See issue: https://github.com/date-fns/date-fns/issues/376
function startOfUTCWeekYear(e, t) {
  requiredArgs(1, arguments);
  var a = t || {}, n = a.locale, i = n && n.options && n.options.firstWeekContainsDate, r = null == i ? 1 : toInteger(i), o = null == a.firstWeekContainsDate ? r : toInteger(a.firstWeekContainsDate), s = getUTCWeekYear(e, t), d = new Date(0);
  d.setUTCFullYear(s, 0, o), d.setUTCHours(0, 0, 0, 0);
  var u = startOfUTCWeek(d, t);
  return u;
}

// This function will be a part of public API when UTC function will be implemented.
// See issue: https://github.com/date-fns/date-fns/issues/376
function getUTCWeek(e, t) {
  requiredArgs(1, arguments);
  var a = toDate(e), n = startOfUTCWeek(a, t).getTime() - startOfUTCWeekYear(a, t).getTime();
  // Round the number of days to the nearest integer
  // because the number of milliseconds in a week is not constant
  // (e.g. it's different in the week of the daylight saving time clock shift)
  return Math.round(n / 6048e5) + 1;
}

function addLeadingZeros(e, t) {
  for (var a = e < 0 ? "-" : "", n = Math.abs(e).toString(); n.length < t; ) n = "0" + n;
  return a + n;
}

/*
 * |     | Unit                           |     | Unit                           |
 * |-----|--------------------------------|-----|--------------------------------|
 * |  a  | AM, PM                         |  A* |                                |
 * |  d  | Day of month                   |  D  |                                |
 * |  h  | Hour [1-12]                    |  H  | Hour [0-23]                    |
 * |  m  | Minute                         |  M  | Month                          |
 * |  s  | Second                         |  S  | Fraction of second             |
 * |  y  | Year (abs)                     |  Y  |                                |
 *
 * Letters marked by * are not implemented but reserved by Unicode standard.
 */ var formatters$1_y = function(e, t) {
  // From http://www.unicode.org/reports/tr35/tr35-31/tr35-dates.html#Date_Format_tokens
  // | Year     |     y | yy |   yyy |  yyyy | yyyyy |
  // |----------|-------|----|-------|-------|-------|
  // | AD 1     |     1 | 01 |   001 |  0001 | 00001 |
  // | AD 12    |    12 | 12 |   012 |  0012 | 00012 |
  // | AD 123   |   123 | 23 |   123 |  0123 | 00123 |
  // | AD 1234  |  1234 | 34 |  1234 |  1234 | 01234 |
  // | AD 12345 | 12345 | 45 | 12345 | 12345 | 12345 |
  var a = e.getUTCFullYear(), n = a > 0 ? a : 1 - a;
 // Returns 1 for 1 BC (which is year 0 in JavaScript)
    return addLeadingZeros("yy" === t ? n % 100 : n, t.length);
}, formatters$1_M = function(e, t) {
  var a = e.getUTCMonth();
  return "M" === t ? String(a + 1) : addLeadingZeros(a + 1, 2);
}, formatters$1_d = function(e, t) {
  return addLeadingZeros(e.getUTCDate(), t.length);
}, formatters$1_h = function(e, t) {
  return addLeadingZeros(e.getUTCHours() % 12 || 12, t.length);
}, formatters$1_H = function(e, t) {
  return addLeadingZeros(e.getUTCHours(), t.length);
}, formatters$1_m = function(e, t) {
  return addLeadingZeros(e.getUTCMinutes(), t.length);
}, formatters$1_s = function(e, t) {
  return addLeadingZeros(e.getUTCSeconds(), t.length);
}, formatters$1_S = function(e, t) {
  var a = t.length, n = e.getUTCMilliseconds();
  return addLeadingZeros(Math.floor(n * Math.pow(10, a - 3)), t.length);
}, o = "midnight", s = "noon", d = "morning", u = "afternoon", m = "evening", l = "night", c = {
  // Era
  G: function(e, t, a) {
    var n = e.getUTCFullYear() > 0 ? 1 : 0;
    switch (t) {
     // AD, BC
      case "G":
     case "GG":
     case "GGG":
      return a.era(n, {
        width: "abbreviated"
      });

      // A, B
           case "GGGGG":
      return a.era(n, {
        width: "narrow"
      });

      // Anno Domini, Before Christ
           case "GGGG":
     default:
      return a.era(n, {
        width: "wide"
      });
    }
  },
  // Year
  y: function(e, t, a) {
    // Ordinal number
    if ("yo" === t) {
      var n = e.getUTCFullYear(), i = n > 0 ? n : 1 - n;
 // Returns 1 for 1 BC (which is year 0 in JavaScript)
            return a.ordinalNumber(i, {
        unit: "year"
      });
    }
    return formatters$1_y(e, t);
  },
  // Local week-numbering year
  Y: function(e, t, a, n) {
    var i = getUTCWeekYear(e, n), r = i > 0 ? i : 1 - i;
 // Returns 1 for 1 BC (which is year 0 in JavaScript)
        // Two digit year
    return "YY" === t ? addLeadingZeros(r % 100, 2) : // Ordinal number
    "Yo" === t ? a.ordinalNumber(r, {
      unit: "year"
    }) : addLeadingZeros(r, t.length);
  },
  // ISO week-numbering year
  R: function(e, t) {
    // Padding
    return addLeadingZeros(getUTCISOWeekYear(e), t.length);
  },
  // Extended year. This is a single number designating the year of this calendar system.
  // The main difference between `y` and `u` localizers are B.C. years:
  // | Year | `y` | `u` |
  // |------|-----|-----|
  // | AC 1 |   1 |   1 |
  // | BC 1 |   1 |   0 |
  // | BC 2 |   2 |  -1 |
  // Also `yy` always returns the last two digits of a year,
  // while `uu` pads single digit years to 2 characters and returns other years unchanged.
  u: function(e, t) {
    return addLeadingZeros(e.getUTCFullYear(), t.length);
  },
  // Quarter
  Q: function(e, t, a) {
    var n = Math.ceil((e.getUTCMonth() + 1) / 3);
    switch (t) {
     // 1, 2, 3, 4
      case "Q":
      return String(n);

      // 01, 02, 03, 04
           case "QQ":
      return addLeadingZeros(n, 2);

      // 1st, 2nd, 3rd, 4th
           case "Qo":
      return a.ordinalNumber(n, {
        unit: "quarter"
      });

      // Q1, Q2, Q3, Q4
           case "QQQ":
      return a.quarter(n, {
        width: "abbreviated",
        context: "formatting"
      });

      // 1, 2, 3, 4 (narrow quarter; could be not numerical)
           case "QQQQQ":
      return a.quarter(n, {
        width: "narrow",
        context: "formatting"
      });

      // 1st quarter, 2nd quarter, ...
           case "QQQQ":
     default:
      return a.quarter(n, {
        width: "wide",
        context: "formatting"
      });
    }
  },
  // Stand-alone quarter
  q: function(e, t, a) {
    var n = Math.ceil((e.getUTCMonth() + 1) / 3);
    switch (t) {
     // 1, 2, 3, 4
      case "q":
      return String(n);

      // 01, 02, 03, 04
           case "qq":
      return addLeadingZeros(n, 2);

      // 1st, 2nd, 3rd, 4th
           case "qo":
      return a.ordinalNumber(n, {
        unit: "quarter"
      });

      // Q1, Q2, Q3, Q4
           case "qqq":
      return a.quarter(n, {
        width: "abbreviated",
        context: "standalone"
      });

      // 1, 2, 3, 4 (narrow quarter; could be not numerical)
           case "qqqqq":
      return a.quarter(n, {
        width: "narrow",
        context: "standalone"
      });

      // 1st quarter, 2nd quarter, ...
           case "qqqq":
     default:
      return a.quarter(n, {
        width: "wide",
        context: "standalone"
      });
    }
  },
  // Month
  M: function(e, t, a) {
    var n = e.getUTCMonth();
    switch (t) {
     case "M":
     case "MM":
      return formatters$1_M(e, t);

      // 1st, 2nd, ..., 12th
           case "Mo":
      return a.ordinalNumber(n + 1, {
        unit: "month"
      });

      // Jan, Feb, ..., Dec
           case "MMM":
      return a.month(n, {
        width: "abbreviated",
        context: "formatting"
      });

      // J, F, ..., D
           case "MMMMM":
      return a.month(n, {
        width: "narrow",
        context: "formatting"
      });

      // January, February, ..., December
           case "MMMM":
     default:
      return a.month(n, {
        width: "wide",
        context: "formatting"
      });
    }
  },
  // Stand-alone month
  L: function(e, t, a) {
    var n = e.getUTCMonth();
    switch (t) {
     // 1, 2, ..., 12
      case "L":
      return String(n + 1);

      // 01, 02, ..., 12
           case "LL":
      return addLeadingZeros(n + 1, 2);

      // 1st, 2nd, ..., 12th
           case "Lo":
      return a.ordinalNumber(n + 1, {
        unit: "month"
      });

      // Jan, Feb, ..., Dec
           case "LLL":
      return a.month(n, {
        width: "abbreviated",
        context: "standalone"
      });

      // J, F, ..., D
           case "LLLLL":
      return a.month(n, {
        width: "narrow",
        context: "standalone"
      });

      // January, February, ..., December
           case "LLLL":
     default:
      return a.month(n, {
        width: "wide",
        context: "standalone"
      });
    }
  },
  // Local week of year
  w: function(e, t, a, n) {
    var i = getUTCWeek(e, n);
    return "wo" === t ? a.ordinalNumber(i, {
      unit: "week"
    }) : addLeadingZeros(i, t.length);
  },
  // ISO week of year
  I: function(e, t, a) {
    var n = getUTCISOWeek(e);
    return "Io" === t ? a.ordinalNumber(n, {
      unit: "week"
    }) : addLeadingZeros(n, t.length);
  },
  // Day of the month
  d: function(e, t, a) {
    return "do" === t ? a.ordinalNumber(e.getUTCDate(), {
      unit: "date"
    }) : formatters$1_d(e, t);
  },
  // Day of year
  D: function(e, t, a) {
    var n = // This function will be a part of public API when UTC function will be implemented.
    // See issue: https://github.com/date-fns/date-fns/issues/376
    function(e) {
      requiredArgs(1, arguments);
      var t = toDate(e), a = t.getTime();
      t.setUTCMonth(0, 1), t.setUTCHours(0, 0, 0, 0);
      var n = t.getTime(), i = a - n;
      return Math.floor(i / 864e5) + 1;
    }(e);
    return "Do" === t ? a.ordinalNumber(n, {
      unit: "dayOfYear"
    }) : addLeadingZeros(n, t.length);
  },
  // Day of week
  E: function(e, t, a) {
    var n = e.getUTCDay();
    switch (t) {
     // Tue
      case "E":
     case "EE":
     case "EEE":
      return a.day(n, {
        width: "abbreviated",
        context: "formatting"
      });

      // T
           case "EEEEE":
      return a.day(n, {
        width: "narrow",
        context: "formatting"
      });

      // Tu
           case "EEEEEE":
      return a.day(n, {
        width: "short",
        context: "formatting"
      });

      // Tuesday
           case "EEEE":
     default:
      return a.day(n, {
        width: "wide",
        context: "formatting"
      });
    }
  },
  // Local day of week
  e: function(e, t, a, n) {
    var i = e.getUTCDay(), r = (i - n.weekStartsOn + 8) % 7 || 7;
    switch (t) {
     // Numerical value (Nth day of week with current locale or weekStartsOn)
      case "e":
      return String(r);

      // Padded numerical value
           case "ee":
      return addLeadingZeros(r, 2);

      // 1st, 2nd, ..., 7th
           case "eo":
      return a.ordinalNumber(r, {
        unit: "day"
      });

     case "eee":
      return a.day(i, {
        width: "abbreviated",
        context: "formatting"
      });

      // T
           case "eeeee":
      return a.day(i, {
        width: "narrow",
        context: "formatting"
      });

      // Tu
           case "eeeeee":
      return a.day(i, {
        width: "short",
        context: "formatting"
      });

      // Tuesday
           case "eeee":
     default:
      return a.day(i, {
        width: "wide",
        context: "formatting"
      });
    }
  },
  // Stand-alone local day of week
  c: function(e, t, a, n) {
    var i = e.getUTCDay(), r = (i - n.weekStartsOn + 8) % 7 || 7;
    switch (t) {
     // Numerical value (same as in `e`)
      case "c":
      return String(r);

      // Padded numerical value
           case "cc":
      return addLeadingZeros(r, t.length);

      // 1st, 2nd, ..., 7th
           case "co":
      return a.ordinalNumber(r, {
        unit: "day"
      });

     case "ccc":
      return a.day(i, {
        width: "abbreviated",
        context: "standalone"
      });

      // T
           case "ccccc":
      return a.day(i, {
        width: "narrow",
        context: "standalone"
      });

      // Tu
           case "cccccc":
      return a.day(i, {
        width: "short",
        context: "standalone"
      });

      // Tuesday
           case "cccc":
     default:
      return a.day(i, {
        width: "wide",
        context: "standalone"
      });
    }
  },
  // ISO day of week
  i: function(e, t, a) {
    var n = e.getUTCDay(), i = 0 === n ? 7 : n;
    switch (t) {
     // 2
      case "i":
      return String(i);

      // 02
           case "ii":
      return addLeadingZeros(i, t.length);

      // 2nd
           case "io":
      return a.ordinalNumber(i, {
        unit: "day"
      });

      // Tue
           case "iii":
      return a.day(n, {
        width: "abbreviated",
        context: "formatting"
      });

      // T
           case "iiiii":
      return a.day(n, {
        width: "narrow",
        context: "formatting"
      });

      // Tu
           case "iiiiii":
      return a.day(n, {
        width: "short",
        context: "formatting"
      });

      // Tuesday
           case "iiii":
     default:
      return a.day(n, {
        width: "wide",
        context: "formatting"
      });
    }
  },
  // AM or PM
  a: function(e, t, a) {
    var n = e.getUTCHours() / 12 >= 1 ? "pm" : "am";
    switch (t) {
     case "a":
     case "aa":
      return a.dayPeriod(n, {
        width: "abbreviated",
        context: "formatting"
      });

     case "aaa":
      return a.dayPeriod(n, {
        width: "abbreviated",
        context: "formatting"
      }).toLowerCase();

     case "aaaaa":
      return a.dayPeriod(n, {
        width: "narrow",
        context: "formatting"
      });

     case "aaaa":
     default:
      return a.dayPeriod(n, {
        width: "wide",
        context: "formatting"
      });
    }
  },
  // AM, PM, midnight, noon
  b: function(e, t, a) {
    var n, i = e.getUTCHours();
    switch (n = 12 === i ? s : 0 === i ? o : i / 12 >= 1 ? "pm" : "am", t) {
     case "b":
     case "bb":
      return a.dayPeriod(n, {
        width: "abbreviated",
        context: "formatting"
      });

     case "bbb":
      return a.dayPeriod(n, {
        width: "abbreviated",
        context: "formatting"
      }).toLowerCase();

     case "bbbbb":
      return a.dayPeriod(n, {
        width: "narrow",
        context: "formatting"
      });

     case "bbbb":
     default:
      return a.dayPeriod(n, {
        width: "wide",
        context: "formatting"
      });
    }
  },
  // in the morning, in the afternoon, in the evening, at night
  B: function(e, t, a) {
    var n, i = e.getUTCHours();
    switch (n = i >= 17 ? m : i >= 12 ? u : i >= 4 ? d : l, t) {
     case "B":
     case "BB":
     case "BBB":
      return a.dayPeriod(n, {
        width: "abbreviated",
        context: "formatting"
      });

     case "BBBBB":
      return a.dayPeriod(n, {
        width: "narrow",
        context: "formatting"
      });

     case "BBBB":
     default:
      return a.dayPeriod(n, {
        width: "wide",
        context: "formatting"
      });
    }
  },
  // Hour [1-12]
  h: function(e, t, a) {
    if ("ho" === t) {
      var n = e.getUTCHours() % 12;
      return 0 === n && (n = 12), a.ordinalNumber(n, {
        unit: "hour"
      });
    }
    return formatters$1_h(e, t);
  },
  // Hour [0-23]
  H: function(e, t, a) {
    return "Ho" === t ? a.ordinalNumber(e.getUTCHours(), {
      unit: "hour"
    }) : formatters$1_H(e, t);
  },
  // Hour [0-11]
  K: function(e, t, a) {
    var n = e.getUTCHours() % 12;
    return "Ko" === t ? a.ordinalNumber(n, {
      unit: "hour"
    }) : addLeadingZeros(n, t.length);
  },
  // Hour [1-24]
  k: function(e, t, a) {
    var n = e.getUTCHours();
    return 0 === n && (n = 24), "ko" === t ? a.ordinalNumber(n, {
      unit: "hour"
    }) : addLeadingZeros(n, t.length);
  },
  // Minute
  m: function(e, t, a) {
    return "mo" === t ? a.ordinalNumber(e.getUTCMinutes(), {
      unit: "minute"
    }) : formatters$1_m(e, t);
  },
  // Second
  s: function(e, t, a) {
    return "so" === t ? a.ordinalNumber(e.getUTCSeconds(), {
      unit: "second"
    }) : formatters$1_s(e, t);
  },
  // Fraction of second
  S: function(e, t) {
    return formatters$1_S(e, t);
  },
  // Timezone (ISO-8601. If offset is 0, output is always `'Z'`)
  X: function(e, t, a, n) {
    var i = (n._originalDate || e).getTimezoneOffset();
    if (0 === i) return "Z";
    switch (t) {
     // Hours and optional minutes
      case "X":
      return formatTimezoneWithOptionalMinutes(i);

      // Hours, minutes and optional seconds without `:` delimiter
      // Note: neither ISO-8601 nor JavaScript supports seconds in timezone offsets
      // so this token always has the same output as `XX`
           case "XXXX":
     case "XX":
      // Hours and minutes without `:` delimiter
      return formatTimezone(i);

      // Hours, minutes and optional seconds with `:` delimiter
      // Note: neither ISO-8601 nor JavaScript supports seconds in timezone offsets
      // so this token always has the same output as `XXX`
           case "XXXXX":
     case "XXX":
 // Hours and minutes with `:` delimiter
           default:
      return formatTimezone(i, ":");
    }
  },
  // Timezone (ISO-8601. If offset is 0, output is `'+00:00'` or equivalent)
  x: function(e, t, a, n) {
    var i = (n._originalDate || e).getTimezoneOffset();
    switch (t) {
     // Hours and optional minutes
      case "x":
      return formatTimezoneWithOptionalMinutes(i);

      // Hours, minutes and optional seconds without `:` delimiter
      // Note: neither ISO-8601 nor JavaScript supports seconds in timezone offsets
      // so this token always has the same output as `xx`
           case "xxxx":
     case "xx":
      // Hours and minutes without `:` delimiter
      return formatTimezone(i);

      // Hours, minutes and optional seconds with `:` delimiter
      // Note: neither ISO-8601 nor JavaScript supports seconds in timezone offsets
      // so this token always has the same output as `xxx`
           case "xxxxx":
     case "xxx":
 // Hours and minutes with `:` delimiter
           default:
      return formatTimezone(i, ":");
    }
  },
  // Timezone (GMT)
  O: function(e, t, a, n) {
    var i = (n._originalDate || e).getTimezoneOffset();
    switch (t) {
     // Short
      case "O":
     case "OO":
     case "OOO":
      return "GMT" + formatTimezoneShort(i, ":");

      // Long
           case "OOOO":
     default:
      return "GMT" + formatTimezone(i, ":");
    }
  },
  // Timezone (specific non-location)
  z: function(e, t, a, n) {
    var i = (n._originalDate || e).getTimezoneOffset();
    switch (t) {
     // Short
      case "z":
     case "zz":
     case "zzz":
      return "GMT" + formatTimezoneShort(i, ":");

      // Long
           case "zzzz":
     default:
      return "GMT" + formatTimezone(i, ":");
    }
  },
  // Seconds timestamp
  t: function(e, t, a, n) {
    var i = n._originalDate || e;
    return addLeadingZeros(Math.floor(i.getTime() / 1e3), t.length);
  },
  // Milliseconds timestamp
  T: function(e, t, a, n) {
    return addLeadingZeros((n._originalDate || e).getTime(), t.length);
  }
};

function formatTimezoneShort(e, t) {
  var a = e > 0 ? "-" : "+", n = Math.abs(e), i = Math.floor(n / 60), r = n % 60;
  if (0 === r) return a + String(i);
  var o = t || "";
  return a + String(i) + o + addLeadingZeros(r, 2);
}

function formatTimezoneWithOptionalMinutes(e, t) {
  return e % 60 == 0 ? (e > 0 ? "-" : "+") + addLeadingZeros(Math.abs(e) / 60, 2) : formatTimezone(e, t);
}

function formatTimezone(e, t) {
  var a = t || "", n = e > 0 ? "-" : "+", i = Math.abs(e);
  return n + addLeadingZeros(Math.floor(i / 60), 2) + a + addLeadingZeros(i % 60, 2);
}

function dateLongFormatter(e, t) {
  switch (e) {
   case "P":
    return t.date({
      width: "short"
    });

   case "PP":
    return t.date({
      width: "medium"
    });

   case "PPP":
    return t.date({
      width: "long"
    });

   case "PPPP":
   default:
    return t.date({
      width: "full"
    });
  }
}

function timeLongFormatter(e, t) {
  switch (e) {
   case "p":
    return t.time({
      width: "short"
    });

   case "pp":
    return t.time({
      width: "medium"
    });

   case "ppp":
    return t.time({
      width: "long"
    });

   case "pppp":
   default:
    return t.time({
      width: "full"
    });
  }
}

var h = {
  p: timeLongFormatter,
  P: function(e, t) {
    var a, n = e.match(/(P+)(p+)?/) || [], i = n[1], r = n[2];
    if (!r) return dateLongFormatter(e, t);
    switch (i) {
     case "P":
      a = t.dateTime({
        width: "short"
      });
      break;

     case "PP":
      a = t.dateTime({
        width: "medium"
      });
      break;

     case "PPP":
      a = t.dateTime({
        width: "long"
      });
      break;

     case "PPPP":
     default:
      a = t.dateTime({
        width: "full"
      });
    }
    return a.replace("{{date}}", dateLongFormatter(i, t)).replace("{{time}}", timeLongFormatter(r, t));
  }
}, g = [ "D", "DD" ], f = [ "YY", "YYYY" ];

function isProtectedDayOfYearToken(e) {
  return -1 !== g.indexOf(e);
}

function isProtectedWeekYearToken(e) {
  return -1 !== f.indexOf(e);
}

function throwProtectedError(e, t, a) {
  if ("YYYY" === e) throw new RangeError("Use `yyyy` instead of `YYYY` (in `".concat(t, "`) for formatting years to the input `").concat(a, "`; see: https://git.io/fxCyr"));
  if ("YY" === e) throw new RangeError("Use `yy` instead of `YY` (in `".concat(t, "`) for formatting years to the input `").concat(a, "`; see: https://git.io/fxCyr"));
  if ("D" === e) throw new RangeError("Use `d` instead of `D` (in `".concat(t, "`) for formatting days of the month to the input `").concat(a, "`; see: https://git.io/fxCyr"));
  if ("DD" === e) throw new RangeError("Use `dd` instead of `DD` (in `".concat(t, "`) for formatting days of the month to the input `").concat(a, "`; see: https://git.io/fxCyr"));
}

// - [yYQqMLwIdDecihHKkms]o matches any available ordinal number token
//   (one of the certain letters followed by `o`)
// - (\w)\1* matches any sequences of the same letter
// - '' matches two quote characters in a row
// - '(''|[^'])+('|$) matches anything surrounded by two quote characters ('),
//   except a single quote symbol, which ends the sequence.
//   Two quote characters do not end the sequence.
//   If there is no matching single quote
//   then the sequence will continue until the end of the string.
// - . matches any single character unmatched by previous parts of the RegExps
var b = /[yYQqMLwIdDecihHKkms]o|(\w)\1*|''|'(''|[^'])+('|$)|./g, w = /P+p+|P+|p+|''|'(''|[^'])+('|$)|./g, p = /^'([^]*?)'?$/, y = /''/g, v = /[a-zA-Z]/;

 // This RegExp catches symbols escaped by quotes, and also
// sequences of symbols P, p, and the combinations like `PPPPPPPppppp`
/**
 * @name format
 * @category Common Helpers
 * @summary Format the date.
 *
 * @description
 * Return the formatted date string in the given format. The result may vary by locale.
 *
 * > ⚠️ Please note that the `format` tokens differ from Moment.js and other libraries.
 * > See: https://git.io/fxCyr
 *
 * The characters wrapped between two single quotes characters (') are escaped.
 * Two single quotes in a row, whether inside or outside a quoted sequence, represent a 'real' single quote.
 * (see the last example)
 *
 * Format of the string is based on Unicode Technical Standard #35:
 * https://www.unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table
 * with a few additions (see note 7 below the table).
 *
 * Accepted patterns:
 * | Unit                            | Pattern | Result examples                   | Notes |
 * |---------------------------------|---------|-----------------------------------|-------|
 * | Era                             | G..GGG  | AD, BC                            |       |
 * |                                 | GGGG    | Anno Domini, Before Christ        | 2     |
 * |                                 | GGGGG   | A, B                              |       |
 * | Calendar year                   | y       | 44, 1, 1900, 2017                 | 5     |
 * |                                 | yo      | 44th, 1st, 0th, 17th              | 5,7   |
 * |                                 | yy      | 44, 01, 00, 17                    | 5     |
 * |                                 | yyy     | 044, 001, 1900, 2017              | 5     |
 * |                                 | yyyy    | 0044, 0001, 1900, 2017            | 5     |
 * |                                 | yyyyy   | ...                               | 3,5   |
 * | Local week-numbering year       | Y       | 44, 1, 1900, 2017                 | 5     |
 * |                                 | Yo      | 44th, 1st, 1900th, 2017th         | 5,7   |
 * |                                 | YY      | 44, 01, 00, 17                    | 5,8   |
 * |                                 | YYY     | 044, 001, 1900, 2017              | 5     |
 * |                                 | YYYY    | 0044, 0001, 1900, 2017            | 5,8   |
 * |                                 | YYYYY   | ...                               | 3,5   |
 * | ISO week-numbering year         | R       | -43, 0, 1, 1900, 2017             | 5,7   |
 * |                                 | RR      | -43, 00, 01, 1900, 2017           | 5,7   |
 * |                                 | RRR     | -043, 000, 001, 1900, 2017        | 5,7   |
 * |                                 | RRRR    | -0043, 0000, 0001, 1900, 2017     | 5,7   |
 * |                                 | RRRRR   | ...                               | 3,5,7 |
 * | Extended year                   | u       | -43, 0, 1, 1900, 2017             | 5     |
 * |                                 | uu      | -43, 01, 1900, 2017               | 5     |
 * |                                 | uuu     | -043, 001, 1900, 2017             | 5     |
 * |                                 | uuuu    | -0043, 0001, 1900, 2017           | 5     |
 * |                                 | uuuuu   | ...                               | 3,5   |
 * | Quarter (formatting)            | Q       | 1, 2, 3, 4                        |       |
 * |                                 | Qo      | 1st, 2nd, 3rd, 4th                | 7     |
 * |                                 | QQ      | 01, 02, 03, 04                    |       |
 * |                                 | QQQ     | Q1, Q2, Q3, Q4                    |       |
 * |                                 | QQQQ    | 1st quarter, 2nd quarter, ...     | 2     |
 * |                                 | QQQQQ   | 1, 2, 3, 4                        | 4     |
 * | Quarter (stand-alone)           | q       | 1, 2, 3, 4                        |       |
 * |                                 | qo      | 1st, 2nd, 3rd, 4th                | 7     |
 * |                                 | qq      | 01, 02, 03, 04                    |       |
 * |                                 | qqq     | Q1, Q2, Q3, Q4                    |       |
 * |                                 | qqqq    | 1st quarter, 2nd quarter, ...     | 2     |
 * |                                 | qqqqq   | 1, 2, 3, 4                        | 4     |
 * | Month (formatting)              | M       | 1, 2, ..., 12                     |       |
 * |                                 | Mo      | 1st, 2nd, ..., 12th               | 7     |
 * |                                 | MM      | 01, 02, ..., 12                   |       |
 * |                                 | MMM     | Jan, Feb, ..., Dec                |       |
 * |                                 | MMMM    | January, February, ..., December  | 2     |
 * |                                 | MMMMM   | J, F, ..., D                      |       |
 * | Month (stand-alone)             | L       | 1, 2, ..., 12                     |       |
 * |                                 | Lo      | 1st, 2nd, ..., 12th               | 7     |
 * |                                 | LL      | 01, 02, ..., 12                   |       |
 * |                                 | LLL     | Jan, Feb, ..., Dec                |       |
 * |                                 | LLLL    | January, February, ..., December  | 2     |
 * |                                 | LLLLL   | J, F, ..., D                      |       |
 * | Local week of year              | w       | 1, 2, ..., 53                     |       |
 * |                                 | wo      | 1st, 2nd, ..., 53th               | 7     |
 * |                                 | ww      | 01, 02, ..., 53                   |       |
 * | ISO week of year                | I       | 1, 2, ..., 53                     | 7     |
 * |                                 | Io      | 1st, 2nd, ..., 53th               | 7     |
 * |                                 | II      | 01, 02, ..., 53                   | 7     |
 * | Day of month                    | d       | 1, 2, ..., 31                     |       |
 * |                                 | do      | 1st, 2nd, ..., 31st               | 7     |
 * |                                 | dd      | 01, 02, ..., 31                   |       |
 * | Day of year                     | D       | 1, 2, ..., 365, 366               | 9     |
 * |                                 | Do      | 1st, 2nd, ..., 365th, 366th       | 7     |
 * |                                 | DD      | 01, 02, ..., 365, 366             | 9     |
 * |                                 | DDD     | 001, 002, ..., 365, 366           |       |
 * |                                 | DDDD    | ...                               | 3     |
 * | Day of week (formatting)        | E..EEE  | Mon, Tue, Wed, ..., Sun           |       |
 * |                                 | EEEE    | Monday, Tuesday, ..., Sunday      | 2     |
 * |                                 | EEEEE   | M, T, W, T, F, S, S               |       |
 * |                                 | EEEEEE  | Mo, Tu, We, Th, Fr, Sa, Su        |       |
 * | ISO day of week (formatting)    | i       | 1, 2, 3, ..., 7                   | 7     |
 * |                                 | io      | 1st, 2nd, ..., 7th                | 7     |
 * |                                 | ii      | 01, 02, ..., 07                   | 7     |
 * |                                 | iii     | Mon, Tue, Wed, ..., Sun           | 7     |
 * |                                 | iiii    | Monday, Tuesday, ..., Sunday      | 2,7   |
 * |                                 | iiiii   | M, T, W, T, F, S, S               | 7     |
 * |                                 | iiiiii  | Mo, Tu, We, Th, Fr, Sa, Su        | 7     |
 * | Local day of week (formatting)  | e       | 2, 3, 4, ..., 1                   |       |
 * |                                 | eo      | 2nd, 3rd, ..., 1st                | 7     |
 * |                                 | ee      | 02, 03, ..., 01                   |       |
 * |                                 | eee     | Mon, Tue, Wed, ..., Sun           |       |
 * |                                 | eeee    | Monday, Tuesday, ..., Sunday      | 2     |
 * |                                 | eeeee   | M, T, W, T, F, S, S               |       |
 * |                                 | eeeeee  | Mo, Tu, We, Th, Fr, Sa, Su        |       |
 * | Local day of week (stand-alone) | c       | 2, 3, 4, ..., 1                   |       |
 * |                                 | co      | 2nd, 3rd, ..., 1st                | 7     |
 * |                                 | cc      | 02, 03, ..., 01                   |       |
 * |                                 | ccc     | Mon, Tue, Wed, ..., Sun           |       |
 * |                                 | cccc    | Monday, Tuesday, ..., Sunday      | 2     |
 * |                                 | ccccc   | M, T, W, T, F, S, S               |       |
 * |                                 | cccccc  | Mo, Tu, We, Th, Fr, Sa, Su        |       |
 * | AM, PM                          | a..aa   | AM, PM                            |       |
 * |                                 | aaa     | am, pm                            |       |
 * |                                 | aaaa    | a.m., p.m.                        | 2     |
 * |                                 | aaaaa   | a, p                              |       |
 * | AM, PM, noon, midnight          | b..bb   | AM, PM, noon, midnight            |       |
 * |                                 | bbb     | am, pm, noon, midnight            |       |
 * |                                 | bbbb    | a.m., p.m., noon, midnight        | 2     |
 * |                                 | bbbbb   | a, p, n, mi                       |       |
 * | Flexible day period             | B..BBB  | at night, in the morning, ...     |       |
 * |                                 | BBBB    | at night, in the morning, ...     | 2     |
 * |                                 | BBBBB   | at night, in the morning, ...     |       |
 * | Hour [1-12]                     | h       | 1, 2, ..., 11, 12                 |       |
 * |                                 | ho      | 1st, 2nd, ..., 11th, 12th         | 7     |
 * |                                 | hh      | 01, 02, ..., 11, 12               |       |
 * | Hour [0-23]                     | H       | 0, 1, 2, ..., 23                  |       |
 * |                                 | Ho      | 0th, 1st, 2nd, ..., 23rd          | 7     |
 * |                                 | HH      | 00, 01, 02, ..., 23               |       |
 * | Hour [0-11]                     | K       | 1, 2, ..., 11, 0                  |       |
 * |                                 | Ko      | 1st, 2nd, ..., 11th, 0th          | 7     |
 * |                                 | KK      | 01, 02, ..., 11, 00               |       |
 * | Hour [1-24]                     | k       | 24, 1, 2, ..., 23                 |       |
 * |                                 | ko      | 24th, 1st, 2nd, ..., 23rd         | 7     |
 * |                                 | kk      | 24, 01, 02, ..., 23               |       |
 * | Minute                          | m       | 0, 1, ..., 59                     |       |
 * |                                 | mo      | 0th, 1st, ..., 59th               | 7     |
 * |                                 | mm      | 00, 01, ..., 59                   |       |
 * | Second                          | s       | 0, 1, ..., 59                     |       |
 * |                                 | so      | 0th, 1st, ..., 59th               | 7     |
 * |                                 | ss      | 00, 01, ..., 59                   |       |
 * | Fraction of second              | S       | 0, 1, ..., 9                      |       |
 * |                                 | SS      | 00, 01, ..., 99                   |       |
 * |                                 | SSS     | 000, 001, ..., 999                |       |
 * |                                 | SSSS    | ...                               | 3     |
 * | Timezone (ISO-8601 w/ Z)        | X       | -08, +0530, Z                     |       |
 * |                                 | XX      | -0800, +0530, Z                   |       |
 * |                                 | XXX     | -08:00, +05:30, Z                 |       |
 * |                                 | XXXX    | -0800, +0530, Z, +123456          | 2     |
 * |                                 | XXXXX   | -08:00, +05:30, Z, +12:34:56      |       |
 * | Timezone (ISO-8601 w/o Z)       | x       | -08, +0530, +00                   |       |
 * |                                 | xx      | -0800, +0530, +0000               |       |
 * |                                 | xxx     | -08:00, +05:30, +00:00            | 2     |
 * |                                 | xxxx    | -0800, +0530, +0000, +123456      |       |
 * |                                 | xxxxx   | -08:00, +05:30, +00:00, +12:34:56 |       |
 * | Timezone (GMT)                  | O...OOO | GMT-8, GMT+5:30, GMT+0            |       |
 * |                                 | OOOO    | GMT-08:00, GMT+05:30, GMT+00:00   | 2     |
 * | Timezone (specific non-locat.)  | z...zzz | GMT-8, GMT+5:30, GMT+0            | 6     |
 * |                                 | zzzz    | GMT-08:00, GMT+05:30, GMT+00:00   | 2,6   |
 * | Seconds timestamp               | t       | 512969520                         | 7     |
 * |                                 | tt      | ...                               | 3,7   |
 * | Milliseconds timestamp          | T       | 512969520900                      | 7     |
 * |                                 | TT      | ...                               | 3,7   |
 * | Long localized date             | P       | 04/29/1453                        | 7     |
 * |                                 | PP      | Apr 29, 1453                      | 7     |
 * |                                 | PPP     | April 29th, 1453                  | 7     |
 * |                                 | PPPP    | Friday, April 29th, 1453          | 2,7   |
 * | Long localized time             | p       | 12:00 AM                          | 7     |
 * |                                 | pp      | 12:00:00 AM                       | 7     |
 * |                                 | ppp     | 12:00:00 AM GMT+2                 | 7     |
 * |                                 | pppp    | 12:00:00 AM GMT+02:00             | 2,7   |
 * | Combination of date and time    | Pp      | 04/29/1453, 12:00 AM              | 7     |
 * |                                 | PPpp    | Apr 29, 1453, 12:00:00 AM         | 7     |
 * |                                 | PPPppp  | April 29th, 1453 at ...           | 7     |
 * |                                 | PPPPpppp| Friday, April 29th, 1453 at ...   | 2,7   |
 * Notes:
 * 1. "Formatting" units (e.g. formatting quarter) in the default en-US locale
 *    are the same as "stand-alone" units, but are different in some languages.
 *    "Formatting" units are declined according to the rules of the language
 *    in the context of a date. "Stand-alone" units are always nominative singular:
 *
 *    `format(new Date(2017, 10, 6), 'do LLLL', {locale: cs}) //=> '6. listopad'`
 *
 *    `format(new Date(2017, 10, 6), 'do MMMM', {locale: cs}) //=> '6. listopadu'`
 *
 * 2. Any sequence of the identical letters is a pattern, unless it is escaped by
 *    the single quote characters (see below).
 *    If the sequence is longer than listed in table (e.g. `EEEEEEEEEEE`)
 *    the output will be the same as default pattern for this unit, usually
 *    the longest one (in case of ISO weekdays, `EEEE`). Default patterns for units
 *    are marked with "2" in the last column of the table.
 *
 *    `format(new Date(2017, 10, 6), 'MMM') //=> 'Nov'`
 *
 *    `format(new Date(2017, 10, 6), 'MMMM') //=> 'November'`
 *
 *    `format(new Date(2017, 10, 6), 'MMMMM') //=> 'N'`
 *
 *    `format(new Date(2017, 10, 6), 'MMMMMM') //=> 'November'`
 *
 *    `format(new Date(2017, 10, 6), 'MMMMMMM') //=> 'November'`
 *
 * 3. Some patterns could be unlimited length (such as `yyyyyyyy`).
 *    The output will be padded with zeros to match the length of the pattern.
 *
 *    `format(new Date(2017, 10, 6), 'yyyyyyyy') //=> '00002017'`
 *
 * 4. `QQQQQ` and `qqqqq` could be not strictly numerical in some locales.
 *    These tokens represent the shortest form of the quarter.
 *
 * 5. The main difference between `y` and `u` patterns are B.C. years:
 *
 *    | Year | `y` | `u` |
 *    |------|-----|-----|
 *    | AC 1 |   1 |   1 |
 *    | BC 1 |   1 |   0 |
 *    | BC 2 |   2 |  -1 |
 *
 *    Also `yy` always returns the last two digits of a year,
 *    while `uu` pads single digit years to 2 characters and returns other years unchanged:
 *
 *    | Year | `yy` | `uu` |
 *    |------|------|------|
 *    | 1    |   01 |   01 |
 *    | 14   |   14 |   14 |
 *    | 376  |   76 |  376 |
 *    | 1453 |   53 | 1453 |
 *
 *    The same difference is true for local and ISO week-numbering years (`Y` and `R`),
 *    except local week-numbering years are dependent on `options.weekStartsOn`
 *    and `options.firstWeekContainsDate` (compare [getISOWeekYear]{@link https://date-fns.org/docs/getISOWeekYear}
 *    and [getWeekYear]{@link https://date-fns.org/docs/getWeekYear}).
 *
 * 6. Specific non-location timezones are currently unavailable in `date-fns`,
 *    so right now these tokens fall back to GMT timezones.
 *
 * 7. These patterns are not in the Unicode Technical Standard #35:
 *    - `i`: ISO day of week
 *    - `I`: ISO week of year
 *    - `R`: ISO week-numbering year
 *    - `t`: seconds timestamp
 *    - `T`: milliseconds timestamp
 *    - `o`: ordinal number modifier
 *    - `P`: long localized date
 *    - `p`: long localized time
 *
 * 8. `YY` and `YYYY` tokens represent week-numbering years but they are often confused with years.
 *    You should enable `options.useAdditionalWeekYearTokens` to use them. See: https://git.io/fxCyr
 *
 * 9. `D` and `DD` tokens represent days of the year but they are often confused with days of the month.
 *    You should enable `options.useAdditionalDayOfYearTokens` to use them. See: https://git.io/fxCyr
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * - The second argument is now required for the sake of explicitness.
 *
 *   ```javascript
 *   // Before v2.0.0
 *   format(new Date(2016, 0, 1))
 *
 *   // v2.0.0 onward
 *   format(new Date(2016, 0, 1), "yyyy-MM-dd'T'HH:mm:ss.SSSxxx")
 *   ```
 *
 * - New format string API for `format` function
 *   which is based on [Unicode Technical Standard #35](https://www.unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table).
 *   See [this post](https://blog.date-fns.org/post/unicode-tokens-in-date-fns-v2-sreatyki91jg) for more details.
 *
 * - Characters are now escaped using single quote symbols (`'`) instead of square brackets.
 *
 * @param {Date|Number} date - the original date
 * @param {String} format - the string of tokens
 * @param {Object} [options] - an object with options.
 * @param {Locale} [options.locale=defaultLocale] - the locale object. See [Locale]{@link https://date-fns.org/docs/Locale}
 * @param {0|1|2|3|4|5|6} [options.weekStartsOn=0] - the index of the first day of the week (0 - Sunday)
 * @param {Number} [options.firstWeekContainsDate=1] - the day of January, which is
 * @param {Boolean} [options.useAdditionalWeekYearTokens=false] - if true, allows usage of the week-numbering year tokens `YY` and `YYYY`;
 *   see: https://git.io/fxCyr
 * @param {Boolean} [options.useAdditionalDayOfYearTokens=false] - if true, allows usage of the day of year tokens `D` and `DD`;
 *   see: https://git.io/fxCyr
 * @returns {String} the formatted date string
 * @throws {TypeError} 2 arguments required
 * @throws {RangeError} `date` must not be Invalid Date
 * @throws {RangeError} `options.locale` must contain `localize` property
 * @throws {RangeError} `options.locale` must contain `formatLong` property
 * @throws {RangeError} `options.weekStartsOn` must be between 0 and 6
 * @throws {RangeError} `options.firstWeekContainsDate` must be between 1 and 7
 * @throws {RangeError} use `yyyy` instead of `YYYY` for formatting years using [format provided] to the input [input provided]; see: https://git.io/fxCyr
 * @throws {RangeError} use `yy` instead of `YY` for formatting years using [format provided] to the input [input provided]; see: https://git.io/fxCyr
 * @throws {RangeError} use `d` instead of `D` for formatting days of the month using [format provided] to the input [input provided]; see: https://git.io/fxCyr
 * @throws {RangeError} use `dd` instead of `DD` for formatting days of the month using [format provided] to the input [input provided]; see: https://git.io/fxCyr
 * @throws {RangeError} format string contains an unescaped latin alphabet character
 *
 * @example
 * // Represent 11 February 2014 in middle-endian format:
 * var result = format(new Date(2014, 1, 11), 'MM/dd/yyyy')
 * //=> '02/11/2014'
 *
 * @example
 * // Represent 2 July 2014 in Esperanto:
 * import { eoLocale } from 'date-fns/locale/eo'
 * var result = format(new Date(2014, 6, 2), "do 'de' MMMM yyyy", {
 *   locale: eoLocale
 * })
 * //=> '2-a de julio 2014'
 *
 * @example
 * // Escape string by single quote characters:
 * var result = format(new Date(2014, 6, 2, 15), "h 'o''clock'")
 * //=> "3 o'clock"
 */
function format(e, t, a) {
  requiredArgs(2, arguments);
  var n = String(t), i = a || {}, o = i.locale || r, s = o.options && o.options.firstWeekContainsDate, d = null == s ? 1 : toInteger(s), u = null == i.firstWeekContainsDate ? d : toInteger(i.firstWeekContainsDate);
  // Test if weekStartsOn is between 1 and 7 _and_ is not NaN
  if (!(u >= 1 && u <= 7)) throw new RangeError("firstWeekContainsDate must be between 1 and 7 inclusively");
  var m = o.options && o.options.weekStartsOn, l = null == m ? 0 : toInteger(m), g = null == i.weekStartsOn ? l : toInteger(i.weekStartsOn);
  // Test if weekStartsOn is between 0 and 6 _and_ is not NaN
  if (!(g >= 0 && g <= 6)) throw new RangeError("weekStartsOn must be between 0 and 6 inclusively");
  if (!o.localize) throw new RangeError("locale must contain localize property");
  if (!o.formatLong) throw new RangeError("locale must contain formatLong property");
  var f = toDate(e);
  if (!isValid(f)) throw new RangeError("Invalid time value");
 // Convert the date in system timezone to the same date in UTC+00:00 timezone.
  // This ensures that when UTC functions will be implemented, locales will be compatible with them.
  // See an issue about UTC functions: https://github.com/date-fns/date-fns/issues/376
    var p = getTimezoneOffsetInMilliseconds(f), y = subMilliseconds(f, p), M = {
    firstWeekContainsDate: u,
    weekStartsOn: g,
    locale: o,
    _originalDate: f
  }, k = n.match(w).map((function(e) {
    var t = e[0];
    return "p" === t || "P" === t ? (0, h[t])(e, o.formatLong, M) : e;
  })).join("").match(b).map((function(a) {
    // Replace two single quote characters with one single quote character
    if ("''" === a) return "'";
    var n = a[0];
    if ("'" === n) return cleanEscapedString(a);
    var r = c[n];
    if (r) return !i.useAdditionalWeekYearTokens && isProtectedWeekYearToken(a) && throwProtectedError(a, t, e), 
    !i.useAdditionalDayOfYearTokens && isProtectedDayOfYearToken(a) && throwProtectedError(a, t, e), 
    r(y, a, o.localize, M);
    if (n.match(v)) throw new RangeError("Format string contains an unescaped latin alphabet character `" + n + "`");
    return a;
  })).join("");
  return k;
}

function cleanEscapedString(e) {
  return e.match(p)[1].replace(y, "'");
}

/**
 * @name getDaysInMonth
 * @category Month Helpers
 * @summary Get the number of days in a month of the given date.
 *
 * @description
 * Get the number of days in a month of the given date.
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * @param {Date|Number} date - the given date
 * @returns {Number} the number of days in a month
 * @throws {TypeError} 1 argument required
 *
 * @example
 * // How many days are in February 2000?
 * const result = getDaysInMonth(new Date(2000, 1))
 * //=> 29
 */ function getDaysInMonth(e) {
  requiredArgs(1, arguments);
  var t = toDate(e), a = t.getFullYear(), n = t.getMonth(), i = new Date(0);
  return i.setFullYear(a, n + 1, 0), i.setHours(0, 0, 0, 0), i.getDate();
}

/**
 * @name subDays
 * @category Day Helpers
 * @summary Subtract the specified number of days from the given date.
 *
 * @description
 * Subtract the specified number of days from the given date.
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * @param {Date|Number} date - the date to be changed
 * @param {Number} amount - the amount of days to be subtracted. Positive decimals will be rounded using `Math.floor`, decimals less than zero will be rounded using `Math.ceil`.
 * @returns {Date} the new date with the days subtracted
 * @throws {TypeError} 2 arguments required
 *
 * @example
 * // Subtract 10 days from 1 September 2014:
 * const result = subDays(new Date(2014, 8, 1), 10)
 * //=> Fri Aug 22 2014 00:00:00
 */ function subDays(e, t) {
  requiredArgs(2, arguments);
  var a = toInteger(t);
  return addDays(e, -a);
}

/**
 * @name isToday
 * @category Day Helpers
 * @summary Is the given date today?
 * @pure false
 *
 * @description
 * Is the given date today?
 *
 * > ⚠️ Please note that this function is not present in the FP submodule as
 * > it uses `Date.now()` internally hence impure and can't be safely curried.
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * @param {Date|Number} date - the date to check
 * @returns {Boolean} the date is today
 * @throws {TypeError} 1 argument required
 *
 * @example
 * // If today is 6 October 2014, is 6 October 14:00:00 today?
 * var result = isToday(new Date(2014, 9, 6, 14, 0))
 * //=> true
 */
/**
 * @name setMonth
 * @category Month Helpers
 * @summary Set the month to the given date.
 *
 * @description
 * Set the month to the given date.
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * @param {Date|Number} date - the date to be changed
 * @param {Number} month - the month of the new date
 * @returns {Date} the new date with the month set
 * @throws {TypeError} 2 arguments required
 *
 * @example
 * // Set February to 1 September 2014:
 * const result = setMonth(new Date(2014, 8, 1), 1)
 * //=> Sat Feb 01 2014 00:00:00
 */
function setMonth(e, t) {
  requiredArgs(2, arguments);
  var a = toDate(e), n = toInteger(t), i = a.getFullYear(), r = a.getDate(), o = new Date(0);
  o.setFullYear(i, n, 15), o.setHours(0, 0, 0, 0);
  var s = getDaysInMonth(o);
 // Set the last day of the new month
  // if the original date was the last day of the longer month
    return a.setMonth(n, Math.min(r, s)), a;
}

/**
 * @name setDate
 * @category Day Helpers
 * @summary Set the day of the month to the given date.
 *
 * @description
 * Set the day of the month to the given date.
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * @param {Date|Number} date - the date to be changed
 * @param {Number} dayOfMonth - the day of the month of the new date
 * @returns {Date} the new date with the day of the month set
 * @throws {TypeError} 2 arguments required
 *
 * @example
 * // Set the 30th day of the month to 1 September 2014:
 * var result = setDate(new Date(2014, 8, 1), 30)
 * //=> Tue Sep 30 2014 00:00:00
 */ const isConnected = e => !("isConnected" in e) || e.isConnected, M = ((e, t) => {
  let a;
  return (...n) => {
    a && clearTimeout(a), a = setTimeout((() => {
      a = 0, e(...n);
    }), t);
  };
})((e => {
  for (let t of e.keys()) e.set(t, e.get(t).filter(isConnected));
}), 2e3), removeFromArray = (e, t) => {
  const a = e.indexOf(t);
  a >= 0 && (e[a] = e[e.length - 1], e.length--);
};

// See issue: https://github.com/date-fns/date-fns/issues/376
function isSameUTCWeek(e, t, a) {
  requiredArgs(2, arguments);
  var n = startOfUTCWeek(e, a), i = startOfUTCWeek(t, a);
  return n.getTime() === i.getTime();
}

var k = {
  lessThanXSeconds: {
    standalone: {
      one: "weniger als 1 Sekunde",
      other: "weniger als {{count}} Sekunden"
    },
    withPreposition: {
      one: "weniger als 1 Sekunde",
      other: "weniger als {{count}} Sekunden"
    }
  },
  xSeconds: {
    standalone: {
      one: "1 Sekunde",
      other: "{{count}} Sekunden"
    },
    withPreposition: {
      one: "1 Sekunde",
      other: "{{count}} Sekunden"
    }
  },
  halfAMinute: {
    standalone: "halbe Minute",
    withPreposition: "halben Minute"
  },
  lessThanXMinutes: {
    standalone: {
      one: "weniger als 1 Minute",
      other: "weniger als {{count}} Minuten"
    },
    withPreposition: {
      one: "weniger als 1 Minute",
      other: "weniger als {{count}} Minuten"
    }
  },
  xMinutes: {
    standalone: {
      one: "1 Minute",
      other: "{{count}} Minuten"
    },
    withPreposition: {
      one: "1 Minute",
      other: "{{count}} Minuten"
    }
  },
  aboutXHours: {
    standalone: {
      one: "etwa 1 Stunde",
      other: "etwa {{count}} Stunden"
    },
    withPreposition: {
      one: "etwa 1 Stunde",
      other: "etwa {{count}} Stunden"
    }
  },
  xHours: {
    standalone: {
      one: "1 Stunde",
      other: "{{count}} Stunden"
    },
    withPreposition: {
      one: "1 Stunde",
      other: "{{count}} Stunden"
    }
  },
  xDays: {
    standalone: {
      one: "1 Tag",
      other: "{{count}} Tage"
    },
    withPreposition: {
      one: "1 Tag",
      other: "{{count}} Tagen"
    }
  },
  aboutXWeeks: {
    standalone: {
      one: "etwa 1 Woche",
      other: "etwa {{count}} Wochen"
    },
    withPreposition: {
      one: "etwa 1 Woche",
      other: "etwa {{count}} Wochen"
    }
  },
  xWeeks: {
    standalone: {
      one: "1 Woche",
      other: "{{count}} Wochen"
    },
    withPreposition: {
      one: "1 Woche",
      other: "{{count}} Wochen"
    }
  },
  aboutXMonths: {
    standalone: {
      one: "etwa 1 Monat",
      other: "etwa {{count}} Monate"
    },
    withPreposition: {
      one: "etwa 1 Monat",
      other: "etwa {{count}} Monaten"
    }
  },
  xMonths: {
    standalone: {
      one: "1 Monat",
      other: "{{count}} Monate"
    },
    withPreposition: {
      one: "1 Monat",
      other: "{{count}} Monaten"
    }
  },
  aboutXYears: {
    standalone: {
      one: "etwa 1 Jahr",
      other: "etwa {{count}} Jahre"
    },
    withPreposition: {
      one: "etwa 1 Jahr",
      other: "etwa {{count}} Jahren"
    }
  },
  xYears: {
    standalone: {
      one: "1 Jahr",
      other: "{{count}} Jahre"
    },
    withPreposition: {
      one: "1 Jahr",
      other: "{{count}} Jahren"
    }
  },
  overXYears: {
    standalone: {
      one: "mehr als 1 Jahr",
      other: "mehr als {{count}} Jahre"
    },
    withPreposition: {
      one: "mehr als 1 Jahr",
      other: "mehr als {{count}} Jahren"
    }
  },
  almostXYears: {
    standalone: {
      one: "fast 1 Jahr",
      other: "fast {{count}} Jahre"
    },
    withPreposition: {
      one: "fast 1 Jahr",
      other: "fast {{count}} Jahren"
    }
  }
}, z = {
  date: buildFormatLongFn({
    formats: {
      full: "EEEE, do MMMM y",
      // Montag, 7. Januar 2018
      long: "do MMMM y",
      // 7. Januar 2018
      medium: "do MMM y",
      // 7. Jan. 2018
      short: "dd.MM.y"
    },
    defaultWidth: "full"
  }),
  time: buildFormatLongFn({
    formats: {
      full: "HH:mm:ss zzzz",
      long: "HH:mm:ss z",
      medium: "HH:mm:ss",
      short: "HH:mm"
    },
    defaultWidth: "full"
  }),
  dateTime: buildFormatLongFn({
    formats: {
      full: "{{date}} 'um' {{time}}",
      long: "{{date}} 'um' {{time}}",
      medium: "{{date}} {{time}}",
      short: "{{date}} {{time}}"
    },
    defaultWidth: "full"
  })
}, P = {
  lastWeek: "'letzten' eeee 'um' p",
  yesterday: "'gestern um' p",
  today: "'heute um' p",
  tomorrow: "'morgen um' p",
  nextWeek: "eeee 'um' p",
  other: "P"
}, W = {
  narrow: [ "J", "F", "M", "A", "M", "J", "J", "A", "S", "O", "N", "D" ],
  abbreviated: [ "Jan", "Feb", "Mär", "Apr", "Mai", "Jun", "Jul", "Aug", "Sep", "Okt", "Nov", "Dez" ],
  wide: [ "Januar", "Februar", "März", "April", "Mai", "Juni", "Juli", "August", "September", "Oktober", "November", "Dezember" ]
}, F = {
  narrow: W.narrow,
  abbreviated: [ "Jan.", "Feb.", "März", "Apr.", "Mai", "Juni", "Juli", "Aug.", "Sep.", "Okt.", "Nov.", "Dez." ],
  wide: W.wide
}, T = {
  code: "de",
  formatDistance: function(e, t, a) {
    var n, i = null != a && a.addSuffix ? k[e].withPreposition : k[e].standalone;
    return n = "string" == typeof i ? i : 1 === t ? i.one : i.other.replace("{{count}}", String(t)), 
    null != a && a.addSuffix ? a.comparison && a.comparison > 0 ? "in " + n : "vor " + n : n;
  },
  formatLong: z,
  formatRelative: function(e, t, a, n) {
    return P[e];
  },
  localize: {
    ordinalNumber: function(e) {
      return Number(e) + ".";
    },
    era: buildLocalizeFn({
      values: {
        narrow: [ "v.Chr.", "n.Chr." ],
        abbreviated: [ "v.Chr.", "n.Chr." ],
        wide: [ "vor Christus", "nach Christus" ]
      },
      defaultWidth: "wide"
    }),
    quarter: buildLocalizeFn({
      values: {
        narrow: [ "1", "2", "3", "4" ],
        abbreviated: [ "Q1", "Q2", "Q3", "Q4" ],
        wide: [ "1. Quartal", "2. Quartal", "3. Quartal", "4. Quartal" ]
      },
      defaultWidth: "wide",
      argumentCallback: function(e) {
        return e - 1;
      }
    }),
    month: buildLocalizeFn({
      values: W,
      formattingValues: F,
      defaultWidth: "wide"
    }),
    day: buildLocalizeFn({
      values: {
        narrow: [ "S", "M", "D", "M", "D", "F", "S" ],
        short: [ "So", "Mo", "Di", "Mi", "Do", "Fr", "Sa" ],
        abbreviated: [ "So.", "Mo.", "Di.", "Mi.", "Do.", "Fr.", "Sa." ],
        wide: [ "Sonntag", "Montag", "Dienstag", "Mittwoch", "Donnerstag", "Freitag", "Samstag" ]
      },
      defaultWidth: "wide"
    }),
    dayPeriod: buildLocalizeFn({
      values: {
        narrow: {
          am: "vm.",
          pm: "nm.",
          midnight: "Mitternacht",
          noon: "Mittag",
          morning: "Morgen",
          afternoon: "Nachm.",
          evening: "Abend",
          night: "Nacht"
        },
        abbreviated: {
          am: "vorm.",
          pm: "nachm.",
          midnight: "Mitternacht",
          noon: "Mittag",
          morning: "Morgen",
          afternoon: "Nachmittag",
          evening: "Abend",
          night: "Nacht"
        },
        wide: {
          am: "vormittags",
          pm: "nachmittags",
          midnight: "Mitternacht",
          noon: "Mittag",
          morning: "Morgen",
          afternoon: "Nachmittag",
          evening: "Abend",
          night: "Nacht"
        }
      },
      defaultWidth: "wide",
      formattingValues: {
        narrow: {
          am: "vm.",
          pm: "nm.",
          midnight: "Mitternacht",
          noon: "Mittag",
          morning: "morgens",
          afternoon: "nachm.",
          evening: "abends",
          night: "nachts"
        },
        abbreviated: {
          am: "vorm.",
          pm: "nachm.",
          midnight: "Mitternacht",
          noon: "Mittag",
          morning: "morgens",
          afternoon: "nachmittags",
          evening: "abends",
          night: "nachts"
        },
        wide: {
          am: "vormittags",
          pm: "nachmittags",
          midnight: "Mitternacht",
          noon: "Mittag",
          morning: "morgens",
          afternoon: "nachmittags",
          evening: "abends",
          night: "nachts"
        }
      },
      defaultFormattingWidth: "wide"
    })
  },
  match: {
    ordinalNumber: buildMatchPatternFn({
      matchPattern: /^(\d+)(\.)?/i,
      parsePattern: /\d+/i,
      valueCallback: function(e) {
        return parseInt(e);
      }
    }),
    era: buildMatchFn({
      matchPatterns: {
        narrow: /^(v\.? ?Chr\.?|n\.? ?Chr\.?)/i,
        abbreviated: /^(v\.? ?Chr\.?|n\.? ?Chr\.?)/i,
        wide: /^(vor Christus|vor unserer Zeitrechnung|nach Christus|unserer Zeitrechnung)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        any: [ /^v/i, /^n/i ]
      },
      defaultParseWidth: "any"
    }),
    quarter: buildMatchFn({
      matchPatterns: {
        narrow: /^[1234]/i,
        abbreviated: /^q[1234]/i,
        wide: /^[1234](\.)? Quartal/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        any: [ /1/i, /2/i, /3/i, /4/i ]
      },
      defaultParseWidth: "any",
      valueCallback: function(e) {
        return e + 1;
      }
    }),
    month: buildMatchFn({
      matchPatterns: {
        narrow: /^[jfmasond]/i,
        abbreviated: /^(j[aä]n|feb|mär[z]?|apr|mai|jun[i]?|jul[i]?|aug|sep|okt|nov|dez)\.?/i,
        wide: /^(januar|februar|märz|april|mai|juni|juli|august|september|oktober|november|dezember)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        narrow: [ /^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i ],
        any: [ /^j[aä]/i, /^f/i, /^mär/i, /^ap/i, /^mai/i, /^jun/i, /^jul/i, /^au/i, /^s/i, /^o/i, /^n/i, /^d/i ]
      },
      defaultParseWidth: "any"
    }),
    day: buildMatchFn({
      matchPatterns: {
        narrow: /^[smdmf]/i,
        short: /^(so|mo|di|mi|do|fr|sa)/i,
        abbreviated: /^(son?|mon?|die?|mit?|don?|fre?|sam?)\.?/i,
        wide: /^(sonntag|montag|dienstag|mittwoch|donnerstag|freitag|samstag)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        any: [ /^so/i, /^mo/i, /^di/i, /^mi/i, /^do/i, /^f/i, /^sa/i ]
      },
      defaultParseWidth: "any"
    }),
    dayPeriod: buildMatchFn({
      matchPatterns: {
        narrow: /^(vm\.?|nm\.?|Mitternacht|Mittag|morgens|nachm\.?|abends|nachts)/i,
        abbreviated: /^(vorm\.?|nachm\.?|Mitternacht|Mittag|morgens|nachm\.?|abends|nachts)/i,
        wide: /^(vormittags|nachmittags|Mitternacht|Mittag|morgens|nachmittags|abends|nachts)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        any: {
          am: /^v/i,
          pm: /^n/i,
          midnight: /^Mitte/i,
          noon: /^Mitta/i,
          morning: /morgens/i,
          afternoon: /nachmittags/i,
          // will never be matched. Afternoon is matched by `pm`
          evening: /abends/i,
          night: /nachts/i
        }
      },
      defaultParseWidth: "any"
    })
  },
  options: {
    weekStartsOn: 1
    /* Monday */ ,
    firstWeekContainsDate: 4
  }
}, C = {
  lessThanXSeconds: {
    one: "menos de un segundo",
    other: "menos de {{count}} segundos"
  },
  xSeconds: {
    one: "1 segundo",
    other: "{{count}} segundos"
  },
  halfAMinute: "medio minuto",
  lessThanXMinutes: {
    one: "menos de un minuto",
    other: "menos de {{count}} minutos"
  },
  xMinutes: {
    one: "1 minuto",
    other: "{{count}} minutos"
  },
  aboutXHours: {
    one: "alrededor de 1 hora",
    other: "alrededor de {{count}} horas"
  },
  xHours: {
    one: "1 hora",
    other: "{{count}} horas"
  },
  xDays: {
    one: "1 día",
    other: "{{count}} días"
  },
  aboutXWeeks: {
    one: "alrededor de 1 semana",
    other: "alrededor de {{count}} semanas"
  },
  xWeeks: {
    one: "1 semana",
    other: "{{count}} semanas"
  },
  aboutXMonths: {
    one: "alrededor de 1 mes",
    other: "alrededor de {{count}} meses"
  },
  xMonths: {
    one: "1 mes",
    other: "{{count}} meses"
  },
  aboutXYears: {
    one: "alrededor de 1 año",
    other: "alrededor de {{count}} años"
  },
  xYears: {
    one: "1 año",
    other: "{{count}} años"
  },
  overXYears: {
    one: "más de 1 año",
    other: "más de {{count}} años"
  },
  almostXYears: {
    one: "casi 1 año",
    other: "casi {{count}} años"
  }
}, S = {
  date: buildFormatLongFn({
    formats: {
      full: "EEEE, d 'de' MMMM 'de' y",
      long: "d 'de' MMMM 'de' y",
      medium: "d MMM y",
      short: "dd/MM/y"
    },
    defaultWidth: "full"
  }),
  time: buildFormatLongFn({
    formats: {
      full: "HH:mm:ss zzzz",
      long: "HH:mm:ss z",
      medium: "HH:mm:ss",
      short: "HH:mm"
    },
    defaultWidth: "full"
  }),
  dateTime: buildFormatLongFn({
    formats: {
      full: "{{date}} 'a las' {{time}}",
      long: "{{date}} 'a las' {{time}}",
      medium: "{{date}}, {{time}}",
      short: "{{date}}, {{time}}"
    },
    defaultWidth: "full"
  })
}, D = {
  lastWeek: "'el' eeee 'pasado a la' p",
  yesterday: "'ayer a la' p",
  today: "'hoy a la' p",
  tomorrow: "'mañana a la' p",
  nextWeek: "eeee 'a la' p",
  other: "P"
}, x = {
  lastWeek: "'el' eeee 'pasado a las' p",
  yesterday: "'ayer a las' p",
  today: "'hoy a las' p",
  tomorrow: "'mañana a las' p",
  nextWeek: "eeee 'a las' p",
  other: "P"
}, L = {
  code: "es",
  formatDistance: function(e, t, a) {
    var n, i = C[e];
    return n = "string" == typeof i ? i : 1 === t ? i.one : i.other.replace("{{count}}", t.toString()), 
    null != a && a.addSuffix ? a.comparison && a.comparison > 0 ? "en " + n : "hace " + n : n;
  },
  formatLong: S,
  formatRelative: function(e, t, a, n) {
    return 1 !== t.getUTCHours() ? x[e] : D[e];
  },
  localize: {
    ordinalNumber: function(e, t) {
      return Number(e) + "º";
    },
    era: buildLocalizeFn({
      values: {
        narrow: [ "AC", "DC" ],
        abbreviated: [ "AC", "DC" ],
        wide: [ "antes de cristo", "después de cristo" ]
      },
      defaultWidth: "wide"
    }),
    quarter: buildLocalizeFn({
      values: {
        narrow: [ "1", "2", "3", "4" ],
        abbreviated: [ "T1", "T2", "T3", "T4" ],
        wide: [ "1º trimestre", "2º trimestre", "3º trimestre", "4º trimestre" ]
      },
      defaultWidth: "wide",
      argumentCallback: function(e) {
        return Number(e) - 1;
      }
    }),
    month: buildLocalizeFn({
      values: {
        narrow: [ "e", "f", "m", "a", "m", "j", "j", "a", "s", "o", "n", "d" ],
        abbreviated: [ "ene", "feb", "mar", "abr", "may", "jun", "jul", "ago", "sep", "oct", "nov", "dic" ],
        wide: [ "enero", "febrero", "marzo", "abril", "mayo", "junio", "julio", "agosto", "septiembre", "octubre", "noviembre", "diciembre" ]
      },
      defaultWidth: "wide"
    }),
    day: buildLocalizeFn({
      values: {
        narrow: [ "d", "l", "m", "m", "j", "v", "s" ],
        short: [ "do", "lu", "ma", "mi", "ju", "vi", "sá" ],
        abbreviated: [ "dom", "lun", "mar", "mié", "jue", "vie", "sáb" ],
        wide: [ "domingo", "lunes", "martes", "miércoles", "jueves", "viernes", "sábado" ]
      },
      defaultWidth: "wide"
    }),
    dayPeriod: buildLocalizeFn({
      values: {
        narrow: {
          am: "a",
          pm: "p",
          midnight: "mn",
          noon: "md",
          morning: "mañana",
          afternoon: "tarde",
          evening: "tarde",
          night: "noche"
        },
        abbreviated: {
          am: "AM",
          pm: "PM",
          midnight: "medianoche",
          noon: "mediodia",
          morning: "mañana",
          afternoon: "tarde",
          evening: "tarde",
          night: "noche"
        },
        wide: {
          am: "a.m.",
          pm: "p.m.",
          midnight: "medianoche",
          noon: "mediodia",
          morning: "mañana",
          afternoon: "tarde",
          evening: "tarde",
          night: "noche"
        }
      },
      defaultWidth: "wide",
      formattingValues: {
        narrow: {
          am: "a",
          pm: "p",
          midnight: "mn",
          noon: "md",
          morning: "de la mañana",
          afternoon: "de la tarde",
          evening: "de la tarde",
          night: "de la noche"
        },
        abbreviated: {
          am: "AM",
          pm: "PM",
          midnight: "medianoche",
          noon: "mediodia",
          morning: "de la mañana",
          afternoon: "de la tarde",
          evening: "de la tarde",
          night: "de la noche"
        },
        wide: {
          am: "a.m.",
          pm: "p.m.",
          midnight: "medianoche",
          noon: "mediodia",
          morning: "de la mañana",
          afternoon: "de la tarde",
          evening: "de la tarde",
          night: "de la noche"
        }
      },
      defaultFormattingWidth: "wide"
    })
  },
  match: {
    ordinalNumber: buildMatchPatternFn({
      matchPattern: /^(\d+)(º)?/i,
      parsePattern: /\d+/i,
      valueCallback: function(e) {
        return parseInt(e, 10);
      }
    }),
    era: buildMatchFn({
      matchPatterns: {
        narrow: /^(ac|dc|a|d)/i,
        abbreviated: /^(a\.?\s?c\.?|a\.?\s?e\.?\s?c\.?|d\.?\s?c\.?|e\.?\s?c\.?)/i,
        wide: /^(antes de cristo|antes de la era com[uú]n|despu[eé]s de cristo|era com[uú]n)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        any: [ /^ac/i, /^dc/i ],
        wide: [ /^(antes de cristo|antes de la era com[uú]n)/i, /^(despu[eé]s de cristo|era com[uú]n)/i ]
      },
      defaultParseWidth: "any"
    }),
    quarter: buildMatchFn({
      matchPatterns: {
        narrow: /^[1234]/i,
        abbreviated: /^T[1234]/i,
        wide: /^[1234](º)? trimestre/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        any: [ /1/i, /2/i, /3/i, /4/i ]
      },
      defaultParseWidth: "any",
      valueCallback: function(e) {
        return e + 1;
      }
    }),
    month: buildMatchFn({
      matchPatterns: {
        narrow: /^[efmajsond]/i,
        abbreviated: /^(ene|feb|mar|abr|may|jun|jul|ago|sep|oct|nov|dic)/i,
        wide: /^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        narrow: [ /^e/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i ],
        any: [ /^en/i, /^feb/i, /^mar/i, /^abr/i, /^may/i, /^jun/i, /^jul/i, /^ago/i, /^sep/i, /^oct/i, /^nov/i, /^dic/i ]
      },
      defaultParseWidth: "any"
    }),
    day: buildMatchFn({
      matchPatterns: {
        narrow: /^[dlmjvs]/i,
        short: /^(do|lu|ma|mi|ju|vi|s[áa])/i,
        abbreviated: /^(dom|lun|mar|mi[ée]|jue|vie|s[áa]b)/i,
        wide: /^(domingo|lunes|martes|mi[ée]rcoles|jueves|viernes|s[áa]bado)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        narrow: [ /^d/i, /^l/i, /^m/i, /^m/i, /^j/i, /^v/i, /^s/i ],
        any: [ /^do/i, /^lu/i, /^ma/i, /^mi/i, /^ju/i, /^vi/i, /^sa/i ]
      },
      defaultParseWidth: "any"
    }),
    dayPeriod: buildMatchFn({
      matchPatterns: {
        narrow: /^(a|p|mn|md|(de la|a las) (mañana|tarde|noche))/i,
        any: /^([ap]\.?\s?m\.?|medianoche|mediodia|(de la|a las) (mañana|tarde|noche))/i
      },
      defaultMatchWidth: "any",
      parsePatterns: {
        any: {
          am: /^a/i,
          pm: /^p/i,
          midnight: /^mn/i,
          noon: /^md/i,
          morning: /mañana/i,
          afternoon: /tarde/i,
          evening: /tarde/i,
          night: /noche/i
        }
      },
      defaultParseWidth: "any"
    })
  },
  options: {
    weekStartsOn: 1
    /* Monday */ ,
    firstWeekContainsDate: 1
  }
}, j = {
  lessThanXSeconds: {
    one: "moins d’une seconde",
    other: "moins de {{count}} secondes"
  },
  xSeconds: {
    one: "1 seconde",
    other: "{{count}} secondes"
  },
  halfAMinute: "30 secondes",
  lessThanXMinutes: {
    one: "moins d’une minute",
    other: "moins de {{count}} minutes"
  },
  xMinutes: {
    one: "1 minute",
    other: "{{count}} minutes"
  },
  aboutXHours: {
    one: "environ 1 heure",
    other: "environ {{count}} heures"
  },
  xHours: {
    one: "1 heure",
    other: "{{count}} heures"
  },
  xDays: {
    one: "1 jour",
    other: "{{count}} jours"
  },
  aboutXWeeks: {
    one: "environ 1 semaine",
    other: "environ {{count}} semaines"
  },
  xWeeks: {
    one: "1 semaine",
    other: "{{count}} semaines"
  },
  aboutXMonths: {
    one: "environ 1 mois",
    other: "environ {{count}} mois"
  },
  xMonths: {
    one: "1 mois",
    other: "{{count}} mois"
  },
  aboutXYears: {
    one: "environ 1 an",
    other: "environ {{count}} ans"
  },
  xYears: {
    one: "1 an",
    other: "{{count}} ans"
  },
  overXYears: {
    one: "plus d’un an",
    other: "plus de {{count}} ans"
  },
  almostXYears: {
    one: "presqu’un an",
    other: "presque {{count}} ans"
  }
}, A = {
  date: buildFormatLongFn({
    formats: {
      full: "EEEE d MMMM y",
      long: "d MMMM y",
      medium: "d MMM y",
      short: "dd/MM/y"
    },
    defaultWidth: "full"
  }),
  time: buildFormatLongFn({
    formats: {
      full: "HH:mm:ss zzzz",
      long: "HH:mm:ss z",
      medium: "HH:mm:ss",
      short: "HH:mm"
    },
    defaultWidth: "full"
  }),
  dateTime: buildFormatLongFn({
    formats: {
      full: "{{date}} 'à' {{time}}",
      long: "{{date}} 'à' {{time}}",
      medium: "{{date}}, {{time}}",
      short: "{{date}}, {{time}}"
    },
    defaultWidth: "full"
  })
}, E = {
  lastWeek: "eeee 'dernier à' p",
  yesterday: "'hier à' p",
  today: "'aujourd’hui à' p",
  tomorrow: "'demain à' p'",
  nextWeek: "eeee 'prochain à' p",
  other: "P"
}, O = {
  code: "fr",
  formatDistance: function(e, t, a) {
    var n, i = j[e];
    return n = "string" == typeof i ? i : 1 === t ? i.one : i.other.replace("{{count}}", String(t)), 
    null != a && a.addSuffix ? a.comparison && a.comparison > 0 ? "dans " + n : "il y a " + n : n;
  },
  formatLong: A,
  formatRelative: function(e, t, a, n) {
    return E[e];
  },
  localize: {
    ordinalNumber: function(e, t) {
      var a = Number(e), n = null == t ? void 0 : t.unit;
      if (0 === a) return "0";
      return a + (1 === a ? n && [ "year", "week", "hour", "minute", "second" ].includes(n) ? "ère" : "er" : "ème");
    },
    era: buildLocalizeFn({
      values: {
        narrow: [ "av. J.-C", "ap. J.-C" ],
        abbreviated: [ "av. J.-C", "ap. J.-C" ],
        wide: [ "avant Jésus-Christ", "après Jésus-Christ" ]
      },
      defaultWidth: "wide"
    }),
    quarter: buildLocalizeFn({
      values: {
        narrow: [ "T1", "T2", "T3", "T4" ],
        abbreviated: [ "1er trim.", "2ème trim.", "3ème trim.", "4ème trim." ],
        wide: [ "1er trimestre", "2ème trimestre", "3ème trimestre", "4ème trimestre" ]
      },
      defaultWidth: "wide",
      argumentCallback: function(e) {
        return e - 1;
      }
    }),
    month: buildLocalizeFn({
      values: {
        narrow: [ "J", "F", "M", "A", "M", "J", "J", "A", "S", "O", "N", "D" ],
        abbreviated: [ "janv.", "févr.", "mars", "avr.", "mai", "juin", "juil.", "août", "sept.", "oct.", "nov.", "déc." ],
        wide: [ "janvier", "février", "mars", "avril", "mai", "juin", "juillet", "août", "septembre", "octobre", "novembre", "décembre" ]
      },
      defaultWidth: "wide"
    }),
    day: buildLocalizeFn({
      values: {
        narrow: [ "D", "L", "M", "M", "J", "V", "S" ],
        short: [ "di", "lu", "ma", "me", "je", "ve", "sa" ],
        abbreviated: [ "dim.", "lun.", "mar.", "mer.", "jeu.", "ven.", "sam." ],
        wide: [ "dimanche", "lundi", "mardi", "mercredi", "jeudi", "vendredi", "samedi" ]
      },
      defaultWidth: "wide"
    }),
    dayPeriod: buildLocalizeFn({
      values: {
        narrow: {
          am: "AM",
          pm: "PM",
          midnight: "minuit",
          noon: "midi",
          morning: "mat.",
          afternoon: "ap.m.",
          evening: "soir",
          night: "mat."
        },
        abbreviated: {
          am: "AM",
          pm: "PM",
          midnight: "minuit",
          noon: "midi",
          morning: "matin",
          afternoon: "après-midi",
          evening: "soir",
          night: "matin"
        },
        wide: {
          am: "AM",
          pm: "PM",
          midnight: "minuit",
          noon: "midi",
          morning: "du matin",
          afternoon: "de l’après-midi",
          evening: "du soir",
          night: "du matin"
        }
      },
      defaultWidth: "wide"
    })
  },
  match: {
    ordinalNumber: buildMatchPatternFn({
      matchPattern: /^(\d+)(ième|ère|ème|er|e)?/i,
      parsePattern: /\d+/i,
      valueCallback: function(e) {
        return parseInt(e);
      }
    }),
    era: buildMatchFn({
      matchPatterns: {
        narrow: /^(av\.J\.C|ap\.J\.C|ap\.J\.-C)/i,
        abbreviated: /^(av\.J\.-C|av\.J-C|apr\.J\.-C|apr\.J-C|ap\.J-C)/i,
        wide: /^(avant Jésus-Christ|après Jésus-Christ)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        any: [ /^av/i, /^ap/i ]
      },
      defaultParseWidth: "any"
    }),
    quarter: buildMatchFn({
      matchPatterns: {
        narrow: /^T?[1234]/i,
        abbreviated: /^[1234](er|ème|e)? trim\.?/i,
        wide: /^[1234](er|ème|e)? trimestre/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        any: [ /1/i, /2/i, /3/i, /4/i ]
      },
      defaultParseWidth: "any",
      valueCallback: function(e) {
        return e + 1;
      }
    }),
    month: buildMatchFn({
      matchPatterns: {
        narrow: /^[jfmasond]/i,
        abbreviated: /^(janv|févr|mars|avr|mai|juin|juill|juil|août|sept|oct|nov|déc)\.?/i,
        wide: /^(janvier|février|mars|avril|mai|juin|juillet|août|septembre|octobre|novembre|décembre)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        narrow: [ /^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i ],
        any: [ /^ja/i, /^f/i, /^mar/i, /^av/i, /^ma/i, /^juin/i, /^juil/i, /^ao/i, /^s/i, /^o/i, /^n/i, /^d/i ]
      },
      defaultParseWidth: "any"
    }),
    day: buildMatchFn({
      matchPatterns: {
        narrow: /^[lmjvsd]/i,
        short: /^(di|lu|ma|me|je|ve|sa)/i,
        abbreviated: /^(dim|lun|mar|mer|jeu|ven|sam)\.?/i,
        wide: /^(dimanche|lundi|mardi|mercredi|jeudi|vendredi|samedi)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        narrow: [ /^d/i, /^l/i, /^m/i, /^m/i, /^j/i, /^v/i, /^s/i ],
        any: [ /^di/i, /^lu/i, /^ma/i, /^me/i, /^je/i, /^ve/i, /^sa/i ]
      },
      defaultParseWidth: "any"
    }),
    dayPeriod: buildMatchFn({
      matchPatterns: {
        narrow: /^(a|p|minuit|midi|mat\.?|ap\.?m\.?|soir|nuit)/i,
        any: /^([ap]\.?\s?m\.?|du matin|de l'après[-\s]midi|du soir|de la nuit)/i
      },
      defaultMatchWidth: "any",
      parsePatterns: {
        any: {
          am: /^a/i,
          pm: /^p/i,
          midnight: /^min/i,
          noon: /^mid/i,
          morning: /mat/i,
          afternoon: /ap/i,
          evening: /soir/i,
          night: /nuit/i
        }
      },
      defaultParseWidth: "any"
    })
  },
  options: {
    weekStartsOn: 1
    /* Monday */ ,
    firstWeekContainsDate: 4
  }
}, q = {
  lessThanXSeconds: {
    one: "meno di un secondo",
    other: "meno di {{count}} secondi"
  },
  xSeconds: {
    one: "un secondo",
    other: "{{count}} secondi"
  },
  halfAMinute: "alcuni secondi",
  lessThanXMinutes: {
    one: "meno di un minuto",
    other: "meno di {{count}} minuti"
  },
  xMinutes: {
    one: "un minuto",
    other: "{{count}} minuti"
  },
  aboutXHours: {
    one: "circa un'ora",
    other: "circa {{count}} ore"
  },
  xHours: {
    one: "un'ora",
    other: "{{count}} ore"
  },
  xDays: {
    one: "un giorno",
    other: "{{count}} giorni"
  },
  aboutXWeeks: {
    one: "circa una settimana",
    other: "circa {{count}} settimane"
  },
  xWeeks: {
    one: "una settimana",
    other: "{{count}} settimane"
  },
  aboutXMonths: {
    one: "circa un mese",
    other: "circa {{count}} mesi"
  },
  xMonths: {
    one: "un mese",
    other: "{{count}} mesi"
  },
  aboutXYears: {
    one: "circa un anno",
    other: "circa {{count}} anni"
  },
  xYears: {
    one: "un anno",
    other: "{{count}} anni"
  },
  overXYears: {
    one: "più di un anno",
    other: "più di {{count}} anni"
  },
  almostXYears: {
    one: "quasi un anno",
    other: "quasi {{count}} anni"
  }
}, H = {
  date: buildFormatLongFn({
    formats: {
      full: "EEEE d MMMM y",
      long: "d MMMM y",
      medium: "d MMM y",
      short: "dd/MM/y"
    },
    defaultWidth: "full"
  }),
  time: buildFormatLongFn({
    formats: {
      full: "HH:mm:ss zzzz",
      long: "HH:mm:ss z",
      medium: "HH:mm:ss",
      short: "HH:mm"
    },
    defaultWidth: "full"
  }),
  dateTime: buildFormatLongFn({
    formats: {
      full: "{{date}} {{time}}",
      long: "{{date}} {{time}}",
      medium: "{{date}} {{time}}",
      short: "{{date}} {{time}}"
    },
    defaultWidth: "full"
  })
}, I = [ "domenica", "lunedì", "martedì", "mercoledì", "giovedì", "venerdì", "sabato" ];

function thisWeek(e) {
  return "'" + I[e] + " alle' p";
}

var U = {
  lastWeek: function(e, t, a) {
    var n = e.getUTCDay();
    return isSameUTCWeek(e, t, a) ? thisWeek(n) : function(e) {
      switch (e) {
       case 0:
        return "'domenica scorsa alle' p";

       default:
        return "'" + I[e] + " scorso alle' p";
      }
    }(n);
  },
  yesterday: "'ieri alle' p",
  today: "'oggi alle' p",
  tomorrow: "'domani alle' p",
  nextWeek: function(e, t, a) {
    var n = e.getUTCDay();
    return isSameUTCWeek(e, t, a) ? thisWeek(n) : function(e) {
      switch (e) {
       case 0:
        return "'domenica prossima alle' p";

       default:
        return "'" + I[e] + " prossimo alle' p";
      }
    }(n);
  },
  other: "P"
}, Y = {
  code: "it",
  formatDistance: function(e, t, a) {
    var n, i = q[e];
    return n = "string" == typeof i ? i : 1 === t ? i.one : i.other.replace("{{count}}", t.toString()), 
    null != a && a.addSuffix ? a.comparison && a.comparison > 0 ? "tra " + n : n + " fa" : n;
  },
  formatLong: H,
  formatRelative: function(e, t, a, n) {
    var i = U[e];
    return "function" == typeof i ? i(t, a, n) : i;
  },
  localize: {
    ordinalNumber: function(e, t) {
      return Number(e) + "º";
    },
    era: buildLocalizeFn({
      values: {
        narrow: [ "aC", "dC" ],
        abbreviated: [ "a.C.", "d.C." ],
        wide: [ "avanti Cristo", "dopo Cristo" ]
      },
      defaultWidth: "wide"
    }),
    quarter: buildLocalizeFn({
      values: {
        narrow: [ "1", "2", "3", "4" ],
        abbreviated: [ "T1", "T2", "T3", "T4" ],
        wide: [ "1º trimestre", "2º trimestre", "3º trimestre", "4º trimestre" ]
      },
      defaultWidth: "wide",
      argumentCallback: function(e) {
        return e - 1;
      }
    }),
    month: buildLocalizeFn({
      values: {
        narrow: [ "G", "F", "M", "A", "M", "G", "L", "A", "S", "O", "N", "D" ],
        abbreviated: [ "gen", "feb", "mar", "apr", "mag", "giu", "lug", "ago", "set", "ott", "nov", "dic" ],
        wide: [ "gennaio", "febbraio", "marzo", "aprile", "maggio", "giugno", "luglio", "agosto", "settembre", "ottobre", "novembre", "dicembre" ]
      },
      defaultWidth: "wide"
    }),
    day: buildLocalizeFn({
      values: {
        narrow: [ "D", "L", "M", "M", "G", "V", "S" ],
        short: [ "dom", "lun", "mar", "mer", "gio", "ven", "sab" ],
        abbreviated: [ "dom", "lun", "mar", "mer", "gio", "ven", "sab" ],
        wide: [ "domenica", "lunedì", "martedì", "mercoledì", "giovedì", "venerdì", "sabato" ]
      },
      defaultWidth: "wide"
    }),
    dayPeriod: buildLocalizeFn({
      values: {
        narrow: {
          am: "m.",
          pm: "p.",
          midnight: "mezzanotte",
          noon: "mezzogiorno",
          morning: "mattina",
          afternoon: "pomeriggio",
          evening: "sera",
          night: "notte"
        },
        abbreviated: {
          am: "AM",
          pm: "PM",
          midnight: "mezzanotte",
          noon: "mezzogiorno",
          morning: "mattina",
          afternoon: "pomeriggio",
          evening: "sera",
          night: "notte"
        },
        wide: {
          am: "AM",
          pm: "PM",
          midnight: "mezzanotte",
          noon: "mezzogiorno",
          morning: "mattina",
          afternoon: "pomeriggio",
          evening: "sera",
          night: "notte"
        }
      },
      defaultWidth: "wide",
      formattingValues: {
        narrow: {
          am: "m.",
          pm: "p.",
          midnight: "mezzanotte",
          noon: "mezzogiorno",
          morning: "di mattina",
          afternoon: "del pomeriggio",
          evening: "di sera",
          night: "di notte"
        },
        abbreviated: {
          am: "AM",
          pm: "PM",
          midnight: "mezzanotte",
          noon: "mezzogiorno",
          morning: "di mattina",
          afternoon: "del pomeriggio",
          evening: "di sera",
          night: "di notte"
        },
        wide: {
          am: "AM",
          pm: "PM",
          midnight: "mezzanotte",
          noon: "mezzogiorno",
          morning: "di mattina",
          afternoon: "del pomeriggio",
          evening: "di sera",
          night: "di notte"
        }
      },
      defaultFormattingWidth: "wide"
    })
  },
  match: {
    ordinalNumber: buildMatchPatternFn({
      matchPattern: /^(\d+)(º)?/i,
      parsePattern: /\d+/i,
      valueCallback: function(e) {
        return parseInt(e, 10);
      }
    }),
    era: buildMatchFn({
      matchPatterns: {
        narrow: /^(aC|dC)/i,
        abbreviated: /^(a\.?\s?C\.?|a\.?\s?e\.?\s?v\.?|d\.?\s?C\.?|e\.?\s?v\.?)/i,
        wide: /^(avanti Cristo|avanti Era Volgare|dopo Cristo|Era Volgare)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        any: [ /^a/i, /^(d|e)/i ]
      },
      defaultParseWidth: "any"
    }),
    quarter: buildMatchFn({
      matchPatterns: {
        narrow: /^[1234]/i,
        abbreviated: /^t[1234]/i,
        wide: /^[1234](º)? trimestre/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        any: [ /1/i, /2/i, /3/i, /4/i ]
      },
      defaultParseWidth: "any",
      valueCallback: function(e) {
        return e + 1;
      }
    }),
    month: buildMatchFn({
      matchPatterns: {
        narrow: /^[gfmalsond]/i,
        abbreviated: /^(gen|feb|mar|apr|mag|giu|lug|ago|set|ott|nov|dic)/i,
        wide: /^(gennaio|febbraio|marzo|aprile|maggio|giugno|luglio|agosto|settembre|ottobre|novembre|dicembre)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        narrow: [ /^g/i, /^f/i, /^m/i, /^a/i, /^m/i, /^g/i, /^l/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i ],
        any: [ /^ge/i, /^f/i, /^mar/i, /^ap/i, /^mag/i, /^gi/i, /^l/i, /^ag/i, /^s/i, /^o/i, /^n/i, /^d/i ]
      },
      defaultParseWidth: "any"
    }),
    day: buildMatchFn({
      matchPatterns: {
        narrow: /^[dlmgvs]/i,
        short: /^(do|lu|ma|me|gi|ve|sa)/i,
        abbreviated: /^(dom|lun|mar|mer|gio|ven|sab)/i,
        wide: /^(domenica|luned[i|ì]|marted[i|ì]|mercoled[i|ì]|gioved[i|ì]|venerd[i|ì]|sabato)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        narrow: [ /^d/i, /^l/i, /^m/i, /^m/i, /^g/i, /^v/i, /^s/i ],
        any: [ /^d/i, /^l/i, /^ma/i, /^me/i, /^g/i, /^v/i, /^s/i ]
      },
      defaultParseWidth: "any"
    }),
    dayPeriod: buildMatchFn({
      matchPatterns: {
        narrow: /^(a|m\.|p|mezzanotte|mezzogiorno|(di|del) (mattina|pomeriggio|sera|notte))/i,
        any: /^([ap]\.?\s?m\.?|mezzanotte|mezzogiorno|(di|del) (mattina|pomeriggio|sera|notte))/i
      },
      defaultMatchWidth: "any",
      parsePatterns: {
        any: {
          am: /^a/i,
          pm: /^p/i,
          midnight: /^mezza/i,
          noon: /^mezzo/i,
          morning: /mattina/i,
          afternoon: /pomeriggio/i,
          evening: /sera/i,
          night: /notte/i
        }
      },
      defaultParseWidth: "any"
    })
  },
  options: {
    weekStartsOn: 1
    /* Monday */ ,
    firstWeekContainsDate: 4
  }
};

function declension(e, t, a) {
  a = a || "regular";
  var n = function(e, t) {
    if (1 === t) return e.one;
    var a = t % 100;
 // ends with 11-20
        if (a <= 20 && a > 10) return e.other;
    var n = a % 10;
 // ends with 2, 3, 4
        return n >= 2 && n <= 4 ? e.twoFour : e.other;
  }(e, t);
  return (n[a] || n).replace("{{count}}", t);
}

var N = {
  lessThanXSeconds: {
    one: {
      regular: "mniej niż sekunda",
      past: "mniej niż sekundę",
      future: "mniej niż sekundę"
    },
    twoFour: "mniej niż {{count}} sekundy",
    other: "mniej niż {{count}} sekund"
  },
  xSeconds: {
    one: {
      regular: "sekunda",
      past: "sekundę",
      future: "sekundę"
    },
    twoFour: "{{count}} sekundy",
    other: "{{count}} sekund"
  },
  halfAMinute: {
    one: "pół minuty",
    twoFour: "pół minuty",
    other: "pół minuty"
  },
  lessThanXMinutes: {
    one: {
      regular: "mniej niż minuta",
      past: "mniej niż minutę",
      future: "mniej niż minutę"
    },
    twoFour: "mniej niż {{count}} minuty",
    other: "mniej niż {{count}} minut"
  },
  xMinutes: {
    one: {
      regular: "minuta",
      past: "minutę",
      future: "minutę"
    },
    twoFour: "{{count}} minuty",
    other: "{{count}} minut"
  },
  aboutXHours: {
    one: {
      regular: "około godziny",
      past: "około godziny",
      future: "około godzinę"
    },
    twoFour: "około {{count}} godziny",
    other: "około {{count}} godzin"
  },
  xHours: {
    one: {
      regular: "godzina",
      past: "godzinę",
      future: "godzinę"
    },
    twoFour: "{{count}} godziny",
    other: "{{count}} godzin"
  },
  xDays: {
    one: {
      regular: "dzień",
      past: "dzień",
      future: "1 dzień"
    },
    twoFour: "{{count}} dni",
    other: "{{count}} dni"
  },
  aboutXWeeks: {
    one: "około tygodnia",
    twoFour: "około {{count}} tygodni",
    other: "około {{count}} tygodni"
  },
  xWeeks: {
    one: "tydzień",
    twoFour: "{{count}} tygodnie",
    other: "{{count}} tygodni"
  },
  aboutXMonths: {
    one: "około miesiąc",
    twoFour: "około {{count}} miesiące",
    other: "około {{count}} miesięcy"
  },
  xMonths: {
    one: "miesiąc",
    twoFour: "{{count}} miesiące",
    other: "{{count}} miesięcy"
  },
  aboutXYears: {
    one: "około rok",
    twoFour: "około {{count}} lata",
    other: "około {{count}} lat"
  },
  xYears: {
    one: "rok",
    twoFour: "{{count}} lata",
    other: "{{count}} lat"
  },
  overXYears: {
    one: "ponad rok",
    twoFour: "ponad {{count}} lata",
    other: "ponad {{count}} lat"
  },
  almostXYears: {
    one: "prawie rok",
    twoFour: "prawie {{count}} lata",
    other: "prawie {{count}} lat"
  }
};

var X = {
  date: buildFormatLongFn({
    formats: {
      full: "EEEE, do MMMM y",
      long: "do MMMM y",
      medium: "do MMM y",
      short: "dd.MM.y"
    },
    defaultWidth: "full"
  }),
  time: buildFormatLongFn({
    formats: {
      full: "HH:mm:ss zzzz",
      long: "HH:mm:ss z",
      medium: "HH:mm:ss",
      short: "HH:mm"
    },
    defaultWidth: "full"
  }),
  dateTime: buildFormatLongFn({
    formats: {
      full: "{{date}} {{time}}",
      long: "{{date}} {{time}}",
      medium: "{{date}}, {{time}}",
      short: "{{date}}, {{time}}"
    },
    defaultWidth: "full"
  })
}, J = {
  masculine: "ostatni",
  feminine: "ostatnia"
}, Z = {
  masculine: "ten",
  feminine: "ta"
}, R = {
  masculine: "następny",
  feminine: "następna"
}, V = {
  0: "feminine",
  1: "masculine",
  2: "masculine",
  3: "feminine",
  4: "masculine",
  5: "masculine",
  6: "feminine"
};

function getAdjective(e, t, a, n) {
  var i = t.getUTCDay();
  return function(e, t, a, n) {
    if (isSameUTCWeek(t, a, n)) return Z;
    if ("lastWeek" === e) return J;
    if ("nextWeek" === e) return R;
    throw new Error("Cannot determine adjectives for token ".concat(e));
  }(e, t, a, n)[V[i]];
}

function dayAndTimeWithAdjective(e, t, a, n) {
  var i = getAdjective(e, t, a, n);
  return "'".concat(i, "' eeee 'o' p");
}

var Q = {
  lastWeek: dayAndTimeWithAdjective,
  yesterday: "'wczoraj o' p",
  today: "'dzisiaj o' p",
  tomorrow: "'jutro o' p",
  nextWeek: dayAndTimeWithAdjective,
  other: "P"
};

var G = {
  code: "pl",
  formatDistance: function(e, t, a) {
    var n = N[e];
    return (a = a || {}).addSuffix ? a.comparison > 0 ? "za " + declension(n, t, "future") : declension(n, t, "past") + " temu" : declension(n, t);
  },
  formatLong: X,
  formatRelative: function(e, t, a, n) {
    var i = Q[e];
    return "function" == typeof i ? i(e, t, a, n) : i;
  },
  localize: {
    ordinalNumber: function(e) {
      var t = Number(e);
      return String(t);
    },
    era: buildLocalizeFn({
      values: {
        narrow: [ "p.n.e.", "n.e." ],
        abbreviated: [ "p.n.e.", "n.e." ],
        wide: [ "przed naszą erą", "naszej ery" ]
      },
      defaultWidth: "wide"
    }),
    quarter: buildLocalizeFn({
      values: {
        narrow: [ "1", "2", "3", "4" ],
        abbreviated: [ "I kw.", "II kw.", "III kw.", "IV kw." ],
        wide: [ "I kwartał", "II kwartał", "III kwartał", "IV kwartał" ]
      },
      defaultWidth: "wide",
      argumentCallback: function(e) {
        return Number(e) - 1;
      }
    }),
    month: buildLocalizeFn({
      values: {
        narrow: [ "S", "L", "M", "K", "M", "C", "L", "S", "W", "P", "L", "G" ],
        abbreviated: [ "sty", "lut", "mar", "kwi", "maj", "cze", "lip", "sie", "wrz", "paź", "lis", "gru" ],
        wide: [ "styczeń", "luty", "marzec", "kwiecień", "maj", "czerwiec", "lipiec", "sierpień", "wrzesień", "październik", "listopad", "grudzień" ]
      },
      defaultWidth: "wide",
      formattingValues: {
        narrow: [ "s", "l", "m", "k", "m", "c", "l", "s", "w", "p", "l", "g" ],
        abbreviated: [ "sty", "lut", "mar", "kwi", "maj", "cze", "lip", "sie", "wrz", "paź", "lis", "gru" ],
        wide: [ "stycznia", "lutego", "marca", "kwietnia", "maja", "czerwca", "lipca", "sierpnia", "września", "października", "listopada", "grudnia" ]
      },
      defaultFormattingWidth: "wide"
    }),
    day: buildLocalizeFn({
      values: {
        narrow: [ "N", "P", "W", "Ś", "C", "P", "S" ],
        short: [ "nie", "pon", "wto", "śro", "czw", "pią", "sob" ],
        abbreviated: [ "niedz.", "pon.", "wt.", "śr.", "czw.", "pt.", "sob." ],
        wide: [ "niedziela", "poniedziałek", "wtorek", "środa", "czwartek", "piątek", "sobota" ]
      },
      defaultWidth: "wide",
      formattingValues: {
        narrow: [ "n", "p", "w", "ś", "c", "p", "s" ],
        short: [ "nie", "pon", "wto", "śro", "czw", "pią", "sob" ],
        abbreviated: [ "niedz.", "pon.", "wt.", "śr.", "czw.", "pt.", "sob." ],
        wide: [ "niedziela", "poniedziałek", "wtorek", "środa", "czwartek", "piątek", "sobota" ]
      },
      defaultFormattingWidth: "wide"
    }),
    dayPeriod: buildLocalizeFn({
      values: {
        narrow: {
          am: "a",
          pm: "p",
          midnight: "półn.",
          noon: "poł",
          morning: "rano",
          afternoon: "popoł.",
          evening: "wiecz.",
          night: "noc"
        },
        abbreviated: {
          am: "AM",
          pm: "PM",
          midnight: "północ",
          noon: "południe",
          morning: "rano",
          afternoon: "popołudnie",
          evening: "wieczór",
          night: "noc"
        },
        wide: {
          am: "AM",
          pm: "PM",
          midnight: "północ",
          noon: "południe",
          morning: "rano",
          afternoon: "popołudnie",
          evening: "wieczór",
          night: "noc"
        }
      },
      defaultWidth: "wide",
      formattingValues: {
        narrow: {
          am: "a",
          pm: "p",
          midnight: "o półn.",
          noon: "w poł.",
          morning: "rano",
          afternoon: "po poł.",
          evening: "wiecz.",
          night: "w nocy"
        },
        abbreviated: {
          am: "AM",
          pm: "PM",
          midnight: "o północy",
          noon: "w południe",
          morning: "rano",
          afternoon: "po południu",
          evening: "wieczorem",
          night: "w nocy"
        },
        wide: {
          am: "AM",
          pm: "PM",
          midnight: "o północy",
          noon: "w południe",
          morning: "rano",
          afternoon: "po południu",
          evening: "wieczorem",
          night: "w nocy"
        }
      },
      defaultFormattingWidth: "wide"
    })
  },
  match: {
    ordinalNumber: buildMatchPatternFn({
      matchPattern: /^(\d+)?/i,
      parsePattern: /\d+/i,
      valueCallback: function(e) {
        return parseInt(e, 10);
      }
    }),
    era: buildMatchFn({
      matchPatterns: {
        narrow: /^(p\.?\s*n\.?\s*e\.?\s*|n\.?\s*e\.?\s*)/i,
        abbreviated: /^(p\.?\s*n\.?\s*e\.?\s*|n\.?\s*e\.?\s*)/i,
        wide: /^(przed\s*nasz(ą|a)\s*er(ą|a)|naszej\s*ery)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        any: [ /^p/i, /^n/i ]
      },
      defaultParseWidth: "any"
    }),
    quarter: buildMatchFn({
      matchPatterns: {
        narrow: /^[1234]/i,
        abbreviated: /^(I|II|III|IV)\s*kw\.?/i,
        wide: /^(I|II|III|IV)\s*kwarta(ł|l)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        narrow: [ /1/i, /2/i, /3/i, /4/i ],
        any: [ /^I kw/i, /^II kw/i, /^III kw/i, /^IV kw/i ]
      },
      defaultParseWidth: "any",
      valueCallback: function(e) {
        return e + 1;
      }
    }),
    month: buildMatchFn({
      matchPatterns: {
        narrow: /^[slmkcwpg]/i,
        abbreviated: /^(sty|lut|mar|kwi|maj|cze|lip|sie|wrz|pa(ź|z)|lis|gru)/i,
        wide: /^(stycznia|stycze(ń|n)|lutego|luty|marca|marzec|kwietnia|kwiecie(ń|n)|maja|maj|czerwca|czerwiec|lipca|lipiec|sierpnia|sierpie(ń|n)|wrze(ś|s)nia|wrzesie(ń|n)|pa(ź|z)dziernika|pa(ź|z)dziernik|listopada|listopad|grudnia|grudzie(ń|n))/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        narrow: [ /^s/i, /^l/i, /^m/i, /^k/i, /^m/i, /^c/i, /^l/i, /^s/i, /^w/i, /^p/i, /^l/i, /^g/i ],
        any: [ /^st/i, /^lu/i, /^mar/i, /^k/i, /^maj/i, /^c/i, /^lip/i, /^si/i, /^w/i, /^p/i, /^lis/i, /^g/i ]
      },
      defaultParseWidth: "any"
    }),
    day: buildMatchFn({
      matchPatterns: {
        narrow: /^[npwścs]/i,
        short: /^(nie|pon|wto|(ś|s)ro|czw|pi(ą|a)|sob)/i,
        abbreviated: /^(niedz|pon|wt|(ś|s)r|czw|pt|sob)\.?/i,
        wide: /^(niedziela|poniedzia(ł|l)ek|wtorek|(ś|s)roda|czwartek|pi(ą|a)tek|sobota)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        narrow: [ /^n/i, /^p/i, /^w/i, /^ś/i, /^c/i, /^p/i, /^s/i ],
        abbreviated: [ /^n/i, /^po/i, /^w/i, /^(ś|s)r/i, /^c/i, /^pt/i, /^so/i ],
        any: [ /^n/i, /^po/i, /^w/i, /^(ś|s)r/i, /^c/i, /^pi/i, /^so/i ]
      },
      defaultParseWidth: "any"
    }),
    dayPeriod: buildMatchFn({
      matchPatterns: {
        narrow: /^(^a$|^p$|pó(ł|l)n\.?|o\s*pó(ł|l)n\.?|po(ł|l)\.?|w\s*po(ł|l)\.?|po\s*po(ł|l)\.?|rano|wiecz\.?|noc|w\s*nocy)/i,
        any: /^(am|pm|pó(ł|l)noc|o\s*pó(ł|l)nocy|po(ł|l)udnie|w\s*po(ł|l)udnie|popo(ł|l)udnie|po\s*po(ł|l)udniu|rano|wieczór|wieczorem|noc|w\s*nocy)/i
      },
      defaultMatchWidth: "any",
      parsePatterns: {
        narrow: {
          am: /^a$/i,
          pm: /^p$/i,
          midnight: /pó(ł|l)n/i,
          noon: /po(ł|l)/i,
          morning: /rano/i,
          afternoon: /po\s*po(ł|l)/i,
          evening: /wiecz/i,
          night: /noc/i
        },
        any: {
          am: /^am/i,
          pm: /^pm/i,
          midnight: /pó(ł|l)n/i,
          noon: /po(ł|l)/i,
          morning: /rano/i,
          afternoon: /po\s*po(ł|l)/i,
          evening: /wiecz/i,
          night: /noc/i
        }
      },
      defaultParseWidth: "any"
    })
  },
  options: {
    weekStartsOn: 1
    /* Monday */ ,
    firstWeekContainsDate: 4
  }
}, B = {
  lessThanXSeconds: {
    one: "menos de um segundo",
    other: "menos de {{count}} segundos"
  },
  xSeconds: {
    one: "1 segundo",
    other: "{{count}} segundos"
  },
  halfAMinute: "meio minuto",
  lessThanXMinutes: {
    one: "menos de um minuto",
    other: "menos de {{count}} minutos"
  },
  xMinutes: {
    one: "1 minuto",
    other: "{{count}} minutos"
  },
  aboutXHours: {
    one: "aproximadamente 1 hora",
    other: "aproximadamente {{count}} horas"
  },
  xHours: {
    one: "1 hora",
    other: "{{count}} horas"
  },
  xDays: {
    one: "1 dia",
    other: "{{count}} dias"
  },
  aboutXWeeks: {
    one: "aproximadamente 1 semana",
    other: "aproximadamente {{count}} semanas"
  },
  xWeeks: {
    one: "1 semana",
    other: "{{count}} semanas"
  },
  aboutXMonths: {
    one: "aproximadamente 1 mês",
    other: "aproximadamente {{count}} meses"
  },
  xMonths: {
    one: "1 mês",
    other: "{{count}} meses"
  },
  aboutXYears: {
    one: "aproximadamente 1 ano",
    other: "aproximadamente {{count}} anos"
  },
  xYears: {
    one: "1 ano",
    other: "{{count}} anos"
  },
  overXYears: {
    one: "mais de 1 ano",
    other: "mais de {{count}} anos"
  },
  almostXYears: {
    one: "quase 1 ano",
    other: "quase {{count}} anos"
  }
};

var K = {
  date: buildFormatLongFn({
    formats: {
      full: "EEEE, d 'de' MMMM 'de' y",
      long: "d 'de' MMMM 'de' y",
      medium: "d 'de' MMM 'de' y",
      short: "dd/MM/y"
    },
    defaultWidth: "full"
  }),
  time: buildFormatLongFn({
    formats: {
      full: "HH:mm:ss zzzz",
      long: "HH:mm:ss z",
      medium: "HH:mm:ss",
      short: "HH:mm"
    },
    defaultWidth: "full"
  }),
  dateTime: buildFormatLongFn({
    formats: {
      full: "{{date}} 'às' {{time}}",
      long: "{{date}} 'às' {{time}}",
      medium: "{{date}}, {{time}}",
      short: "{{date}}, {{time}}"
    },
    defaultWidth: "full"
  })
}, $ = {
  lastWeek: "'na última' eeee 'às' p",
  yesterday: "'ontem às' p",
  today: "'hoje às' p",
  tomorrow: "'amanhã às' p",
  nextWeek: "eeee 'às' p",
  other: "P"
};

var _ = {
  code: "pt",
  formatDistance: function(e, t, a) {
    var n;
    return a = a || {}, n = "string" == typeof B[e] ? B[e] : 1 === t ? B[e].one : B[e].other.replace("{{count}}", t), 
    a.addSuffix ? a.comparison > 0 ? "daqui a " + n : "há " + n : n;
  },
  formatLong: K,
  formatRelative: function(e, t, a, n) {
    return $[e];
  },
  localize: {
    ordinalNumber: function(e) {
      return Number(e) + "º";
    },
    era: buildLocalizeFn({
      values: {
        narrow: [ "aC", "dC" ],
        abbreviated: [ "a.C.", "d.C." ],
        wide: [ "antes de Cristo", "depois de Cristo" ]
      },
      defaultWidth: "wide"
    }),
    quarter: buildLocalizeFn({
      values: {
        narrow: [ "1", "2", "3", "4" ],
        abbreviated: [ "T1", "T2", "T3", "T4" ],
        wide: [ "1º trimestre", "2º trimestre", "3º trimestre", "4º trimestre" ]
      },
      defaultWidth: "wide",
      argumentCallback: function(e) {
        return Number(e) - 1;
      }
    }),
    month: buildLocalizeFn({
      values: {
        narrow: [ "j", "f", "m", "a", "m", "j", "j", "a", "s", "o", "n", "d" ],
        abbreviated: [ "jan", "fev", "mar", "abr", "mai", "jun", "jul", "ago", "set", "out", "nov", "dez" ],
        wide: [ "janeiro", "fevereiro", "março", "abril", "maio", "junho", "julho", "agosto", "setembro", "outubro", "novembro", "dezembro" ]
      },
      defaultWidth: "wide"
    }),
    day: buildLocalizeFn({
      values: {
        narrow: [ "d", "s", "t", "q", "q", "s", "s" ],
        short: [ "dom", "seg", "ter", "qua", "qui", "sex", "sáb" ],
        abbreviated: [ "dom", "seg", "ter", "qua", "qui", "sex", "sáb" ],
        wide: [ "domingo", "segunda-feira", "terça-feira", "quarta-feira", "quinta-feira", "sexta-feira", "sábado" ]
      },
      defaultWidth: "wide"
    }),
    dayPeriod: buildLocalizeFn({
      values: {
        narrow: {
          am: "AM",
          pm: "PM",
          midnight: "meia-noite",
          noon: "meio-dia",
          morning: "manhã",
          afternoon: "tarde",
          evening: "noite",
          night: "madrugada"
        },
        abbreviated: {
          am: "AM",
          pm: "PM",
          midnight: "meia-noite",
          noon: "meio-dia",
          morning: "manhã",
          afternoon: "tarde",
          evening: "noite",
          night: "madrugada"
        },
        wide: {
          am: "AM",
          pm: "PM",
          midnight: "meia-noite",
          noon: "meio-dia",
          morning: "manhã",
          afternoon: "tarde",
          evening: "noite",
          night: "madrugada"
        }
      },
      defaultWidth: "wide",
      formattingValues: {
        narrow: {
          am: "AM",
          pm: "PM",
          midnight: "meia-noite",
          noon: "meio-dia",
          morning: "da manhã",
          afternoon: "da tarde",
          evening: "da noite",
          night: "da madrugada"
        },
        abbreviated: {
          am: "AM",
          pm: "PM",
          midnight: "meia-noite",
          noon: "meio-dia",
          morning: "da manhã",
          afternoon: "da tarde",
          evening: "da noite",
          night: "da madrugada"
        },
        wide: {
          am: "AM",
          pm: "PM",
          midnight: "meia-noite",
          noon: "meio-dia",
          morning: "da manhã",
          afternoon: "da tarde",
          evening: "da noite",
          night: "da madrugada"
        }
      },
      defaultFormattingWidth: "wide"
    })
  },
  match: {
    ordinalNumber: buildMatchPatternFn({
      matchPattern: /^(\d+)(º|ª)?/i,
      parsePattern: /\d+/i,
      valueCallback: function(e) {
        return parseInt(e, 10);
      }
    }),
    era: buildMatchFn({
      matchPatterns: {
        narrow: /^(ac|dc|a|d)/i,
        abbreviated: /^(a\.?\s?c\.?|a\.?\s?e\.?\s?c\.?|d\.?\s?c\.?|e\.?\s?c\.?)/i,
        wide: /^(antes de cristo|antes da era comum|depois de cristo|era comum)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        any: [ /^ac/i, /^dc/i ],
        wide: [ /^(antes de cristo|antes da era comum)/i, /^(depois de cristo|era comum)/i ]
      },
      defaultParseWidth: "any"
    }),
    quarter: buildMatchFn({
      matchPatterns: {
        narrow: /^[1234]/i,
        abbreviated: /^T[1234]/i,
        wide: /^[1234](º|ª)? trimestre/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        any: [ /1/i, /2/i, /3/i, /4/i ]
      },
      defaultParseWidth: "any",
      valueCallback: function(e) {
        return e + 1;
      }
    }),
    month: buildMatchFn({
      matchPatterns: {
        narrow: /^[jfmasond]/i,
        abbreviated: /^(jan|fev|mar|abr|mai|jun|jul|ago|set|out|nov|dez)/i,
        wide: /^(janeiro|fevereiro|março|abril|maio|junho|julho|agosto|setembro|outubro|novembro|dezembro)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        narrow: [ /^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i ],
        any: [ /^ja/i, /^f/i, /^mar/i, /^ab/i, /^mai/i, /^jun/i, /^jul/i, /^ag/i, /^s/i, /^o/i, /^n/i, /^d/i ]
      },
      defaultParseWidth: "any"
    }),
    day: buildMatchFn({
      matchPatterns: {
        narrow: /^[dstq]/i,
        short: /^(dom|seg|ter|qua|qui|sex|s[áa]b)/i,
        abbreviated: /^(dom|seg|ter|qua|qui|sex|s[áa]b)/i,
        wide: /^(domingo|segunda-?\s?feira|terça-?\s?feira|quarta-?\s?feira|quinta-?\s?feira|sexta-?\s?feira|s[áa]bado)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        narrow: [ /^d/i, /^s/i, /^t/i, /^q/i, /^q/i, /^s/i, /^s/i ],
        any: [ /^d/i, /^seg/i, /^t/i, /^qua/i, /^qui/i, /^sex/i, /^s[áa]/i ]
      },
      defaultParseWidth: "any"
    }),
    dayPeriod: buildMatchFn({
      matchPatterns: {
        narrow: /^(a|p|meia-?\s?noite|meio-?\s?dia|(da) (manh[ãa]|tarde|noite|madrugada))/i,
        any: /^([ap]\.?\s?m\.?|meia-?\s?noite|meio-?\s?dia|(da) (manh[ãa]|tarde|noite|madrugada))/i
      },
      defaultMatchWidth: "any",
      parsePatterns: {
        any: {
          am: /^a/i,
          pm: /^p/i,
          midnight: /^meia/i,
          noon: /^meio/i,
          morning: /manh[ãa]/i,
          afternoon: /tarde/i,
          evening: /noite/i,
          night: /madrugada/i
        }
      },
      defaultParseWidth: "any"
    })
  },
  options: {
    weekStartsOn: 1
    /* Monday */ ,
    firstWeekContainsDate: 4
  }
}, ee = {
  lessThanXSeconds: {
    one: "bir saniyeden az",
    other: "{{count}} saniyeden az"
  },
  xSeconds: {
    one: "1 saniye",
    other: "{{count}} saniye"
  },
  halfAMinute: "yarım dakika",
  lessThanXMinutes: {
    one: "bir dakikadan az",
    other: "{{count}} dakikadan az"
  },
  xMinutes: {
    one: "1 dakika",
    other: "{{count}} dakika"
  },
  aboutXHours: {
    one: "yaklaşık 1 saat",
    other: "yaklaşık {{count}} saat"
  },
  xHours: {
    one: "1 saat",
    other: "{{count}} saat"
  },
  xDays: {
    one: "1 gün",
    other: "{{count}} gün"
  },
  aboutXWeeks: {
    one: "yaklaşık 1 hafta",
    other: "yaklaşık {{count}} hafta"
  },
  xWeeks: {
    one: "1 hafta",
    other: "{{count}} hafta"
  },
  aboutXMonths: {
    one: "yaklaşık 1 ay",
    other: "yaklaşık {{count}} ay"
  },
  xMonths: {
    one: "1 ay",
    other: "{{count}} ay"
  },
  aboutXYears: {
    one: "yaklaşık 1 yıl",
    other: "yaklaşık {{count}} yıl"
  },
  xYears: {
    one: "1 yıl",
    other: "{{count}} yıl"
  },
  overXYears: {
    one: "1 yıldan fazla",
    other: "{{count}} yıldan fazla"
  },
  almostXYears: {
    one: "neredeyse 1 yıl",
    other: "neredeyse {{count}} yıl"
  }
}, te = {
  date: buildFormatLongFn({
    formats: {
      full: "d MMMM y EEEE",
      long: "d MMMM y",
      medium: "d MMM y",
      short: "dd.MM.yyyy"
    },
    defaultWidth: "full"
  }),
  time: buildFormatLongFn({
    formats: {
      full: "HH:mm:ss zzzz",
      long: "HH:mm:ss z",
      medium: "HH:mm:ss",
      short: "HH:mm"
    },
    defaultWidth: "full"
  }),
  dateTime: buildFormatLongFn({
    formats: {
      full: "{{date}} 'saat' {{time}}",
      long: "{{date}} 'saat' {{time}}",
      medium: "{{date}}, {{time}}",
      short: "{{date}}, {{time}}"
    },
    defaultWidth: "full"
  })
}, ae = {
  lastWeek: "'geçen hafta' eeee 'saat' p",
  yesterday: "'dün saat' p",
  today: "'bugün saat' p",
  tomorrow: "'yarın saat' p",
  nextWeek: "eeee 'saat' p",
  other: "P"
}, ne = {
  code: "tr",
  formatDistance: function(e, t, a) {
    var n, i = ee[e];
    return n = "string" == typeof i ? i : 1 === t ? i.one : i.other.replace("{{count}}", t.toString()), 
    null != a && a.addSuffix ? a.comparison && a.comparison > 0 ? n + " sonra" : n + " önce" : n;
  },
  formatLong: te,
  formatRelative: function(e, t, a, n) {
    return ae[e];
  },
  localize: {
    ordinalNumber: function(e, t) {
      return Number(e) + ".";
    },
    era: buildLocalizeFn({
      values: {
        narrow: [ "MÖ", "MS" ],
        abbreviated: [ "MÖ", "MS" ],
        wide: [ "Milattan Önce", "Milattan Sonra" ]
      },
      defaultWidth: "wide"
    }),
    quarter: buildLocalizeFn({
      values: {
        narrow: [ "1", "2", "3", "4" ],
        abbreviated: [ "1Ç", "2Ç", "3Ç", "4Ç" ],
        wide: [ "İlk çeyrek", "İkinci Çeyrek", "Üçüncü çeyrek", "Son çeyrek" ]
      },
      defaultWidth: "wide",
      argumentCallback: function(e) {
        return Number(e) - 1;
      }
    }),
    month: buildLocalizeFn({
      values: {
        narrow: [ "O", "Ş", "M", "N", "M", "H", "T", "A", "E", "E", "K", "A" ],
        abbreviated: [ "Oca", "Şub", "Mar", "Nis", "May", "Haz", "Tem", "Ağu", "Eyl", "Eki", "Kas", "Ara" ],
        wide: [ "Ocak", "Şubat", "Mart", "Nisan", "Mayıs", "Haziran", "Temmuz", "Ağustos", "Eylül", "Ekim", "Kasım", "Aralık" ]
      },
      defaultWidth: "wide"
    }),
    day: buildLocalizeFn({
      values: {
        narrow: [ "P", "P", "S", "Ç", "P", "C", "C" ],
        short: [ "Pz", "Pt", "Sa", "Ça", "Pe", "Cu", "Ct" ],
        abbreviated: [ "Paz", "Pzt", "Sal", "Çar", "Per", "Cum", "Cts" ],
        wide: [ "Pazar", "Pazartesi", "Salı", "Çarşamba", "Perşembe", "Cuma", "Cumartesi" ]
      },
      defaultWidth: "wide"
    }),
    dayPeriod: buildLocalizeFn({
      values: {
        narrow: {
          am: "öö",
          pm: "ös",
          midnight: "gy",
          noon: "ö",
          morning: "sa",
          afternoon: "ös",
          evening: "ak",
          night: "ge"
        },
        abbreviated: {
          am: "ÖÖ",
          pm: "ÖS",
          midnight: "gece yarısı",
          noon: "öğle",
          morning: "sabah",
          afternoon: "öğleden sonra",
          evening: "akşam",
          night: "gece"
        },
        wide: {
          am: "Ö.Ö.",
          pm: "Ö.S.",
          midnight: "gece yarısı",
          noon: "öğle",
          morning: "sabah",
          afternoon: "öğleden sonra",
          evening: "akşam",
          night: "gece"
        }
      },
      defaultWidth: "wide",
      formattingValues: {
        narrow: {
          am: "öö",
          pm: "ös",
          midnight: "gy",
          noon: "ö",
          morning: "sa",
          afternoon: "ös",
          evening: "ak",
          night: "ge"
        },
        abbreviated: {
          am: "ÖÖ",
          pm: "ÖS",
          midnight: "gece yarısı",
          noon: "öğlen",
          morning: "sabahleyin",
          afternoon: "öğleden sonra",
          evening: "akşamleyin",
          night: "geceleyin"
        },
        wide: {
          am: "ö.ö.",
          pm: "ö.s.",
          midnight: "gece yarısı",
          noon: "öğlen",
          morning: "sabahleyin",
          afternoon: "öğleden sonra",
          evening: "akşamleyin",
          night: "geceleyin"
        }
      },
      defaultFormattingWidth: "wide"
    })
  },
  match: {
    ordinalNumber: buildMatchPatternFn({
      matchPattern: /^(\d+)(\.)?/i,
      parsePattern: /\d+/i,
      valueCallback: function(e) {
        return parseInt(e, 10);
      }
    }),
    era: buildMatchFn({
      matchPatterns: {
        narrow: /^(mö|ms)/i,
        abbreviated: /^(mö|ms)/i,
        wide: /^(milattan önce|milattan sonra)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        any: [ /(^mö|^milattan önce)/i, /(^ms|^milattan sonra)/i ]
      },
      defaultParseWidth: "any"
    }),
    quarter: buildMatchFn({
      matchPatterns: {
        narrow: /^[1234]/i,
        abbreviated: /^[1234]ç/i,
        wide: /^((i|İ)lk|(i|İ)kinci|üçüncü|son) çeyrek/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        any: [ /1/i, /2/i, /3/i, /4/i ],
        abbreviated: [ /1ç/i, /2ç/i, /3ç/i, /4ç/i ],
        wide: [ /^(i|İ)lk çeyrek/i, /(i|İ)kinci çeyrek/i, /üçüncü çeyrek/i, /son çeyrek/i ]
      },
      defaultParseWidth: "any",
      valueCallback: function(e) {
        return e + 1;
      }
    }),
    month: buildMatchFn({
      matchPatterns: {
        narrow: /^[oşmnhtaek]/i,
        abbreviated: /^(oca|şub|mar|nis|may|haz|tem|ağu|eyl|eki|kas|ara)/i,
        wide: /^(ocak|şubat|mart|nisan|mayıs|haziran|temmuz|ağustos|eylül|ekim|kasım|aralık)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        narrow: [ /^o/i, /^ş/i, /^m/i, /^n/i, /^m/i, /^h/i, /^t/i, /^a/i, /^e/i, /^e/i, /^k/i, /^a/i ],
        any: [ /^o/i, /^ş/i, /^mar/i, /^n/i, /^may/i, /^h/i, /^t/i, /^ağ/i, /^ey/i, /^ek/i, /^k/i, /^ar/i ]
      },
      defaultParseWidth: "any"
    }),
    day: buildMatchFn({
      matchPatterns: {
        narrow: /^[psçc]/i,
        short: /^(pz|pt|sa|ça|pe|cu|ct)/i,
        abbreviated: /^(paz|pzt|sal|çar|per|cum|cts)/i,
        wide: /^(pazar|pazartesi|salı|çarşamba|perşembe|cuma|cumartesi)/i
      },
      defaultMatchWidth: "wide",
      parsePatterns: {
        narrow: [ /^p/i, /^p/i, /^s/i, /^ç/i, /^p/i, /^c/i, /^c/i ],
        any: [ /^pz/i, /^pt/i, /^sa/i, /^ça/i, /^pe/i, /^cu/i, /^ct/i ],
        wide: [ /^pazar/i, /^pazartesi/i, /^salı/i, /^çarşamba/i, /^perşembe/i, /^cuma/i, /cumartesi/i ]
      },
      defaultParseWidth: "any"
    }),
    dayPeriod: buildMatchFn({
      matchPatterns: {
        narrow: /^(öö|ös|gy|ö|sa|ös|ak|ge)/i,
        any: /^(ö\.?\s?[ös]\.?|öğleden sonra|gece yarısı|öğle|(sabah|öğ|akşam|gece)(leyin))/i
      },
      defaultMatchWidth: "any",
      parsePatterns: {
        any: {
          am: /^ö\.?ö\.?/i,
          pm: /^ö\.?s\.?/i,
          midnight: /^(gy|gece yarısı)/i,
          noon: /^öğ/i,
          morning: /^sa/i,
          afternoon: /^öğleden sonra/i,
          evening: /^ak/i,
          night: /^ge/i
        }
      },
      defaultParseWidth: "any"
    })
  },
  options: {
    weekStartsOn: 1
    /* Monday */ ,
    firstWeekContainsDate: 1
  }
}, ie = {
  lessThanXSeconds: {
    one: "不到 1 秒",
    other: "不到 {{count}} 秒"
  },
  xSeconds: {
    one: "1 秒",
    other: "{{count}} 秒"
  },
  halfAMinute: "半分钟",
  lessThanXMinutes: {
    one: "不到 1 分钟",
    other: "不到 {{count}} 分钟"
  },
  xMinutes: {
    one: "1 分钟",
    other: "{{count}} 分钟"
  },
  xHours: {
    one: "1 小时",
    other: "{{count}} 小时"
  },
  aboutXHours: {
    one: "大约 1 小时",
    other: "大约 {{count}} 小时"
  },
  xDays: {
    one: "1 天",
    other: "{{count}} 天"
  },
  aboutXWeeks: {
    one: "大约 1 个星期",
    other: "大约 {{count}} 个星期"
  },
  xWeeks: {
    one: "1 个星期",
    other: "{{count}} 个星期"
  },
  aboutXMonths: {
    one: "大约 1 个月",
    other: "大约 {{count}} 个月"
  },
  xMonths: {
    one: "1 个月",
    other: "{{count}} 个月"
  },
  aboutXYears: {
    one: "大约 1 年",
    other: "大约 {{count}} 年"
  },
  xYears: {
    one: "1 年",
    other: "{{count}} 年"
  },
  overXYears: {
    one: "超过 1 年",
    other: "超过 {{count}} 年"
  },
  almostXYears: {
    one: "将近 1 年",
    other: "将近 {{count}} 年"
  }
};

var re = {
  date: buildFormatLongFn({
    formats: {
      full: "y'年'M'月'd'日' EEEE",
      long: "y'年'M'月'd'日'",
      medium: "yyyy-MM-dd",
      short: "yy-MM-dd"
    },
    defaultWidth: "full"
  }),
  time: buildFormatLongFn({
    formats: {
      full: "zzzz a h:mm:ss",
      long: "z a h:mm:ss",
      medium: "a h:mm:ss",
      short: "a h:mm"
    },
    defaultWidth: "full"
  }),
  dateTime: buildFormatLongFn({
    formats: {
      full: "{{date}} {{time}}",
      long: "{{date}} {{time}}",
      medium: "{{date}} {{time}}",
      short: "{{date}} {{time}}"
    },
    defaultWidth: "full"
  })
};

function checkWeek(e, t, a, n) {
  return isSameUTCWeek(e, t, a) ? n : e.getTime() > t.getTime() ? "'下个'" + n : "'上个'" + n;
}

var oe = {
  lastWeek: checkWeek,
  // days before yesterday, maybe in this week or last week
  yesterday: "'昨天' p",
  today: "'今天' p",
  tomorrow: "'明天' p",
  nextWeek: checkWeek,
  // days after tomorrow, maybe in this week or next week
  other: "PP p"
};

var se = {
  ordinalNumber: function(e, t) {
    // If ordinal numbers depend on context, for example,
    // if they are different for different grammatical genders,
    // use `options.unit`:
    //   var options = dirtyOptions || {}
    //   var unit = String(options.unit)
    // where `unit` can be 'year', 'quarter', 'month', 'week', 'date', 'dayOfYear',
    // 'day', 'hour', 'minute', 'second'
    var a = Number(e);
    switch (String((t || {}).unit)) {
     case "date":
      return a.toString() + "日";

     case "hour":
      return a.toString() + "时";

     case "minute":
      return a.toString() + "分";

     case "second":
      return a.toString() + "秒";

     default:
      return "第 " + a.toString();
    }
  },
  era: buildLocalizeFn({
    values: {
      narrow: [ "前", "公元" ],
      abbreviated: [ "前", "公元" ],
      wide: [ "公元前", "公元" ]
    },
    defaultWidth: "wide"
  }),
  quarter: buildLocalizeFn({
    values: {
      narrow: [ "1", "2", "3", "4" ],
      abbreviated: [ "第一季", "第二季", "第三季", "第四季" ],
      wide: [ "第一季度", "第二季度", "第三季度", "第四季度" ]
    },
    defaultWidth: "wide",
    argumentCallback: function(e) {
      return Number(e) - 1;
    }
  }),
  month: buildLocalizeFn({
    values: {
      narrow: [ "一", "二", "三", "四", "五", "六", "七", "八", "九", "十", "十一", "十二" ],
      abbreviated: [ "1月", "2月", "3月", "4月", "5月", "6月", "7月", "8月", "9月", "10月", "11月", "12月" ],
      wide: [ "一月", "二月", "三月", "四月", "五月", "六月", "七月", "八月", "九月", "十月", "十一月", "十二月" ]
    },
    defaultWidth: "wide"
  }),
  day: buildLocalizeFn({
    values: {
      narrow: [ "日", "一", "二", "三", "四", "五", "六" ],
      short: [ "日", "一", "二", "三", "四", "五", "六" ],
      abbreviated: [ "周日", "周一", "周二", "周三", "周四", "周五", "周六" ],
      wide: [ "星期日", "星期一", "星期二", "星期三", "星期四", "星期五", "星期六" ]
    },
    defaultWidth: "wide"
  }),
  dayPeriod: buildLocalizeFn({
    values: {
      narrow: {
        am: "上",
        pm: "下",
        midnight: "凌晨",
        noon: "午",
        morning: "早",
        afternoon: "下午",
        evening: "晚",
        night: "夜"
      },
      abbreviated: {
        am: "上午",
        pm: "下午",
        midnight: "凌晨",
        noon: "中午",
        morning: "早晨",
        afternoon: "中午",
        evening: "晚上",
        night: "夜间"
      },
      wide: {
        am: "上午",
        pm: "下午",
        midnight: "凌晨",
        noon: "中午",
        morning: "早晨",
        afternoon: "中午",
        evening: "晚上",
        night: "夜间"
      }
    },
    defaultWidth: "wide",
    formattingValues: {
      narrow: {
        am: "上",
        pm: "下",
        midnight: "凌晨",
        noon: "午",
        morning: "早",
        afternoon: "下午",
        evening: "晚",
        night: "夜"
      },
      abbreviated: {
        am: "上午",
        pm: "下午",
        midnight: "凌晨",
        noon: "中午",
        morning: "早晨",
        afternoon: "中午",
        evening: "晚上",
        night: "夜间"
      },
      wide: {
        am: "上午",
        pm: "下午",
        midnight: "凌晨",
        noon: "中午",
        morning: "早晨",
        afternoon: "中午",
        evening: "晚上",
        night: "夜间"
      }
    },
    defaultFormattingWidth: "wide"
  })
}, de = {
  ordinalNumber: buildMatchPatternFn({
    matchPattern: /^(第\s*)?\d+(日|时|分|秒)?/i,
    parsePattern: /\d+/i,
    valueCallback: function(e) {
      return parseInt(e, 10);
    }
  }),
  era: buildMatchFn({
    matchPatterns: {
      narrow: /^(前)/i,
      abbreviated: /^(前)/i,
      wide: /^(公元前|公元)/i
    },
    defaultMatchWidth: "wide",
    parsePatterns: {
      any: [ /^(前)/i, /^(公元)/i ]
    },
    defaultParseWidth: "any"
  }),
  quarter: buildMatchFn({
    matchPatterns: {
      narrow: /^[1234]/i,
      abbreviated: /^第[一二三四]刻/i,
      wide: /^第[一二三四]刻钟/i
    },
    defaultMatchWidth: "wide",
    parsePatterns: {
      any: [ /(1|一)/i, /(2|二)/i, /(3|三)/i, /(4|四)/i ]
    },
    defaultParseWidth: "any",
    valueCallback: function(e) {
      return e + 1;
    }
  }),
  month: buildMatchFn({
    matchPatterns: {
      narrow: /^(一|二|三|四|五|六|七|八|九|十[二一])/i,
      abbreviated: /^(一|二|三|四|五|六|七|八|九|十[二一]|\d|1[12])月/i,
      wide: /^(一|二|三|四|五|六|七|八|九|十[二一])月/i
    },
    defaultMatchWidth: "wide",
    parsePatterns: {
      narrow: [ /^一/i, /^二/i, /^三/i, /^四/i, /^五/i, /^六/i, /^七/i, /^八/i, /^九/i, /^十(?!(一|二))/i, /^十一/i, /^十二/i ],
      any: [ /^一|1/i, /^二|2/i, /^三|3/i, /^四|4/i, /^五|5/i, /^六|6/i, /^七|7/i, /^八|8/i, /^九|9/i, /^十(?!(一|二))|10/i, /^十一|11/i, /^十二|12/i ]
    },
    defaultParseWidth: "any"
  }),
  day: buildMatchFn({
    matchPatterns: {
      narrow: /^[一二三四五六日]/i,
      short: /^[一二三四五六日]/i,
      abbreviated: /^周[一二三四五六日]/i,
      wide: /^星期[一二三四五六日]/i
    },
    defaultMatchWidth: "wide",
    parsePatterns: {
      any: [ /日/i, /一/i, /二/i, /三/i, /四/i, /五/i, /六/i ]
    },
    defaultParseWidth: "any"
  }),
  dayPeriod: buildMatchFn({
    matchPatterns: {
      any: /^(上午?|下午?|午夜|[中正]午|早上?|下午|晚上?|凌晨|)/i
    },
    defaultMatchWidth: "any",
    parsePatterns: {
      any: {
        am: /^上午?/i,
        pm: /^下午?/i,
        midnight: /^午夜/i,
        noon: /^[中正]午/i,
        morning: /^早上/i,
        afternoon: /^下午/i,
        evening: /^晚上?/i,
        night: /^凌晨/i
      }
    },
    defaultParseWidth: "any"
  })
};

/*
 * Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.
 */
const ue = {
  language: "en",
  dateFormat: "MM/dd/y",
  timeFormat: "H:mm a"
}, me = {
  de: T,
  en: r,
  fr: O,
  tr: ne,
  it: Y,
  pl: G,
  pt: _,
  es: L,
  zh: {
    code: "zh-CN",
    formatDistance: function(e, t, a) {
      var n;
      return a = a || {}, n = "string" == typeof ie[e] ? ie[e] : 1 === t ? ie[e].one : ie[e].other.replace("{{count}}", t), 
      a.addSuffix ? a.comparison > 0 ? n + "内" : n + "前" : n;
    },
    formatLong: re,
    formatRelative: function(e, t, a, n) {
      var i = oe[e];
      return "function" == typeof i ? i(t, a, n, "eeee p") : i;
    },
    localize: se,
    match: de,
    options: {
      weekStartsOn: 1
      /* Monday */ ,
      firstWeekContainsDate: 4
    }
  }
}, le = {
  showFooter: {
    en: "Expand",
    de: "Ausklappen",
    es: "Ampliar",
    it: "Espandi"
  },
  hideFooter: {
    en: "Collapse",
    de: "Einklappen",
    es: "Colapso",
    it: "Crollo"
  },
  messages: {
    en: "Messages",
    de: "Meldungen",
    es: "Mensajes",
    it: "Messaggi"
  },
  messageFilters: {
    en: "Filter and Sort",
    de: "Filtern und Sortieren",
    es: "Filtrar y clasificar",
    it: "Filtra e Ordina"
  },
  emptyMessageSearchResult: {
    en: "There are no results for the selected filter criteria.",
    de: "Für die gewählten Filterkriterien liegen keine Ergebnisse vor.",
    es: "No hay resultados para los criterios de filtro seleccionados.",
    it: "Non ci sono risultati per il criterio di filtro selezionato."
  },
  emptyMessageSearchFacility: {
    en: "There are no facilities for the given search string.",
    de: "Es gibt keine Einrichtungen zu dieser Suche",
    it: "Non ci sono risultati per questa stringa di ricerca."
  },
  emptyMessageList: {
    en: "There are no messages. Look here for new messages.",
    de: "Es liegen keine Meldungen vor. Neue Meldungen sind hier zu finden.",
    es: "No hay mensajes. Los nuevos mensajes se pueden encontrar aquí.",
    it: "Non ci sono messaggi. Guarda qui per nuovi messaggi."
  },
  seeAllMessages: {
    en: "View all messages",
    de: "Alle Meldungen anzeigen",
    es: "Ver todos los mensajes",
    it: "Visualizza tutti i messaggi"
  },
  today: {
    en: "Today",
    de: "Heute",
    es: "Hoy",
    it: "Oggi"
  },
  yesterday: {
    en: "Yesterday",
    de: "Gestern",
    es: "Ayer",
    it: "Ieri"
  },
  last: {
    en: "Last",
    de: "Letzter",
    es: "Último",
    it: "Ultimo"
  },
  search: {
    en: "Search",
    de: "Suche",
    es: "Buscar",
    it: "Cerca"
  },
  searchOrSelect: {
    en: "Search or select",
    de: "Suche or wähle aus",
    es: "Buscar u seleccionar",
    it: "Cerca o seleziona"
  },
  searchType: {
    en: "Search type",
    de: "Suchtyp",
    es: "Tipo de búsqueda",
    it: "Tipo di ricerca"
  },
  allTypes: {
    en: "All message types",
    de: "Alle Meldungstypen",
    es: "Todos los tipos de mensajes",
    it: "Tutti i tipi di messaggi"
  },
  information: {
    en: "Information",
    de: "Information",
    es: "Información",
    it: "Informazioni"
  },
  success: {
    en: "Completed",
    de: "Abgeschlossen",
    es: "Completado",
    it: "Completato"
  },
  warning: {
    en: "Warning",
    de: "Warnung",
    es: "Advertencia",
    it: "Avviso"
  },
  error: {
    en: "Error",
    de: "Fehler",
    es: "Error",
    it: "Errore"
  },
  descending: {
    en: "Descending",
    de: "Absteigend",
    es: "Descendiendo",
    it: "Discendente"
  },
  ascending: {
    en: "Ascending",
    de: "Aufsteigend",
    es: "Ascendiendo",
    it: "Ascendente"
  },
  messageTypes: {
    en: "Message types",
    de: "Meldungstypen",
    es: "Tipos de mensajes",
    it: "Tipi di messaggi"
  },
  showMoreDetails: {
    en: "Show more",
    de: "Mehr Details",
    es: "Más detalles",
    it: "Mostra di più"
  },
  discardAll: {
    en: "Delete all",
    de: "Alle löschen",
    es: "Borrar todo",
    it: "Elimina tutti"
  },
  entities: {
    en: "Entries",
    de: "Einträge",
    es: "Entradas",
    it: "Elementi"
  },
  title: {
    en: "Title",
    de: "Titel",
    es: "Título",
    it: "Titolo"
  },
  description: {
    en: "Description",
    de: "Beschreibung",
    es: "Descripción",
    it: "Descrizione"
  },
  dateTime: {
    en: "Date/time",
    de: "Datum/Zeit",
    es: "Fecha/Hora",
    it: "Data/Ora"
  },
  messageClass: {
    en: "Category",
    de: "Kategorie",
    es: "Categoría",
    it: "Categoria"
  },
  goTo: {
    en: "Go to",
    de: "Gehe zu",
    es: "Ir a",
    it: "Vai a"
  },
  close: {
    en: "Close",
    de: "Schließen",
    es: "Cerrar",
    it: "Chiudi"
  },
  documentation: {
    en: "Documentation",
    de: "Dokumentation",
    es: "Documentación",
    it: "Documenti"
  },
  didYouMean: {
    en: "Suggestions",
    de: "Vorschläge",
    es: "Propuestas",
    it: "Indicazioni"
  },
  mostRelevant: {
    en: "Matching results",
    de: "Passende Ergebnisse",
    es: "Resultados coincidentes",
    it: "Risultati"
  },
  dismiss: {
    en: "Discard",
    de: "Verwerfen",
    es: "Descartar",
    it: "Elimina"
  },
  setDate: {
    en: "Set date",
    de: "Datum festlegen",
    es: "Fijar fecha",
    it: "Imposta data"
  },
  setTime: {
    en: "Set time",
    de: "Zeit festlegen",
    es: "Fijar hora",
    it: "Imposta tempo"
  },
  range: {
    en: "Time span",
    de: "Zeitraum",
    es: "Período",
    it: "Periodo"
  },
  setDateTime: {
    en: "Set date & time",
    de: "Datum & Uhrzeit festlegen",
    es: "Fijar la fecha y la hora",
    it: "Imposta data e ora"
  },
  setRange: {
    en: "Set time span",
    de: "Zeitraum festlegen",
    es: "Establece el período",
    it: "Imposta periodo"
  },
  save: {
    en: "Save",
    de: "Speichern",
    es: "Guardar",
    it: "Salva"
  },
  templates: {
    en: "Templates",
    de: "Vorlagen",
    es: "Plantillas",
    it: "Tempi"
  },
  calendar: {
    en: "Calendar",
    de: "Kalendar",
    es: "Calendario",
    it: "Calendario"
  },
  time: {
    en: "Time",
    de: "Uhrzeit",
    es: "aeg",
    it: "Ora"
  },
  startTime: {
    en: "Start Time",
    de: "Startzeit",
    es: "Start Time",
    it: "Ora di inizio"
  },
  endTime: {
    en: "End Time",
    de: "Endzeit",
    es: "End Time",
    it: "Ora di fine"
  },
  listItemsPerPage: {
    en: "Elements per page",
    de: "Elemente pro Seite",
    es: "Elementos por página",
    it: "Elementi per pagina"
  },
  recentSearch: {
    en: "Recent searches",
    de: "Letzte Suchanfragen",
    es: "Búsquedas recientes",
    it: "Ricerche recenti"
  },
  back: {
    en: "Back",
    de: "Zurück",
    es: "Atrás",
    it: "Indietro"
  },
  "reset-selection": {
    en: "Reset selection",
    de: "Zurücksetzen",
    es: "Resetear",
    it: "Resetta selezione"
  },
  reset: {
    en: "Reset",
    de: "Zurücksetzen",
    es: "Resetear",
    it: "Resetta"
  },
  faclities: {
    en: "Facilities",
    de: "Einrichtungen",
    es: "Equipos",
    it: "Impianti"
  },
  selectSomething: {
    en: "Select {{search-type-label}}",
    de: "{{search-type-label}} auswählen",
    es: "Seleccione {search-type-label}}",
    it: "Seleziona {{ricerca-tipo-label}}"
  },
  noFilterResults: {
    en: "No items to display.",
    de: "Keine Elemente zum Anzeigen.",
    es: "No hay artículos para mostrar.",
    it: "Nessun elemento da visualizzare."
  }
}, {state: ce, onChange: he} = ((a, n) => {
  const i = ((e, t = ((e, t) => e !== t)) => {
    let a = new Map(Object.entries(null != e ? e : {}));
    const n = {
      dispose: [],
      get: [],
      set: [],
      reset: []
    }, reset = () => {
      a = new Map(Object.entries(null != e ? e : {})), n.reset.forEach((e => e()));
    }, get = e => (n.get.forEach((t => t(e))), a.get(e)), set = (e, i) => {
      const r = a.get(e);
      t(i, r, e) && (a.set(e, i), n.set.forEach((t => t(e, i, r))));
    }, i = "undefined" == typeof Proxy ? {} : new Proxy(e, {
      get: (e, t) => get(t),
      ownKeys: e => Array.from(a.keys()),
      getOwnPropertyDescriptor: () => ({
        enumerable: !0,
        configurable: !0
      }),
      has: (e, t) => a.has(t),
      set: (e, t, a) => (set(t, a), !0)
    }), on = (e, t) => (n[e].push(t), () => {
      removeFromArray(n[e], t);
    });
    return {
      state: i,
      get,
      set,
      on,
      onChange: (t, a) => {
        const n = on("set", ((e, n) => {
          e === t && a(n);
        })), i = on("reset", (() => a(e[t])));
        return () => {
          n(), i();
        };
      },
      use: (...e) => {
        const t = e.reduce(((e, t) => (t.set && e.push(on("set", t.set)), t.get && e.push(on("get", t.get)), 
        t.reset && e.push(on("reset", t.reset)), t.dispose && e.push(on("dispose", t.dispose)), 
        e)), []);
        return () => t.forEach((e => e()));
      },
      dispose: () => {
        // Call first dispose as resetting the state would
        // cause less updates ;)
        n.dispose.forEach((e => e())), reset();
      },
      reset,
      forceUpdate: e => {
        const t = a.get(e);
        n.set.forEach((a => a(e, t, t)));
      }
    };
  })(a, n);
  return i.use((() => {
    if ("function" != typeof e) 
    // If we are not in a stencil project, we do nothing.
    // This function is not really exported by @stencil/core.
    return {};
    const a = new Map;
    return {
      dispose: () => a.clear(),
      get: t => {
        const n = e();
        n && ((e, t, a) => {
          const n = e.get(t);
          n ? n.includes(a) || n.push(a) : e.set(t, [ a ]);
        })(a, t, n);
      },
      set: e => {
        const n = a.get(e);
        n && a.set(e, n.filter(t)), M(a);
      },
      reset: () => {
        a.forEach((e => e.forEach(t))), M(a);
      }
    };
  })()), i;
})({
  language: ue.language,
  dateFormat: ue.dateFormat,
  timeFormat: ue.timeFormat,
  translations: {},
  languageListenerActive: !1,
  isStateSet: !1
});

// Needed when text is not directly translated in the dom
function listenToLanguageChange(e) {
  he("language", (() => e()));
}

async function setLocale() {
  if (!ce.isStateSet) return function() {
    if (ce.languageListenerActive) return;
    new MutationObserver((e => {
      // If the language attribute has changed
      e.filter((e => "lang" === e.attributeName)).length > 0 && (ce.language = document.documentElement.getAttribute("lang"));
    })).observe(document.documentElement, {
      attributes: !0
    }), ce.languageListenerActive = !0;
  }(), Promise.all([ getLanguage(), getDateFormat(), getTimeFormat() ]).then((async ([e, t, a]) => {
    ce.isStateSet = !0, ce.language = e, ce.dateFormat = t, ce.timeFormat = a;
  }));
}

/**
 * Gets user language from the document lang attribute
 * Or from the portal user settings global object
 */ async function getLanguage() {
  let e = document.documentElement.getAttribute("lang");
  if (!e || "undefined" === e) try {
    e = await getPortalContext().getSCSUserSetting("bci.system.language");
  } catch (t) {
    e = ue.language;
  }
  return e;
}

/**
 * Gets dateformat string from global user settings object
 * Or takes default
 */ async function getDateFormat() {
  try {
    return await getPortalContext().getSCSUserSetting("bci.system.dateformat");
  } catch (e) {
    return ue.dateFormat;
  }
}

/**
 * Gets timeformat string from global user settings object
 * Or takes default
 */ async function getTimeFormat() {
  try {
    return await getPortalContext().getSCSUserSetting("bci.system.timeformat");
  } catch (e) {
    return ue.timeFormat;
  }
}

function getPortalContext() {
  return window.BCIPortal;
}

/*
 * Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.
 */
/**
 * Translate the given key to the desired language based on the localization dictionary provided
 * under BCIPortal global object.
 *
 * @param key language key of the related text
 * @param language language code. Default is the user language.
 */ function translate(e) {
  try {
    return le[e] && (le[e][ce.language] || le[e].en) || e;
  } catch (t) {
    return e;
  }
}

/**
 * Format a timestamp according to the user's configured date format
 *
 * @param timestamp
 */ function formatDate(e, t, a) {
  try {
    return format(new Date(e), (t || ce.dateFormat) + " " + (a || ce.timeFormat));
  } catch (t) {
    return format(new Date(e), ue.dateFormat + " " + ue.timeFormat);
  }
}

/**
 * TODO
 *
 * @param timestamp
 */ function formatDateAsDayString(e, t = ue.dateFormat) {
  if (e) try {
    const a = new Date(e);
    return function(e) {
      return requiredArgs(1, arguments), isSameDay(e, Date.now());
    }
    /**
 * @name isYesterday
 * @category Day Helpers
 * @summary Is the given date yesterday?
 * @pure false
 *
 * @description
 * Is the given date yesterday?
 *
 * > ⚠️ Please note that this function is not present in the FP submodule as
 * > it uses `Date.now()` internally hence impure and can't be safely curried.
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * @param {Date|Number} date - the date to check
 * @returns {Boolean} the date is yesterday
 * @throws {TypeError} 1 argument required
 *
 * @example
 * // If today is 6 October 2014, is 5 October 14:00:00 yesterday?
 * var result = isYesterday(new Date(2014, 9, 5, 14, 0))
 * //=> true
 */ (a) ? translate("today") : function(e) {
      return requiredArgs(1, arguments), isSameDay(e, subDays(Date.now(), 1));
    }(a) ? translate("yesterday") : function(e, t) {
      requiredArgs(2, arguments);
      var a = toDate(e), n = toDate(t), i = compareLocalAsc(a, n), r = Math.abs(differenceInCalendarDays(a, n));
      a.setDate(a.getDate() - i * r);
      // Math.abs(diff in full days - diff in calendar days) === 1 if last calendar day is not full
      // If so, result must be decreased by 1 in absolute value
      var o = Number(compareLocalAsc(a, n) === -i), s = i * (r - o);
      // Prevent negative zero
      return 0 === s ? 0 : s;
    }(new Date, a) < 7 ? translate("last") + " " + format(new Date(e), "EEEE", {
      locale: me[ce.language || ue.language]
    }) : format(new Date(e), t || ce.dateFormat);
  } catch (t) {
    return format(new Date(e), ue.dateFormat);
  }
}

/**
 * Gets a new logger instance to log to the browser console.
 */ function getLogger() {
  return {
    info: (e, t) => {
      t ? console.log(`[bci-portal] ${e}`, t) : console.log(`[bci-portal] ${e}`);
    },
    warn: (e, t) => {
      t ? console.warn(`[bci-portal] ${e}`, t) : console.warn(`[bci-portal] ${e}`);
    },
    error: (e, t) => {
      t ? console.error(`[bci-portal] ${e}`, t) : console.error(`[bci-portal] ${e}`);
    }
  };
}

/**
 * creates a date instance with specified parameters
 * @param dateInstance to use as basis
 * @param year year to set
 * @param month month so set
 * @param day day in month to set
 */ function createDate(e, t, a, n = null) {
  return e = setMonth(e = 
  /**
 * @name setYear
 * @category Year Helpers
 * @summary Set the year to the given date.
 *
 * @description
 * Set the year to the given date.
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * @param {Date|Number} date - the date to be changed
 * @param {Number} year - the year of the new date
 * @returns {Date} the new date with the year set
 * @throws {TypeError} 2 arguments required
 *
 * @example
 * // Set year 2013 to 1 September 2014:
 * const result = setYear(new Date(2014, 8, 1), 2013)
 * //=> Sun Sep 01 2013 00:00:00
 */
  function(e, t) {
    requiredArgs(2, arguments);
    var a = toDate(e), n = toInteger(t);
    // Check if date is Invalid Date because Date.prototype.setFullYear ignores the value of Invalid Date
    return isNaN(a.getTime()) ? new Date(NaN) : (a.setFullYear(n), a);
  }(e, t), a), null !== n && (e = function(e, t) {
    requiredArgs(2, arguments);
    var a = toDate(e), n = toInteger(t);
    return a.setDate(n), a;
  }(e, n)), e;
}

/**
 * flattens an array
 * @param array
 */ function flattenArray(e) {
  return [].concat.apply([], e);
}

/**
 * Returns whether app is in responsive mode
 */ function isResponsiveMode() {
  return window.innerWidth < 768;
}

//this method checks if timeformat is with Meridiem(AM/PM) value
function timeFormatHasMeridiem(e) {
  // space is required as timeformats with AM/PM always have a space between the time and the meridiem
  return e.includes(" a");
}

//this method checks if timeformat has seconds
function isHideSeconds(e) {
  return e.includes(":ss");
}

function tap(e) {
  return function(t) {
    return e(t), t;
  };
}

export { isSameDay as A, getDaysInMonth as B, startOfDay as C, ue as D, timeFormatHasMeridiem as E, isHideSeconds as F, listenToLanguageChange as G, formatDateAsDayString as H, formatDate as I, me as L, tap as a, toDate as b, toInteger as c, getUTCISOWeek as d, getUTCWeek as e, flattenArray as f, getLogger as g, getUTCWeekYear as h, isResponsiveMode as i, startOfUTCWeek as j, startOfUTCISOWeek as k, isProtectedWeekYearToken as l, throwProtectedError as m, isProtectedDayOfYearToken as n, subMilliseconds as o, getTimezoneOffsetInMilliseconds as p, r as q, requiredArgs as r, setLocale as s, translate as t, h as u, addDays as v, format as w, setMonth as x, ce as y, createDate as z }

